@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.112 $
+ * $Revision: 2.118 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 // *************************************************************************
 // This is the HYPRE implementation of LinearSystemCore.
 // *************************************************************************
@@ -65,7 +52,7 @@ enum HYsolverID {HYPCG,HYLSICG,HYGMRES,HYFGMRES,HYCGSTAB,HYCGSTABL,HYTFQMR,
                  HYY12M,HYAMGE,HYHYBRID};
 enum HYpreconID {HYIDENTITY,HYDIAGONAL,HYPILUT,HYPARASAILS,HYBOOMERAMG,HYML,
                  HYDDILUT,HYPOLY,HYDDICT,HYSCHWARZ,HYEUCLID,HYBLOCK,HYMLI,
-                 HYUZAWA,HYMLMAXWELL,HYAMS};
+                 HYUZAWA,HYMLMAXWELL,HYAMS,HYSYSPDE};
 
 #define HYFEI_HIGHMASK      2147483647-255
 #define HYFEI_SPECIALMASK              255
@@ -474,9 +461,10 @@ class HYPRE_LinSysCore
    void   setupPreconAMS();
    void   setupPreconBlock();
    void   setupPreconEuclid();
+   void   setupPreconSysPDE();
    void   solveUsingBoomeramg(int&);
-   void   solveUsingSuperLU(int&);
-   void   solveUsingSuperLUX(int&);
+   double solveUsingSuperLU(int&);
+   double solveUsingSuperLUX(int&);
    void   solveUsingDSuperLU(int&);
    void   solveUsingY12M(int&);
    void   solveUsingAMGe(int&);
@@ -656,6 +644,9 @@ class HYPRE_LinSysCore
    int             amgSchwarzDomainType_;
    int             amgUseGSMG_;
    int             amgGSMGNSamples_;
+   int             amgAggLevels_;
+   int             amgInterpType_;
+   int             amgPmax_;
    int             pilutFillin_;
    double          pilutDropTol_;
    int             pilutMaxNnzPerRow_;
@@ -692,6 +683,35 @@ class HYPRE_LinSysCore
    HYPRE_IJVector  amsX_;
    HYPRE_IJVector  amsY_;
    HYPRE_IJVector  amsZ_;
+   HYPRE_ParCSRMatrix  amsBetaPoisson_;
+   int             amsNumPDEs_;
+   int             amsMaxIter_;
+   double          amsTol_;
+   int             amsCycleType_;
+   int             amsRelaxType_;
+   int             amsRelaxTimes_;
+   double          amsRelaxWt_;
+   double          amsRelaxOmega_;
+   int             amsPrintLevel_;
+   int             amsAlphaCoarsenType_;
+   int             amsAlphaAggLevels_;
+   int             amsAlphaRelaxType_;
+   double          amsAlphaStrengthThresh_;
+   int             amsAlphaInterpType_;
+   int             amsAlphaPmax_;
+   int             amsBetaCoarsenType_;
+   int             amsBetaAggLevels_;
+   int             amsBetaRelaxType_;
+   double          amsBetaStrengthThresh_;
+   int             amsBetaInterpType_;
+   int             amsBetaPmax_;
+   int             sysPDEMethod_;
+   int             sysPDEFormat_;
+   double          sysPDETol_;
+   int             sysPDEMaxIter_;
+   int             sysPDENumPre_;
+   int             sysPDENumPost_;
+   int             sysPDENVars_;
 
    // ----------------------------------------------------------------------
    // FEI and MLI variables
@@ -711,6 +731,8 @@ class HYPRE_LinSysCore
    double          MLI_Hybrid_ConvRate_;
    int             MLI_Hybrid_NTrials_;
    HYPRE_FEI_AMSData AMSData_;
+   int             FEI_mixedDiagFlag_;
+   double          *FEI_mixedDiag_;
 
    // ----------------------------------------------------------------------
    // ML Maxwell variables
