@@ -2,8 +2,8 @@
 // File:	String.java
 // Package:	sidl
 // Copyright:	(c) 2000-2001 The Regents of the University of California
-// Revision:	$Revision: 1.5 $
-// Modified:	$Date: 2006/08/29 22:29:21 $
+// Revision:	$Revision: 1.6 $
+// Modified:	$Date: 2007/09/27 19:35:15 $
 // Description:	holder and array classes for built-in data types
 //
 // Copyright (c) 2000-2001, The Regents of the University of Calfornia.
@@ -250,6 +250,13 @@ public class String {
     public Array get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
 
 }
@@ -447,6 +454,13 @@ public class String {
     public Array1 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
   }
 
@@ -652,6 +666,14 @@ public class String {
     public Array2 get() {
       return d_obj;
     }
+
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
     }
   }
 
@@ -865,6 +887,13 @@ public class String {
     public Array3 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
 
   }
@@ -1091,6 +1120,13 @@ public class String {
     public Array4 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
 
   }
@@ -1326,6 +1362,13 @@ public class String {
     public Array5 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
 
   }
@@ -1568,6 +1611,13 @@ public class String {
     public Array6 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
   }
 
@@ -1824,6 +1874,13 @@ public class String {
     public Array7 get() {
       return d_obj;
     }
+
+    /**
+     * Destroy held array
+     */
+    public void destroy() {
+      if (d_obj != null) { d_obj.destroy(); d_obj = null; }
+    }
   }
 
   }
