@@ -1,62 +1,50 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.9 $
+ * $Revision: 2.12 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /* hypre_blas.h  --  Contains BLAS prototypes needed by Hypre */
 
 #ifndef HYPRE_BLAS_H
 #define HYPRE_BLAS_H
 #include "f2c.h"
+#include "fortran.h"
 
 /* --------------------------------------------------------------------------
  *   Change all names to hypre_ to avoid link conflicts
  * --------------------------------------------------------------------------*/
 
-#define dasum_   hypre_dasum
-#define daxpy_   hypre_daxpy
-#define dcopy_   hypre_dcopy
-#define ddot_    hypre_ddot
-#define dgemm_   hypre_dgemm
-#define dgemv_   hypre_dgemv
-#define dger_    hypre_dger
-#define dnrm2_   hypre_dnrm2
-#define drot_    hypre_drot
-#define dscal_   hypre_dscal
-#define dswap_   hypre_dswap
-#define dsymm_   hypre_dsymm
-#define dsymv_   hypre_dsymv
-#define dsyr2_   hypre_dsyr2
-#define dsyr2k_  hypre_dsyr2k
-#define dsyrk_   hypre_dsyrk
-#define dtrmm_   hypre_dtrmm
-#define dtrmv_   hypre_dtrmv
-#define dtrsm_   hypre_dtrsm
-#define dtrsv_   hypre_dtrsv
-#define idamax_  hypre_idamax
+#define dasum_   hypre_F90_NAME_BLAS(dasum,DASUM)
+#define daxpy_   hypre_F90_NAME_BLAS(daxpy,DAXPY)
+#define dcopy_   hypre_F90_NAME_BLAS(dcopy,DCOPY)
+#define ddot_    hypre_F90_NAME_BLAS(ddot,DDOT)
+#define dgemm_   hypre_F90_NAME_BLAS(dgemm,DGEMM)
+#define dgemv_   hypre_F90_NAME_BLAS(dgemv,DGEMV)
+#define dger_    hypre_F90_NAME_BLAS(dger,DGER)
+#define dnrm2_   hypre_F90_NAME_BLAS(dnrm2,DNRM2)
+#define drot_    hypre_F90_NAME_BLAS(drot,DROT)
+#define dscal_   hypre_F90_NAME_BLAS(dscal,DSCAL)
+#define dswap_   hypre_F90_NAME_BLAS(dswap,DSWAP)
+#define dsymm_   hypre_F90_NAME_BLAS(dsymm,DSYMM)
+#define dsymv_   hypre_F90_NAME_BLAS(dsymv,DSYMV)
+#define dsyr2_   hypre_F90_NAME_BLAS(dsyr2,DSYR2)
+#define dsyr2k_  hypre_F90_NAME_BLAS(dsyr2k,DSYR2K)
+#define dsyrk_   hypre_F90_NAME_BLAS(dsyrk,DSYRK)
+#define dtrmm_   hypre_F90_NAME_BLAS(dtrmm,DTRMM)
+#define dtrmv_   hypre_F90_NAME_BLAS(dtrmv,DTRMV)
+#define dtrsm_   hypre_F90_NAME_BLAS(dtrsm,DTRSM)
+#define dtrsv_   hypre_F90_NAME_BLAS(dtrsv,DTRSV)
+#define idamax_  hypre_F90_NAME_BLAS(idamax,IDAMAX)
 
 /* blas_utils.c */
 logical lsame_ ( char *ca , char *cb );
