@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.2 $
+ * $Revision: 2.5 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /*
  * ilut.c
  *
@@ -34,7 +21,7 @@
  * Started 11/29/95
  * George
  *
- * $Id: ilut.c,v 2.2 2006/09/22 22:06:01 hill66 Exp $
+ * $Id: ilut.c,v 2.5 2008/07/18 01:32:40 ulrikey Exp $
  */
 
 #include <math.h>
@@ -105,7 +92,7 @@ int hypre_ILUT(DataDistType *ddist, HYPRE_DistributedMatrix matrix, FactorMatTyp
 
     ierr = HYPRE_DistributedMatrixGetRow( matrix, firstrow+i, &size,
                NULL, &values);
-    if (ierr) return(ierr);
+    /* if (ierr) return(ierr);*/
     dummy_row_ptr[ 1 ] = size;
     hypre_ComputeAdd2Nrms( 1, dummy_row_ptr, values, &(ldu->nrm2s[i]) );
     ierr = HYPRE_DistributedMatrixRestoreRow( matrix, firstrow+i, &size,
