@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.3 $
+ * $Revision: 2.6 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /*
  * serilut.c
  *
@@ -47,7 +34,7 @@
  * 1/13 AJC
  * - Modified code with macros to allow both 0 and 1-based indexing
  *
- * $Id: serilut.c,v 2.3 2006/09/22 22:06:01 hill66 Exp $
+ * $Id: serilut.c,v 2.6 2008/07/18 01:32:40 ulrikey Exp $
  *
  */
 
@@ -114,11 +101,11 @@ int hypre_SerILUT(DataDistType *ddist, HYPRE_DistributedMatrix matrix,
 }
 #endif
 
-  if(ierr) return(ierr);
+/* if(ierr) return(ierr);*/
 
   /* Exchange structural unions with other processors */
   ierr = ExchangeStructuralUnions( ddist, &structural_union, globals );
-  if(ierr) return(ierr);
+  /* if(ierr) return(ierr); */
 
   /* Select the rows to be factored */
 #ifdef HYPRE_TIMING
@@ -171,7 +158,7 @@ int hypre_SerILUT(DataDistType *ddist, HYPRE_DistributedMatrix matrix,
     /* Initialize work space  */
     ierr = HYPRE_DistributedMatrixGetRow( matrix, firstrow+i, &row_size,
                &col_ind, &values);
-    if (ierr) return(ierr);
+    /* if (ierr) return(ierr); */
 
     for (lastjr=1, lastlr=0, j=0, diag_present=0; j<row_size; j++) {
       if (iperm[ col_ind[j] - firstrow ] < iperm[i]) 
@@ -269,7 +256,7 @@ int hypre_SerILUT(DataDistType *ddist, HYPRE_DistributedMatrix matrix,
     /* Initialize work space */
     ierr = HYPRE_DistributedMatrixGetRow( matrix, firstrow+i, &row_size,
                &col_ind, &values);
-    if (ierr) return(ierr);
+    /* if (ierr) return(ierr); */
 
     for (lastjr=1, lastlr=0, j=0, diag_present=0; j<row_size; j++) {
       if (col_ind[j] >= firstrow  &&
@@ -390,7 +377,7 @@ int hypre_SelectInterior( int local_num_rows,
     {
       ierr = HYPRE_DistributedMatrixGetRow( matrix, firstrow+i, &row_size,
                &col_ind, &values);
-      if (ierr) return(ierr);
+      /* if (ierr) return(ierr); */
 
       for (j=0, break_loop=0; ( j<row_size )&& (break_loop == 0); j++) 
       {
@@ -439,7 +426,7 @@ int FindStructuralUnion( HYPRE_DistributedMatrix matrix,
     /* Get row structure; no values needed */
     ierr = HYPRE_DistributedMatrixGetRow( matrix, firstrow+i, &row_size,
                &col_ind, NULL );
-    if (ierr) return(ierr);
+    /* if (ierr) return(ierr); */
 
     /* Loop through nonzeros in this row */
     for ( j=0; j<row_size; j++)
@@ -453,7 +440,7 @@ int FindStructuralUnion( HYPRE_DistributedMatrix matrix,
     /* Restore row structure */
     ierr = HYPRE_DistributedMatrixRestoreRow( matrix, firstrow+i, &row_size,
                &col_ind, NULL );
-    if (ierr) return(ierr);
+    /* if (ierr) return(ierr); */
 
   }
 
@@ -585,7 +572,7 @@ void hypre_SecondDrop(int maxnz, double tol, int row,
   /* Now, I want to keep maxnz elements of L. Go and extract them */
 
   ierr = hypre_DoubleQuickSplit( w, jw, last, maxnz ); 
-  if (ierr) return;
+  /* if (ierr) return; */
   for ( j= hypre_max(0,last-maxnz); j< last; j++ ) 
   {
      ldu->lcolind[ldu->lerowptr[lrow]] = jw[ j ];
@@ -613,7 +600,7 @@ void hypre_SecondDrop(int maxnz, double tol, int row,
 
   /* Now, I want to keep maxnz elements of U. Go and extract them */
   ierr = hypre_DoubleQuickSplit( w+first, jw+first, lastjr-first, maxnz ); 
-  if (ierr) return;
+  /* if (ierr) return; */
   for ( j=hypre_max(first, lastjr-maxnz); j< lastjr; j++ ) 
   {
      ldu->ucolind[ldu->uerowptr[lrow]] = jw[ j ];
@@ -739,7 +726,7 @@ void hypre_SecondDropUpdate(int maxnz, int maxnzkeep, double tol, int row,
 
   /* Keep large maxnz elements of L */
   ierr = hypre_DoubleQuickSplit( w+1, jw+1, last-1, maxnz ); 
-  if (ierr) return;
+  /* if (ierr) return; */
   for ( j= hypre_max(1,last-maxnz); j< last; j++ ) 
   {
      ldu->lcolind[ldu->lerowptr[lrow]] = jw[ j ];
