@@ -1,29 +1,16 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.1 $
+ * $Revision: 2.7 $
  ***********************************************************************EHEADER*/
 
+
 #ifndef HYPRE_KRYLOV_HEADER
 #define HYPRE_KRYLOV_HEADER
 
@@ -85,6 +72,13 @@ typedef int (*HYPRE_PtrToSolverFcn)(HYPRE_Solver,
                                     HYPRE_Vector,
                                     HYPRE_Vector);
 
+#ifndef HYPRE_MODIFYPC
+#define HYPRE_MODIFYPC
+typedef int (*HYPRE_PtrToModifyPCFcn)(HYPRE_Solver,
+                                      int,
+                                      double);
+
+#endif
 /*@}*/
 
 /*--------------------------------------------------------------------------
@@ -113,11 +107,22 @@ int HYPRE_PCGSolve(HYPRE_Solver solver,
                    HYPRE_Vector x);
 
 /**
- * (Optional) Set the convergence tolerance.
+ * (Optional) Set the relative convergence tolerance.
  **/
 int HYPRE_PCGSetTol(HYPRE_Solver solver,
                     double       tol);
 
+/**
+ * (Optional) Set the absolute convergence tolerance (default is
+ * 0). If one desires the convergence test to check the absolute
+ * convergence tolerance {\it only}, then set the relative convergence
+ * tolerance to 0.0.  (The default convergence test is $ <C*r,r> \leq$
+ * max(relative$\_$tolerance$^{2} \ast <C*b, b>$, absolute$\_$tolerance$^2$).)
+ **/
+int HYPRE_PCGSetAbsoluteTol(HYPRE_Solver solver,
+                            double       a_tol);
+
+
 /*
  * RE-VISIT
  **/
@@ -269,12 +274,24 @@ HYPRE_GMRESSolve(HYPRE_Solver solver,
 
 
 /**
- * (Optional) Set the convergence tolerance.
+ * (Optional) Set the relative convergence tolerance.
  **/
 int
 HYPRE_GMRESSetTol(HYPRE_Solver solver,
                   double       tol);
 
+/**
+ * (Optional) Set the absolute convergence tolerance (default is 0). 
+ * If one desires
+ * the convergence test to check the absolute convergence tolerance {\it only}, then
+ * set the relative convergence tolerance to 0.0.  (The convergence test is 
+ * $\|r\| \leq$ max(relative$\_$tolerance$\ast \|b\|$, absolute$\_$tolerance).)
+ *
+ **/
+int
+HYPRE_GMRESSetAbsoluteTol(HYPRE_Solver solver,
+                  double       a_tol);
+
 /*
  * RE-VISIT
  **/
@@ -357,13 +374,17 @@ HYPRE_GMRESGetResidual(HYPRE_Solver   solver,
  **/
 int HYPRE_GMRESGetTol(HYPRE_Solver solver, double *tol);
 
+/**
+ **/
+int HYPRE_GMRESGetAbsoluteTol(HYPRE_Solver solver, double *tol);
+
 /*
  * RE-VISIT
  **/
 int HYPRE_GMRESGetConvergenceFactorTol(HYPRE_Solver solver, double *cf_tol);
 
 /*
- * RE-VISIT
+ * OBSOLETE 
  **/
 int HYPRE_GMRESGetStopCrit(HYPRE_Solver solver, int *stop_crit);
 
@@ -401,7 +422,173 @@ int HYPRE_GMRESGetPrintLevel(HYPRE_Solver solver, int *level);
 int HYPRE_GMRESGetConverged(HYPRE_Solver solver, int *converged);
 
 /*@}*/
+/**
+ * @name FlexGMRES Solver
+ **/
+/*@{*/
 
+/**
+ * Prepare to solve the system.  The coefficient data in {\tt b} and {\tt x} is
+ * ignored here, but information about the layout of the data may be used.
+ **/
+int 
+HYPRE_FlexGMRESSetup(HYPRE_Solver solver,
+                 HYPRE_Matrix A,
+                 HYPRE_Vector b,
+                 HYPRE_Vector x);
+
+
+/**
+ * Solve the system.
+ **/
+int 
+HYPRE_FlexGMRESSolve(HYPRE_Solver solver,
+                 HYPRE_Matrix A,
+                 HYPRE_Vector b,
+                 HYPRE_Vector x);
+
+
+/**
+ * (Optional) Set the convergence tolerance.
+ **/
+int
+HYPRE_FlexGMRESSetTol(HYPRE_Solver solver,
+                  double       tol);
+
+/**
+ * (Optional) Set the absolute convergence tolerance (default is 0). 
+ * If one desires
+ * the convergence test to check the absolute convergence tolerance {\it only}, then
+ * set the relative convergence tolerance to 0.0.  (The convergence test is 
+ * $\|r\| \leq$ max(relative$\_$tolerance$\ast \|b\|$, absolute$\_$tolerance).)
+ *
+ **/
+int
+HYPRE_FlexGMRESSetAbsoluteTol(HYPRE_Solver solver,
+                  double       a_tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_FlexGMRESSetConvergenceFactorTol(HYPRE_Solver solver, double cf_tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_FlexGMRESSetMinIter(HYPRE_Solver solver, int min_iter);
+
+/**
+ * (Optional) Set maximum number of iterations.
+ **/
+int
+HYPRE_FlexGMRESSetMaxIter(HYPRE_Solver solver,
+                      int          max_iter);
+
+/**
+ * (Optional) Set the maximum size of the Krylov space.
+ **/
+int HYPRE_FlexGMRESSetKDim(HYPRE_Solver solver,
+                       int          k_dim);
+
+
+/**
+ * (Optional) Set the preconditioner to use.
+ **/
+int
+HYPRE_FlexGMRESSetPrecond(HYPRE_Solver         solver,
+                      HYPRE_PtrToSolverFcn precond,
+                      HYPRE_PtrToSolverFcn precond_setup,
+                      HYPRE_Solver         precond_solver);
+
+/**
+ * (Optional) Set the amount of logging to do.
+ **/
+int
+HYPRE_FlexGMRESSetLogging(HYPRE_Solver solver,
+                      int          logging);
+
+/**
+ * (Optional) Set the amount of printing to do to the screen.
+ **/
+int
+HYPRE_FlexGMRESSetPrintLevel(HYPRE_Solver solver,
+                         int          level);
+
+/**
+ * Return the number of iterations taken.
+ **/
+int
+HYPRE_FlexGMRESGetNumIterations(HYPRE_Solver  solver,
+                            int          *num_iterations);
+
+/**
+ * Return the norm of the final relative residual.
+ **/
+int
+HYPRE_FlexGMRESGetFinalRelativeResidualNorm(HYPRE_Solver  solver,
+                                        double       *norm);
+
+/**
+ * Return the residual.
+ **/
+int
+HYPRE_FlexGMRESGetResidual(HYPRE_Solver   solver,
+                       void         **residual);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetTol(HYPRE_Solver solver, double *tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_FlexGMRESGetConvergenceFactorTol(HYPRE_Solver solver, double *cf_tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_FlexGMRESGetStopCrit(HYPRE_Solver solver, int *stop_crit);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_FlexGMRESGetMinIter(HYPRE_Solver solver, int *min_iter);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetMaxIter(HYPRE_Solver solver, int *max_iter);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetKDim(HYPRE_Solver solver, int *k_dim);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetPrecond(HYPRE_Solver solver, HYPRE_Solver *precond_data_ptr);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetLogging(HYPRE_Solver solver, int *level);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetPrintLevel(HYPRE_Solver solver, int *level);
+
+/**
+ **/
+int HYPRE_FlexGMRESGetConverged(HYPRE_Solver solver, int *converged);
+
+/**
+ * (Optional) Set a user-defined function to modify solve-time preconditioner
+ * attributes.
+ **/
+int HYPRE_FlexGMRESSetModifyPC( HYPRE_Solver  solver,
+                             HYPRE_PtrToModifyPCFcn modify_pc);
+   
+
+
+
+/*@}*/
 /*--------------------------------------------------------------------------
  *--------------------------------------------------------------------------*/
 
@@ -441,6 +628,19 @@ int
 HYPRE_BiCGSTABSetTol(HYPRE_Solver solver,
                      double       tol);
 
+
+/**
+ * (Optional) Set the absolute convergence tolerance (default is 0). 
+ * If one desires
+ * the convergence test to check the absolute convergence tolerance {\it only}, then
+ * set the relative convergence tolerance to 0.0.  (The convergence test is 
+ * $\|r\| \leq$ max(relative$\_$tolerance $\ast \|b\|$, absolute$\_$tolerance).)
+ *
+ **/
+int
+HYPRE_BiCGSTABSetAbsoluteTol(HYPRE_Solver solver,
+                             double       a_tol);
+
 /*
  * RE-VISIT
  **/
@@ -513,6 +713,182 @@ int HYPRE_BiCGSTABGetPrecond(HYPRE_Solver solver, HYPRE_Solver *precond_data_ptr
 
 /*@}*/
 
+/*--------------------------------------------------------------------------
+ *--------------------------------------------------------------------------*/
+
+/**
+ * @name LGMRES Solver
+ **/
+/*@{*/
+
+/**
+ * Prepare to solve the system.  The coefficient data in {\tt b} and {\tt x} is
+ * ignored here, but information about the layout of the data may be used.
+ **/
+int 
+HYPRE_LGMRESSetup(HYPRE_Solver solver,
+                 HYPRE_Matrix A,
+                 HYPRE_Vector b,
+                 HYPRE_Vector x);
+
+
+/**
+ * Solve the system. Details on LGMRES may be found in A. H. Baker,
+ * E.R. Jessup, and T.A. Manteuffel, "A technique for accelerating the
+ * convergence of restarted GMRES." SIAM Journal on Matrix Analysis and
+ * Applications, 26 (2005), pp. 962-984. LGMRES(m,k) in the paper
+ * corresponds to LGMRES(Kdim+AugDim, AugDim).
+ **/
+int 
+HYPRE_LGMRESSolve(HYPRE_Solver solver,
+                 HYPRE_Matrix A,
+                 HYPRE_Vector b,
+                 HYPRE_Vector x);
+
+
+/**
+ * (Optional) Set the convergence tolerance.
+ **/
+int
+HYPRE_LGMRESSetTol(HYPRE_Solver solver,
+                  double       tol);
+/**
+ * (Optional) Set the absolute convergence tolerance (default is 0). 
+ * If one desires
+ * the convergence test to check the absolute convergence tolerance {\it only}, then
+ * set the relative convergence tolerance to 0.0.  (The convergence test is 
+ * $\|r\| \leq$ max(relative$\_$tolerance$\ast \|b\|$, absolute$\_$tolerance).)
+ *
+ **/
+int
+HYPRE_LGMRESSetAbsoluteTol(HYPRE_Solver solver,
+                  double       a_tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_LGMRESSetConvergenceFactorTol(HYPRE_Solver solver, double cf_tol);
+
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_LGMRESSetMinIter(HYPRE_Solver solver, int min_iter);
+
+/**
+ * (Optional) Set maximum number of iterations.
+ **/
+int
+HYPRE_LGMRESSetMaxIter(HYPRE_Solver solver,
+                      int          max_iter);
+
+/**
+ * (Optional) Set the maximum size of the approximation space
+ * (includes the augmentation vectors).
+ **/
+int HYPRE_LGMRESSetKDim(HYPRE_Solver solver,
+                       int          k_dim);
+
+/**
+ * (Optional) Set the number of augmentation vectors  (default: 2).
+ **/
+int HYPRE_LGMRESSetAugDim(HYPRE_Solver solver,
+                       int          aug_dim);
+
+
+
+/**
+ * (Optional) Set the preconditioner to use.
+ **/
+int
+HYPRE_LGMRESSetPrecond(HYPRE_Solver         solver,
+                      HYPRE_PtrToSolverFcn precond,
+                      HYPRE_PtrToSolverFcn precond_setup,
+                      HYPRE_Solver         precond_solver);
+
+/**
+ * (Optional) Set the amount of logging to do.
+ **/
+int
+HYPRE_LGMRESSetLogging(HYPRE_Solver solver,
+                      int          logging);
+
+/**
+ * (Optional) Set the amount of printing to do to the screen.
+ **/
+int
+HYPRE_LGMRESSetPrintLevel(HYPRE_Solver solver,
+                         int          level);
+
+/**
+ * Return the number of iterations taken.
+ **/
+int
+HYPRE_LGMRESGetNumIterations(HYPRE_Solver  solver,
+                            int          *num_iterations);
+
+/**
+ * Return the norm of the final relative residual.
+ **/
+int
+HYPRE_LGMRESGetFinalRelativeResidualNorm(HYPRE_Solver  solver,
+                                        double       *norm);
+
+/**
+ * Return the residual.
+ **/
+int
+HYPRE_LGMRESGetResidual(HYPRE_Solver   solver,
+                       void         **residual);
+
+/**
+ **/
+int HYPRE_LGMRESGetTol(HYPRE_Solver solver, double *tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_LGMRESGetConvergenceFactorTol(HYPRE_Solver solver, double *cf_tol);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_LGMRESGetStopCrit(HYPRE_Solver solver, int *stop_crit);
+
+/*
+ * RE-VISIT
+ **/
+int HYPRE_LGMRESGetMinIter(HYPRE_Solver solver, int *min_iter);
+
+/**
+ **/
+int HYPRE_LGMRESGetMaxIter(HYPRE_Solver solver, int *max_iter);
+
+/**
+ **/
+int HYPRE_LGMRESGetKDim(HYPRE_Solver solver, int *k_dim);
+/**
+ **/
+int HYPRE_LGMRESGetAugDim(HYPRE_Solver solver, int *k_dim);
+
+
+/**
+ **/
+int HYPRE_LGMRESGetPrecond(HYPRE_Solver solver, HYPRE_Solver *precond_data_ptr);
+
+/**
+ **/
+int HYPRE_LGMRESGetLogging(HYPRE_Solver solver, int *level);
+
+/**
+ **/
+int HYPRE_LGMRESGetPrintLevel(HYPRE_Solver solver, int *level);
+
+/**
+ **/
+int HYPRE_LGMRESGetConverged(HYPRE_Solver solver, int *converged);
+
+/*@}*/
 /*--------------------------------------------------------------------------
  *--------------------------------------------------------------------------*/
 
