@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.13 $
+ * $Revision: 2.17 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_PCG interface
@@ -108,6 +95,23 @@ HYPRE_PCGGetTol( HYPRE_Solver solver,
 {
    return( hypre_PCGGetTol( (void *) solver, tol ) );
 }
+/*--------------------------------------------------------------------------
+ * HYPRE_PCGSetAbsoluteTol, HYPRE_PCGGetAbsoluteTol
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_PCGSetAbsoluteTol( HYPRE_Solver solver,
+                 double             a_tol    )
+{
+   return( hypre_PCGSetAbsoluteTol( (void *) solver, a_tol ) );
+}
+
+int
+HYPRE_PCGGetAbsoluteTol( HYPRE_Solver solver,
+                 double           * a_tol    )
+{
+   return( hypre_PCGGetAbsoluteTol( (void *) solver, a_tol ) );
+}
 
 /*--------------------------------------------------------------------------
  * HYPRE_PCGSetAbsoluteTolFactor, HYPRE_PCGGetAbsoluteTolFactor
@@ -219,6 +223,24 @@ HYPRE_PCGGetRelChange( HYPRE_Solver solver,
    return( hypre_PCGGetRelChange( (void *) solver, rel_change ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_PCGSetRecomputeResidual, HYPRE_PCGGetRecomputeResidual
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_PCGSetRecomputeResidual( HYPRE_Solver solver,
+                       int                recompute_residual )
+{
+   return( hypre_PCGSetRecomputeResidual( (void *) solver, recompute_residual ) );
+}
+
+int
+HYPRE_PCGGetRecomputeResidual( HYPRE_Solver solver,
+                       int              * recompute_residual )
+{
+   return( hypre_PCGGetRecomputeResidual( (void *) solver, recompute_residual ) );
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_PCGSetPrecond
  *--------------------------------------------------------------------------*/
