@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.12 $
+ * $Revision: 2.18 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 /******************************************************************************
  *
  * Preconditioned conjugate gradient (Omin) headers
@@ -71,7 +58,7 @@
 
 typedef struct
 {
-   char * (*CAlloc)        ( int count, int elt_size );
+   char * (*CAlloc)        ( size_t count, size_t elt_size );
    int    (*Free)          ( char *ptr );
    int    (*CommInfo)      ( void  *A, int   *my_id, int   *num_procs );
    void * (*CreateVector)  ( void *vector );
@@ -100,14 +87,25 @@ typedef struct
  where the norm is an energy norm wrt preconditioner, |r|=sqrt(<Cr,r>).
  - two_norm!=0 means: the norm is the L2 norm, |r|=sqrt(<r,r>)
  - rel_change!=0 means: if pass the other stopping criteria, also check the
- relative change in the solution x.
- - stop_crit!=0 means: pure absolute error tolerance rather than a pure relative
- error tolerance on the residual.  Never applies if rel_change!=0 or atolf!=0.
+ relative change in the solution x.  Pass iff this relative change is small.
+ - tol = relative error tolerance, as above
+ -a_tol = absolute convergence tolerance (default is 0.0)
+   If one desires the convergence test to check the absolute
+   convergence tolerance *only*, then set the relative convergence
+   tolerance to 0.0.  (The default convergence test is  <C*r,r> <=
+   max(relative_tolerance^2 * <C*b, b>, absolute_tolerance^2)
+- cf_tol = convergence factor tolerance; if >0 used for special test
+  for slow convergence
+- stop_crit!=0 means (TO BE PHASED OUT):
+  pure absolute error tolerance rather than a pure relative
+  error tolerance on the residual.  Never applies if rel_change!=0 or atolf!=0.
  - atolf = absolute error tolerance factor to be used _together_ with the
  relative error tolerance, |delta-residual| / ( atolf + |right-hand-side| ) < tol
- - tol = relative error tolerance, as above
- - cf_tol = convergence factor tolerance; if >0 used for special test
- for slow convergence
+  (To BE PHASED OUT)
+ - recompute_residual means: when the iteration seems to be converged, recompute the
+ residual from scratch (r=b-Ax) and use this new residual to repeat the convergence test.
+ This can be expensive, use this only if you have seen a problem with the regular
+ residual computation.
 */
 
 typedef struct
@@ -115,9 +113,11 @@ typedef struct
    double   tol;
    double   atolf;
    double   cf_tol;
+   double   a_tol;
    int      max_iter;
    int      two_norm;
    int      rel_change;
+   int      recompute_residual;
    int      stop_crit;
    int      converged;
 
@@ -166,7 +166,7 @@ extern "C" {
 
 hypre_PCGFunctions *
 hypre_PCGFunctionsCreate(
-   char * (*CAlloc)        ( int count, int elt_size ),
+   char * (*CAlloc)        ( size_t count, size_t elt_size ),
    int    (*Free)          ( char *ptr ),
    int    (*CommInfo)      ( void  *A, int   *my_id, int   *num_procs ),
    void * (*CreateVector)  ( void *vector ),
