@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.4 $
+ * $Revision: 2.7 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * Routine for building a DistributedMatrix from a ParCSRMatrix
@@ -104,31 +91,31 @@ HYPRE_BuildIJMatrixFromDistributedMatrix(
 
    ierr = HYPRE_IJMatrixSetLocalStorageType( 
                  *ij_matrix, local_storage_type );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr); */
 
    ierr = HYPRE_IJMatrixSetLocalSize( *ij_matrix, 
                 last_local_row-first_local_row+1,
                 last_local_col-first_local_col+1 );
 
    ierr = HYPRE_IJMatrixInitialize( *ij_matrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr);*/
 
    /* Loop through all locally stored rows and insert them into ij_matrix */
    for (i=first_local_row; i<= last_local_row; i++)
    {
       ierr = HYPRE_DistributedMatrixGetRow( DistributedMatrix, i, &size, &col_ind, &values );
-      if( ierr ) return(ierr);
+      /* if( ierr ) return(ierr);*/
 
       ierr = HYPRE_IJMatrixInsertRow( *ij_matrix, size, i, col_ind, values );
-      if( ierr ) return(ierr);
+      /* if( ierr ) return(ierr);*/
 
       ierr = HYPRE_DistributedMatrixRestoreRow( DistributedMatrix, i, &size, &col_ind, &values );
-      if( ierr ) return(ierr);
+      /* if( ierr ) return(ierr); */
 
    }
 
    ierr = HYPRE_IJMatrixAssemble( *ij_matrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr); */
 
    return(ierr);
 }
