@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.2 $
+ * $Revision: 2.5 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * Routine for building a DistributedMatrix from a MPIAIJ Mat, i.e. PETSc matrix
@@ -80,17 +67,17 @@ HYPRE_ConvertPETScMatrixToDistributedMatrix(
    ierr = PetscObjectGetComm( (PetscObject) PETSc_matrix, &MPI_Comm); CHKERRA(ierr);
 
    ierr = HYPRE_DistributedMatrixCreate( MPI_Comm, DistributedMatrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr); */
 
    ierr = HYPRE_DistributedMatrixSetLocalStorageType( *DistributedMatrix,
                                                      HYPRE_PETSC );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr);*/
 
    ierr = HYPRE_DistributedMatrixInitialize( *DistributedMatrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr);*/
 
    ierr = HYPRE_DistributedMatrixSetLocalStorage( *DistributedMatrix, PETSc_matrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr); */
    /* Note that this is kind of cheating, since the Mat structure contains more
       than local information... the alternative is to extract the global info
       from the Mat and put it into DistributedMatrixAuxiliaryStorage. However,
@@ -101,7 +88,7 @@ HYPRE_ConvertPETScMatrixToDistributedMatrix(
    ierr = HYPRE_DistributedMatrixSetDims( *DistributedMatrix, M, N);
 
    ierr = HYPRE_DistributedMatrixAssemble( *DistributedMatrix );
-   if(ierr) return(ierr);
+   /* if(ierr) return(ierr);*/
 
 #ifdef HYPRE_TIMING
    hypre_EndTiming( timer );
