@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.28 $
+ * $Revision: 2.35 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_ParAMG interface
@@ -913,7 +900,17 @@ HYPRE_BoomerAMGGetSchwarzRlxWeight( HYPRE_Solver  solver,
    return( hypre_BoomerAMGGetSchwarzRlxWeight( (void *) solver, 
 			schwarz_rlx_weight ) );
 }
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetSchwarzUseNonSymm
+ *--------------------------------------------------------------------------*/
 
+int
+HYPRE_BoomerAMGSetSchwarzUseNonSymm( HYPRE_Solver  solver,
+                                     int use_nonsymm)
+{
+   return( hypre_BoomerAMGSetSchwarzUseNonSymm( (void *) solver, 
+			use_nonsymm ) );
+}
 /*--------------------------------------------------------------------------
  * HYPRE_BoomerAMGSym
  *--------------------------------------------------------------------------*/
@@ -991,6 +988,39 @@ HYPRE_BoomerAMGSetEuclidFile( HYPRE_Solver  solver,
    return( hypre_BoomerAMGSetEuclidFile( (void *) solver, euclidfile ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetEuLevel
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_BoomerAMGSetEuLevel( HYPRE_Solver  solver,
+                           int           eu_level)
+{
+   return( hypre_BoomerAMGSetEuLevel( (void *) solver, eu_level ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetEuSparseA
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_BoomerAMGSetEuSparseA( HYPRE_Solver  solver,
+                             double        eu_sparse_A  )
+{
+   return( hypre_BoomerAMGSetEuSparseA( (void *) solver, eu_sparse_A ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetEuBJ
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_BoomerAMGSetEuBJ( HYPRE_Solver  solver,
+                        int	      eu_bj)
+{
+   return( hypre_BoomerAMGSetEuBJ( (void *) solver, eu_bj ) );
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_BoomerAMGSetNumFunctions, HYPRE_BoomerAMGGetNumFunctions
  *--------------------------------------------------------------------------*/
@@ -1019,7 +1049,16 @@ HYPRE_BoomerAMGSetNodal( HYPRE_Solver  solver,
 {
    return( hypre_BoomerAMGSetNodal( (void *) solver, nodal ) );
 }
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetNodalDiag
+ *--------------------------------------------------------------------------*/
 
+int
+HYPRE_BoomerAMGSetNodalDiag( HYPRE_Solver  solver,
+                         int          nodal  )
+{
+   return( hypre_BoomerAMGSetNodalDiag( (void *) solver, nodal ) );
+}
 /*--------------------------------------------------------------------------
  * HYPRE_BoomerAMGSetDofFunc
  *--------------------------------------------------------------------------*/
@@ -1080,6 +1119,17 @@ HYPRE_BoomerAMGSetCRRate( HYPRE_Solver  solver,
    return( hypre_BoomerAMGSetCRRate( (void *) solver, CR_rate ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetCRStrongTh
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_BoomerAMGSetCRStrongTh( HYPRE_Solver  solver,
+                          double        CR_strong_th  )
+{
+   return( hypre_BoomerAMGSetCRStrongTh( (void *) solver, CR_strong_th ) );
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_BoomerAMGSetISType
  *--------------------------------------------------------------------------*/
@@ -1123,3 +1173,62 @@ HYPRE_BoomerAMGSetNumSamples( HYPRE_Solver  solver,
 {
    return( hypre_BoomerAMGSetNumSamples( (void *) solver, gsmg ) );
 }
+/* BM Aug 25, 2006 */
+                                                                                                       
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetCGCIts
+ *--------------------------------------------------------------------------*/
+                                                                                                       
+int
+HYPRE_BoomerAMGSetCGCIts (HYPRE_Solver solver,
+                          int its)
+{
+  return (hypre_BoomerAMGSetCGCIts ( (void *) solver, its ) );
+}
+                                                                                                       
+/* BM Oct 23, 2006 */
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetPlotGrids
+ *--------------------------------------------------------------------------*/
+                                                                                                       
+int
+HYPRE_BoomerAMGSetPlotGrids (HYPRE_Solver solver,
+                             int plotgrids)
+{
+  return (hypre_BoomerAMGSetPlotGrids ( (void *) solver, plotgrids ) );
+}
+                                                                                                       
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetPlotFileName
+ *--------------------------------------------------------------------------*/
+                                                                                                       
+int
+HYPRE_BoomerAMGSetPlotFileName (HYPRE_Solver solver,
+                                const char *plotfilename)
+{
+  return (hypre_BoomerAMGSetPlotFileName ( (void *) solver, plotfilename ) );
+}
+                                                                                                       
+/* BM Oct 17, 2006 */
+                                                                                                       
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetCoordDim
+ *--------------------------------------------------------------------------*/
+                                                                                                       
+int
+HYPRE_BoomerAMGSetCoordDim (HYPRE_Solver solver,
+                            int coorddim)
+{
+  return (hypre_BoomerAMGSetCoordDim ( (void *) solver, coorddim ) );
+}
+                                                                                                       
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetCoordinates
+ *--------------------------------------------------------------------------*/
+                                                                                                       
+int
+HYPRE_BoomerAMGSetCoordinates (HYPRE_Solver solver,
+                               float *coordinates)
+{
+  return (hypre_BoomerAMGSetCoordinates ( (void *) solver, coordinates ) );
+}
