@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.12 $
+ * $Revision: 2.16 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -97,6 +84,16 @@ HYPRE_ParCSRHybridSetTol( HYPRE_Solver solver,
 {
    return( hypre_AMGHybridSetTol( (void *) solver, tol ) );
 }
+/*--------------------------------------------------------------------------
+ * HYPRE_ParCSRHybridSetAbsoluteTol
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_ParCSRHybridSetAbsoluteTol( HYPRE_Solver solver,
+                          double             tol    )
+{
+   return( hypre_AMGHybridSetAbsoluteTol( (void *) solver, tol ) );
+}
 
 /*--------------------------------------------------------------------------
  * HYPRE_ParCSRHybridSetConvergenceTol
@@ -268,6 +265,19 @@ HYPRE_ParCSRHybridSetTruncFactor( HYPRE_Solver solver,
    return( hypre_AMGHybridSetTruncFactor( (void *) solver, trunc_factor ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_ParCSRHybridSetPMaxElmts
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_ParCSRHybridSetPMaxElmts( HYPRE_Solver solver,
+                              int              p_max    )
+{
+   return( hypre_AMGHybridSetPMaxElmts( (void *) solver, p_max ) );
+}
+
+
+
 /*--------------------------------------------------------------------------
  * HYPRE_ParCSRHybridSetMaxLevels
  *--------------------------------------------------------------------------*/
