@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will  useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.7 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
 
+
 #include "headers.h"
 #include "aux_interp.h"
 
@@ -412,7 +399,7 @@ hypre_ParCSRCommExtendA(hypre_ParCSRMatrix *A, int newoff, int *found,
 	  }
       /* Sort new nodes at end */
       if(proc_found < index - 1)
-	ssort(&new_map[index - (index-proc_found)],index-proc_found);
+	hypre_ssort(&new_map[index - (index-proc_found)],index-proc_found);
       k++;
       i++;
     }
@@ -627,7 +614,7 @@ hypre_ParCSRCommExtendA(hypre_ParCSRMatrix *A, int newoff, int *found,
 #endif
 
 /* sort for non-ordered arrays */
-int ssort(int *data, int n)
+int hypre_ssort(int *data, int n)
 {
   int i,si;               
   int change = 0;
@@ -644,7 +631,7 @@ int ssort(int *data, int n)
   return change;
 }
 
-/* Auxilary function for ssort */
+/* Auxilary function for hypre_ssort */
 int index_of_minimum(int *data, int n)
 {
   int answer;
