@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.48 $
+ * $Revision: 2.59 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 /******************************************************************************
  *
  * ParAMG functions
@@ -54,19 +41,21 @@ hypre_BoomerAMGCreate()
    double   jacobi_trunc_threshold;
    double   S_commpkg_switch;
    double   CR_rate;
+   double   CR_strong_th;
    int      interp_type;
    int      coarsen_type;
    int      measure_type;
    int      setup_type;
    int      P_max_elmts;
    int 	    num_functions;
-   int 	    nodal;
+   int 	    nodal, nodal_diag;
    int 	    num_paths;
    int 	    agg_num_levels;
    int      post_interp_type;
    int 	    num_CR_relax_steps;
    int 	    IS_type;
    int 	    CR_use_CG;
+   int 	    cgc_its;
 
    /* solve params */
    int      min_iter;
@@ -84,12 +73,14 @@ hypre_BoomerAMGCreate()
    int      smooth_num_levels;
    int      smooth_num_sweeps;
 
-   int      variant, overlap, domain_type;
+   int      variant, overlap, domain_type, schwarz_use_nonsymm;
    double   schwarz_rlx_weight;
    int	    level, sym;
+   int	    eu_level, eu_bj;
+   int	    max_nz_per_row;
    double   thresh, filter;
    double   drop_tol;
-   int	    max_nz_per_row;
+   double   eu_sparse_A;
    char    *euclidfile;
 
    int block_mode;
@@ -106,6 +97,8 @@ hypre_BoomerAMGCreate()
    char     log_file_name[256];
    int      debug_flag;
 
+   char     plot_file_name[251];
+
    /*-----------------------------------------------------------------------
     * Setup default values for parameters
     *-----------------------------------------------------------------------*/
@@ -124,13 +117,16 @@ hypre_BoomerAMGCreate()
    P_max_elmts = 0;
    num_functions = 1;
    nodal = 0;
+   nodal_diag = 0;
    num_paths = 1;
    agg_num_levels = 0;
    post_interp_type = 0;
    num_CR_relax_steps = 2;
    CR_rate = 0.7;
+   CR_strong_th = 0;
    IS_type = 1;
    CR_use_CG = 0;
+   cgc_its = 1;
 
    variant = 0;
    overlap = 1;
@@ -139,7 +135,8 @@ hypre_BoomerAMGCreate()
    smooth_num_sweeps = 1;
    smooth_num_levels = 0;
    smooth_type = 6;
-
+   schwarz_use_nonsymm = 0;
+   
    level = 1;
    sym = 0;
    thresh = 0.1;
@@ -147,6 +144,9 @@ hypre_BoomerAMGCreate()
    drop_tol = 0.0001;
    max_nz_per_row = 20;
    euclidfile = NULL;
+   eu_level = 0;
+   eu_sparse_A = 0.0;
+   eu_bj = 0;
 
    /* solve params */
    min_iter  = 0;
@@ -193,16 +193,20 @@ hypre_BoomerAMGCreate()
    hypre_BoomerAMGSetPMaxElmts(amg_data, P_max_elmts);
    hypre_BoomerAMGSetNumFunctions(amg_data, num_functions);
    hypre_BoomerAMGSetNodal(amg_data, nodal);
+   hypre_BoomerAMGSetNodal(amg_data, nodal_diag);
    hypre_BoomerAMGSetNumPaths(amg_data, num_paths);
    hypre_BoomerAMGSetAggNumLevels(amg_data, agg_num_levels);
    hypre_BoomerAMGSetPostInterpType(amg_data, post_interp_type);
    hypre_BoomerAMGSetNumCRRelaxSteps(amg_data, num_CR_relax_steps);
    hypre_BoomerAMGSetCRRate(amg_data, CR_rate);
+   hypre_BoomerAMGSetCRStrongTh(amg_data, CR_strong_th);
    hypre_BoomerAMGSetISType(amg_data, IS_type);
    hypre_BoomerAMGSetCRUseCG(amg_data, CR_use_CG);
+   hypre_BoomerAMGSetCGCIts(amg_data, cgc_its);
    hypre_BoomerAMGSetVariant(amg_data, variant);
    hypre_BoomerAMGSetOverlap(amg_data, overlap);
    hypre_BoomerAMGSetSchwarzRlxWeight(amg_data, schwarz_rlx_weight);
+   hypre_BoomerAMGSetSchwarzUseNonSymm(amg_data, schwarz_use_nonsymm);
    hypre_BoomerAMGSetDomainType(amg_data, domain_type);
    hypre_BoomerAMGSetSym(amg_data, sym);
    hypre_BoomerAMGSetLevel(amg_data, level);
@@ -211,6 +215,9 @@ hypre_BoomerAMGCreate()
    hypre_BoomerAMGSetDropTol(amg_data, drop_tol);
    hypre_BoomerAMGSetMaxNzPerRow(amg_data, max_nz_per_row);
    hypre_BoomerAMGSetEuclidFile(amg_data, euclidfile);
+   hypre_BoomerAMGSetEuLevel(amg_data, eu_level);
+   hypre_BoomerAMGSetEuSparseA(amg_data, eu_sparse_A);
+   hypre_BoomerAMGSetEuBJ(amg_data, eu_bj);
 
    hypre_BoomerAMGSetMinIter(amg_data, min_iter);
    hypre_BoomerAMGSetMaxIter(amg_data, max_iter);
@@ -264,6 +271,14 @@ hypre_BoomerAMGCreate()
    /* this can not be set by the user currently */
    hypre_ParAMGDataBlockMode(amg_data) = block_mode;
 
+   /* BM Oct 22, 2006 */
+   hypre_ParAMGDataPlotGrids(amg_data) = 0;
+   hypre_BoomerAMGSetPlotFileName (amg_data, plot_file_name);
+                                                                                                       
+   /* BM Oct 17, 2006 */
+   hypre_ParAMGDataCoordDim(amg_data) = 0;
+   hypre_ParAMGDataCoordinates(amg_data) = NULL;
+
    return (void *) amg_data;
 }
 
@@ -803,7 +818,9 @@ hypre_BoomerAMGSetInterpType( void     *data,
       return hypre_error_flag;
    } 
 
-   if (interp_type < 0 || interp_type > 13)
+
+   if (interp_type < 0 || interp_type > 25)
+
    {
       hypre_error_in_arg(2);
       return hypre_error_flag;
@@ -1152,7 +1169,7 @@ hypre_BoomerAMGSetCycleNumSweeps( void     *data,
       return hypre_error_flag;
    } 
 
-   if (num_sweeps < 1)
+   if (num_sweeps < 0)
    {
       hypre_error_in_arg(2);
       return hypre_error_flag;
@@ -2059,6 +2076,78 @@ hypre_BoomerAMGSetNumSamples( void *data,
    return hypre_error_flag;
 }
 
+/* BM Aug 25, 2006 */
+
+int
+hypre_BoomerAMGSetCGCIts( void *data,
+                          int  its)
+{
+  int ierr = 0;
+  hypre_ParAMGData *amg_data = data;
+
+  hypre_ParAMGDataCGCIts(amg_data) = its;
+  return (ierr);
+}
+
+/* BM Oct 22, 2006 */
+int
+hypre_BoomerAMGSetPlotGrids( void *data,
+                          int plotgrids)
+{
+  int ierr = 0;
+  hypre_ParAMGData *amg_data = data;
+
+  hypre_ParAMGDataPlotGrids(amg_data) = plotgrids;
+  return (ierr);
+}
+
+int
+hypre_BoomerAMGSetPlotFileName( void       *data,
+                              const char *plot_file_name )
+{
+   hypre_ParAMGData  *amg_data = data;
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   }
+   if( strlen(plot_file_name)>251 )
+   {
+      hypre_error_in_arg(2);
+      return hypre_error_flag;
+   }
+   if (strlen(plot_file_name)==0 )
+     sprintf(hypre_ParAMGDataPlotFileName(amg_data), "%s", "AMGgrids.CF.dat");
+   else
+     sprintf(hypre_ParAMGDataPlotFileName(amg_data), "%s", plot_file_name);
+
+   return hypre_error_flag;
+}
+
+/* BM Oct 17, 2006 */
+int
+hypre_BoomerAMGSetCoordDim( void *data,
+                          int coorddim)
+{
+  int ierr = 0;
+  hypre_ParAMGData *amg_data = data;
+
+  hypre_ParAMGDataCoordDim(amg_data) = coorddim;
+  return (ierr);
+}
+
+int
+hypre_BoomerAMGSetCoordinates( void *data,
+                             float *coordinates)
+{
+  int ierr = 0;
+  hypre_ParAMGData *amg_data = data;
+
+  hypre_ParAMGDataCoordinates(amg_data) = coordinates;
+  return (ierr);
+}
+
 /*--------------------------------------------------------------------------
  * Routines to set the problem data parameters
  *--------------------------------------------------------------------------*/
@@ -2122,7 +2211,26 @@ hypre_BoomerAMGSetNodal( void     *data,
 
    return hypre_error_flag;
 }
+/*--------------------------------------------------------------------------
+ * Indicate how to treat diag for primary matrix with  nodal systems function
+ *--------------------------------------------------------------------------*/
 
+int
+hypre_BoomerAMGSetNodalDiag( void     *data,
+                          int    nodal )
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataNodalDiag(amg_data) = nodal;
+
+   return hypre_error_flag;
+}
 /*--------------------------------------------------------------------------
  * Indicate the degree of aggressive coarsening
  *--------------------------------------------------------------------------*/
@@ -2222,6 +2330,27 @@ hypre_BoomerAMGSetCRRate( void     *data,
    return hypre_error_flag;
 }
 
+/*--------------------------------------------------------------------------
+ * Indicates the desired convergence rate for Compatible relaxation
+ *--------------------------------------------------------------------------*/
+
+int
+hypre_BoomerAMGSetCRStrongTh( void     *data,
+                          double    CR_strong_th )
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataCRStrongTh(amg_data) = CR_strong_th;
+
+   return hypre_error_flag;
+}
+
 /*--------------------------------------------------------------------------
  * Indicates which independent set algorithm is used for CR
  *--------------------------------------------------------------------------*/
@@ -2298,11 +2427,6 @@ hypre_BoomerAMGSetDofFunc( void     *data,
       hypre_error_in_arg(1);
       return hypre_error_flag;
    } 
-   if (!dof_func)
-   {
-      hypre_error_in_arg(2);
-      return hypre_error_flag;
-   } 
    hypre_TFree(hypre_ParAMGDataDofFunc(amg_data));
    hypre_ParAMGDataDofFunc(amg_data) = dof_func;
 
@@ -2564,6 +2688,23 @@ hypre_BoomerAMGGetSchwarzRlxWeight( void     *data,
    return hypre_error_flag;
 }
 
+int
+hypre_BoomerAMGSetSchwarzUseNonSymm( void     *data,
+                                     int use_nonsymm)
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataSchwarzUseNonSymm(amg_data) = use_nonsymm;
+
+   return hypre_error_flag;
+}
+
 int
 hypre_BoomerAMGSetSym( void     *data,
                             int       sym)
@@ -2688,3 +2829,54 @@ hypre_BoomerAMGSetEuclidFile( void     *data,
    return hypre_error_flag;
 }
 
+int
+hypre_BoomerAMGSetEuLevel( void     *data,
+                            int      eu_level)
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataEuLevel(amg_data) = eu_level;
+
+   return hypre_error_flag;
+}
+
+int
+hypre_BoomerAMGSetEuSparseA( void     *data,
+                             double    eu_sparse_A)
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataEuSparseA(amg_data) = eu_sparse_A;
+
+   return hypre_error_flag;
+}
+
+int
+hypre_BoomerAMGSetEuBJ( void     *data,
+                        int       eu_bj)
+{
+   hypre_ParAMGData  *amg_data = data;
+ 
+   if (!amg_data)
+   {
+      printf("Warning! BoomerAMG object empty!\n");
+      hypre_error_in_arg(1);
+      return hypre_error_flag;
+   } 
+   hypre_ParAMGDataEuBJ(amg_data) = eu_bj;
+
+   return hypre_error_flag;
+}
+
