@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.28 $
+ * $Revision: 2.35 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 #ifndef hypre_ParAMG_DATA_HEADER
 #define hypre_ParAMG_DATA_HEADER
 
@@ -50,6 +37,7 @@ typedef struct
    double   jacobi_trunc_threshold;
    double   S_commpkg_switch;
    double   CR_rate;
+   double   CR_strong_th;
    int      measure_type;
    int      setup_type;
    int      coarsen_type;
@@ -62,6 +50,7 @@ typedef struct
    int      num_CR_relax_steps;
    int      IS_type;
    int      CR_use_CG;
+   int      cgc_its;
 
    /* solve params */
    int      max_iter;
@@ -81,6 +70,7 @@ typedef struct
    int      num_variables;
    int      num_functions;
    int      nodal;
+   int      nodal_diag;
    int      num_points;
    int     *dof_func;
    int     *dof_point;           
@@ -112,16 +102,20 @@ typedef struct
    int                  smooth_type;
    HYPRE_Solver        *smoother;
    int			smooth_num_sweeps;
-   int                  variant;
-   int                  overlap;
-   int                  domain_type;
+   int                  schw_variant;
+   int                  schw_overlap;
+   int                  schw_domain_type;
    double		schwarz_rlx_weight;
-   int			sym;
-   int			level;
-   int			max_nz_per_row;
-   double		threshold;
-   double		filter;
-   double		drop_tol;
+   int                  schwarz_use_nonsymm;
+   int			ps_sym;
+   int			ps_level;
+   int			pi_max_nz_per_row;
+   int			eu_level;
+   int			eu_bj;
+   double		ps_threshold;
+   double		ps_filter;
+   double		pi_drop_tol;
+   double		eu_sparse_A;
    char		       *euclidfile;
 
    /* data generated in the solve phase */
@@ -151,6 +145,14 @@ typedef struct
    char     log_file_name[256];
    int      debug_flag;
 
+   /* whether to print the constructed coarse grids BM Oct 22, 2006 */
+   int      plot_grids;
+   char     plot_filename[251];
+
+   /* coordinate data BM Oct 17, 2006 */
+   int      coorddim;
+   float    *coordinates;
+
 } hypre_ParAMGData;
 
 /*--------------------------------------------------------------------------
@@ -177,9 +179,11 @@ typedef struct
 #define hypre_ParAMGDataPostInterpType(amg_data) ((amg_data)->post_interp_type)
 #define hypre_ParAMGDataNumCRRelaxSteps(amg_data) ((amg_data)->num_CR_relax_steps)
 #define hypre_ParAMGDataCRRate(amg_data) ((amg_data)->CR_rate)
+#define hypre_ParAMGDataCRStrongTh(amg_data) ((amg_data)->CR_strong_th)
 #define hypre_ParAMGDataISType(amg_data) ((amg_data)->IS_type)
 #define hypre_ParAMGDataCRUseCG(amg_data) ((amg_data)->CR_use_CG)
 #define hypre_ParAMGDataL1Norms(amg_data) ((amg_data)->l1_norms)
+ #define hypre_ParAMGDataCGCIts(amg_data) ((amg_data)->cgc_its)
 
 /* solve params */
 
@@ -200,6 +204,7 @@ typedef struct
 #define  hypre_ParAMGDataNumVariables(amg_data)  ((amg_data)->num_variables)
 #define hypre_ParAMGDataNumFunctions(amg_data) ((amg_data)->num_functions)
 #define hypre_ParAMGDataNodal(amg_data) ((amg_data)->nodal)
+#define hypre_ParAMGDataNodalDiag(amg_data) ((amg_data)->nodal_diag)
 #define hypre_ParAMGDataNumPoints(amg_data) ((amg_data)->num_points)
 #define hypre_ParAMGDataDofFunc(amg_data) ((amg_data)->dof_func)
 #define hypre_ParAMGDataDofPoint(amg_data) ((amg_data)->dof_point)
@@ -223,18 +228,23 @@ typedef struct
 #define hypre_ParAMGDataSmoothNumSweeps(amg_data) \
 ((amg_data)->smooth_num_sweeps)	
 #define hypre_ParAMGDataSmoother(amg_data) ((amg_data)->smoother)	
-#define hypre_ParAMGDataVariant(amg_data) ((amg_data)->variant)	
-#define hypre_ParAMGDataOverlap(amg_data) ((amg_data)->overlap)	
-#define hypre_ParAMGDataDomainType(amg_data) ((amg_data)->domain_type)	
+#define hypre_ParAMGDataVariant(amg_data) ((amg_data)->schw_variant)	
+#define hypre_ParAMGDataOverlap(amg_data) ((amg_data)->schw_overlap)	
+#define hypre_ParAMGDataDomainType(amg_data) ((amg_data)->schw_domain_type)	
 #define hypre_ParAMGDataSchwarzRlxWeight(amg_data) \
 ((amg_data)->schwarz_rlx_weight)
-#define hypre_ParAMGDataSym(amg_data) ((amg_data)->sym)	
-#define hypre_ParAMGDataLevel(amg_data) ((amg_data)->level)	
-#define hypre_ParAMGDataMaxNzPerRow(amg_data) ((amg_data)->max_nz_per_row)
-#define hypre_ParAMGDataThreshold(amg_data) ((amg_data)->threshold)	
-#define hypre_ParAMGDataFilter(amg_data) ((amg_data)->filter)	
-#define hypre_ParAMGDataDropTol(amg_data) ((amg_data)->drop_tol)	
+#define hypre_ParAMGDataSchwarzUseNonSymm(amg_data) \
+((amg_data)->schwarz_use_nonsymm)
+#define hypre_ParAMGDataSym(amg_data) ((amg_data)->ps_sym)	
+#define hypre_ParAMGDataLevel(amg_data) ((amg_data)->ps_level)	
+#define hypre_ParAMGDataMaxNzPerRow(amg_data) ((amg_data)->pi_max_nz_per_row)
+#define hypre_ParAMGDataThreshold(amg_data) ((amg_data)->ps_threshold)	
+#define hypre_ParAMGDataFilter(amg_data) ((amg_data)->ps_filter)	
+#define hypre_ParAMGDataDropTol(amg_data) ((amg_data)->pi_drop_tol)	
 #define hypre_ParAMGDataEuclidFile(amg_data) ((amg_data)->euclidfile)	
+#define hypre_ParAMGDataEuLevel(amg_data) ((amg_data)->eu_level)	
+#define hypre_ParAMGDataEuSparseA(amg_data) ((amg_data)->eu_sparse_A)
+#define hypre_ParAMGDataEuBJ(amg_data) ((amg_data)->eu_bj)
 
 /* block */
 #define hypre_ParAMGDataABlockArray(amg_data) ((amg_data)->A_block_array)
@@ -271,6 +281,14 @@ typedef struct
 #define hypre_ParAMGDataLogFileName(amg_data) ((amg_data)->log_file_name)
 #define hypre_ParAMGDataDebugFlag(amg_data)   ((amg_data)->debug_flag)
 
+/* BM Oct 22, 2006 */
+#define hypre_ParAMGDataPlotGrids(amg_data) ((amg_data)->plot_grids)
+#define hypre_ParAMGDataPlotFileName(amg_data) ((amg_data)->plot_filename)
+
+/* coordinates BM Oct 17, 2006 */
+#define hypre_ParAMGDataCoordDim(amg_data) ((amg_data)->coorddim)
+#define hypre_ParAMGDataCoordinates(amg_data) ((amg_data)->coordinates)
+
 #endif
 
 
