@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.12 $
+ * $Revision: 2.16 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *****************************************************************************/
@@ -57,10 +44,11 @@
 
 int
 hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
-                       int                    num_functions,
-                       int                   *dof_func,
-                       int                    option,
-                       hypre_ParCSRMatrix   **AN_ptr)
+                            int                    num_functions,
+                            int                   *dof_func,
+                            int                    option,
+                            int                    diag_option,     
+                            hypre_ParCSRMatrix   **AN_ptr)
 {
    MPI_Comm 	       comm            = hypre_ParCSRMatrixComm(A);
    hypre_CSRMatrix    *A_diag          = hypre_ParCSRMatrixDiag(A);
@@ -132,6 +120,10 @@ hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
    int		      *map_to_map;
    int		      *counter;
 
+   double sum;
+   double *data;
+   
+
    MPI_Comm_size(comm,&num_procs);
 
    if (!comm_pkg)
@@ -227,48 +219,6 @@ hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
 
    switch (mode)
    {
-      case 7:  /* frobenius norm with signs*/
-      {
-         for (i=0; i < num_nodes; i++)
-         {
-            for (j=0; j < num_functions; j++)
-            {
-	       for (k=A_diag_i[row]; k < A_diag_i[row+1]; k++)
-	       {
-	          k_map = map_to_node[A_diag_j[k]];
-	          if (counter[k_map] < start_index)
-	          {
-	             counter[k_map] = index;
-	             AN_diag_j[index] = k_map;
-	             AN_diag_data[index] = A_diag_data[k]*A_diag_data[k];
-	             index++;
-	          }
-	          else
-	          {
-	             AN_diag_data[counter[k_map]] += 
-				A_diag_data[k]*A_diag_data[k];
-	          }
-	       }
-	       row++;
-            }
-            start_index = index;
-         }
-         for (i=0; i < AN_num_nonzeros_diag; i++)
-            AN_diag_data[i] = sqrt(AN_diag_data[i]);
-
-         /* temp for testing - make all diagonal entries negative */
-         /* the diagonal is the first element listed in each row -
-            this is the same as serial code */
-
-         for (i=0; i < num_nodes; i++)
-         {
-            index = AN_diag_i[i];
-            AN_diag_data[index] = - AN_diag_data[index];
-         }
-
-      }
-      break;
-      
       case 1:  /* frobenius norm */
       {
          for (i=0; i < num_nodes; i++)
@@ -298,18 +248,6 @@ hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
          for (i=0; i < AN_num_nonzeros_diag; i++)
             AN_diag_data[i] = sqrt(AN_diag_data[i]);
 
-#if 0
-         /* temp for testing - make all diagonal entries negative */
-         /* the diagonal is the first element listed in each row -
-            this is the same as serial code */
-
-         for (i=0; i < num_nodes; i++)
-         {
-            index = AN_diag_i[i];
-            AN_diag_data[index] = - AN_diag_data[index];
-         }
-#endif         
-
       }
       break;
       
@@ -373,8 +311,113 @@ hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
          }
       }
       break;
+
+      case 4:  /* inf. norm (row-sum)  */
+      {
+
+         data = hypre_CTAlloc(double, AN_num_nonzeros_diag*num_functions);
+
+         for (i=0; i < num_nodes; i++)
+         {
+            for (j=0; j < num_functions; j++)
+            {
+	       for (k=A_diag_i[row]; k < A_diag_i[row+1]; k++)
+	       {
+	          k_map = map_to_node[A_diag_j[k]];
+	          if (counter[k_map] < start_index)
+	          {
+	             counter[k_map] = index;
+	             AN_diag_j[index] = k_map;
+	             data[index*num_functions + j] = fabs(A_diag_data[k]);
+	             index++;
+	          }
+	          else
+	          {
+	             data[(counter[k_map])*num_functions + j] += fabs(A_diag_data[k]);
+	          }
+	       }
+	       row++;
+            }
+            start_index = index;
+         }
+         for (i=0; i < AN_num_nonzeros_diag; i++)
+         {
+            AN_diag_data[i]  = data[i*num_functions];
+            
+            for (j=1; j< num_functions; j++)
+            {
+               AN_diag_data[i]  = hypre_max( AN_diag_data[i],data[i*num_functions+j]);
+            }
+         }
+         hypre_TFree(data);
+      
+      }
+      break;
+
+      case 6:  /* sum of all elements in each block */
+      {
+         for (i=0; i < num_nodes; i++)
+         {
+            for (j=0; j < num_functions; j++)
+            {
+	       for (k=A_diag_i[row]; k < A_diag_i[row+1]; k++)
+	       {
+	          k_map = map_to_node[A_diag_j[k]];
+	          if (counter[k_map] < start_index)
+	          {
+	             counter[k_map] = index;
+	             AN_diag_j[index] = k_map;
+	             AN_diag_data[index] = (A_diag_data[k]);
+	             index++;
+	          }
+	          else
+	          {
+	             AN_diag_data[counter[k_map]] += (A_diag_data[k]);
+	          }
+	       }
+	       row++;
+            }
+            start_index = index;
+         }
+      }
+      break;
+
    }
 
+   if (diag_option ==1 )
+   {
+      /* make the diag entry the negative of the sum of off-diag entries (DO MORE BELOW) */
+      for (i=0; i < num_nodes; i++)
+      {
+         index = AN_diag_i[i]; 
+         sum = 0.0;
+         for (k = AN_diag_i[i]+1; k < AN_diag_i[i+1]; k++)
+         {
+            sum += AN_diag_data[k];
+            
+         }
+         AN_diag_data[index] = -sum;
+      }
+      
+   }
+   else if (diag_option == 2)
+   {
+      
+      /*  make all diagonal entries negative */
+      /* the diagonal is the first element listed in each row - */
+      
+      for (i=0; i < num_nodes; i++)
+      {
+         index = AN_diag_i[i];
+         AN_diag_data[index] = - AN_diag_data[index];
+      }
+   }
+
+
+
+
+
+
    num_nonzeros_offd = A_offd_i[num_variables];
    AN_offd_i = hypre_CTAlloc(int, num_nodes+1);
 
@@ -609,10 +652,101 @@ hypre_BoomerAMGCreateNodalA(hypre_ParCSRMatrix    *A,
             }
          }
          break;
+         
+         case 4:  /* inf. norm (row-sum)  */
+         {
+            
+            data = hypre_CTAlloc(double, AN_num_nonzeros_offd*num_functions);
+            
+            for (i=0; i < num_nodes; i++)
+            {
+               for (j=0; j < num_functions; j++)
+               {
+                  for (k=A_offd_i[row]; k < A_offd_i[row+1]; k++)
+                  {
+                     k_map = map_to_map[A_offd_j[k]];
+                     if (counter[k_map] < start_index)
+                     {
+                        counter[k_map] = index;
+                        AN_offd_j[index] = k_map;
+                        data[index*num_functions + j] = fabs(A_offd_data[k]);
+                        index++;
+                     }
+                     else
+                     {
+                        data[(counter[k_map])*num_functions + j] += fabs(A_offd_data[k]);
+                     }
+                  }
+                  row++;
+               }
+               start_index = index;
+            }
+            for (i=0; i < AN_num_nonzeros_offd; i++)
+            {
+               AN_offd_data[i]  = data[i*num_functions];
+               
+               for (j=1; j< num_functions; j++)
+               {
+                  AN_offd_data[i]  = hypre_max( AN_offd_data[i],data[i*num_functions+j]);
+               }
+            }
+            hypre_TFree(data);
+            
+         }
+         break;
+         
+         case 6:  /* sum of value of all elements in block */
+         {
+            for (i=0; i < num_nodes; i++)
+            {
+               for (j=0; j < num_functions; j++)
+               {
+                  for (k=A_offd_i[row]; k < A_offd_i[row+1]; k++)
+                  {
+                     k_map = map_to_map[A_offd_j[k]];
+                     if (counter[k_map] < start_index)
+                     {
+                        counter[k_map] = index;
+                        AN_offd_j[index] = k_map;
+                        AN_offd_data[index] = (A_offd_data[k]);
+                        index++;
+                     }
+                     else
+                     {
+                        AN_offd_data[counter[k_map]] += (A_offd_data[k]);
+                     }
+                  }
+                  row++;
+               }
+               start_index = index;
+            }
+            
+         }
+         break;
       }
+   
       hypre_TFree(map_to_map);
    }
-   
+
+   if (diag_option ==1 )
+   {
+      /* make the diag entry the negative of the sum of off-diag entries (here we are adding the 
+         off_diag contribution)*/
+      /* the diagonal is the first element listed in each row of AN_diag_data - */
+      for (i=0; i < num_nodes; i++)
+      {
+         sum = 0.0;
+         for (k = AN_offd_i[i]; k < AN_offd_i[i+1]; k++)
+         {
+            sum += AN_offd_data[k];
+            
+         }
+         index = AN_diag_i[i];/* location of diag entry in data */ 
+         AN_diag_data[index] -= sum; /* subtract from current value */
+      }
+      
+   }
+
     
    AN = hypre_ParCSRMatrixCreate(comm, global_num_nodes, global_num_nodes,
 		row_starts_AN, row_starts_AN, num_cols_offd_AN,
