@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.20 $
+ * $Revision: 2.28 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 #include "headers.h"
 #include "par_amg.h"
 
@@ -34,6 +21,9 @@
  *
  * Routine for getting matrix statistics from setup
  *
+ *
+ * AHB - using block norm 6 (sum of all elements) instead of 1 (frobenius)
+ *
  *****************************************************************************/
 
 
@@ -259,6 +249,14 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
       {
 	printf(" Coarsening Type = CLJP, fixed random \n");
       }
+      else if (abs(coarsen_type) == 21) /* BM Aug 29, 2006 */
+      {
+        printf(" Coarsening Type = CGC \n");
+      }
+      else if (abs(coarsen_type) == 22) /* BM Aug 29, 2006 */
+      {
+        printf(" Coarsening Type = CGC-E \n");
+      }
       /*if (coarsen_type > 0) 
       {
 	printf(" Hybrid Coarsening (switch to CLJP when coarsening slows)\n");
@@ -335,10 +333,18 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
 	printf(" Interpolation = block classical interpolation with diagonal blocks\n");
 	printf("                 for nodal systems AMG\n");
       }
+      else if (interp_type == 24) 
+      {
+	printf(" Interpolation = block direct interpolation \n");
+	printf("                 for nodal systems AMG\n");
+      }
+
+
 
       if (block_mode)
       {
-         printf( "\nBlock Operator Matrix Information:\n\n");
+         printf( "\nBlock Operator Matrix Information:\n");
+           printf( "(Row sums and weights use sum of all elements in the block -keeping signs)\n\n");
       }
       else 
       {
@@ -397,13 +403,13 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
             min_entries = (A_diag_i[1]-A_diag_i[0])+(A_offd_i[1]-A_offd_i[0]);
             for (j = A_diag_i[0]; j < A_diag_i[1]; j++)
             {
-               hypre_CSRBlockMatrixBlockNorm(1, &A_diag_data[j*bnnz], &tmp_norm, block_size);
+               hypre_CSRBlockMatrixBlockNorm(6, &A_diag_data[j*bnnz], &tmp_norm, block_size);
                min_rowsum += tmp_norm;
             }
             
             for (j = A_offd_i[0]; j < A_offd_i[1]; j++)
             {
-               hypre_CSRBlockMatrixBlockNorm(1, &A_offd_data[j*bnnz], &tmp_norm, block_size);
+               hypre_CSRBlockMatrixBlockNorm(6, &A_offd_data[j*bnnz], &tmp_norm, block_size);
                min_rowsum += tmp_norm;
             }
             
@@ -418,12 +424,12 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
                rowsum = 0.0;
                for (i = A_diag_i[j]; i < A_diag_i[j+1]; i++)
                {
-                  hypre_CSRBlockMatrixBlockNorm(1, &A_diag_data[i*bnnz], &tmp_norm, block_size);
+                  hypre_CSRBlockMatrixBlockNorm(6, &A_diag_data[i*bnnz], &tmp_norm, block_size);
                   rowsum += tmp_norm;
                }
                for (i = A_offd_i[j]; i < A_offd_i[j+1]; i++)
                {
-                  hypre_CSRBlockMatrixBlockNorm(1, &A_offd_data[i*bnnz], &tmp_norm, block_size);
+                  hypre_CSRBlockMatrixBlockNorm(6, &A_offd_data[i*bnnz], &tmp_norm, block_size);
                   rowsum += tmp_norm;
                }
                min_rowsum = hypre_min(rowsum, min_rowsum);
@@ -562,10 +568,12 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
       if (block_mode)
       {
          printf( "\n\nBlock Interpolation Matrix Information:\n\n");
+         printf( "(Row sums and weights use sum of all elements in the block - keeping signs)\n\n");
       }
       else 
       {
-         printf( "\n\nInterpolation Matrix Information:\n\n");
+         printf( "\n\nInterpolation Matrix Information:\n");
+        
       }
       
       printf("                 entries/row    min     max");
@@ -611,14 +619,14 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
          {
             if (hypre_CSRBlockMatrixNumCols(P_block_diag)) 
             {
-               hypre_CSRBlockMatrixBlockNorm(1, &P_diag_data[0], &tmp_norm, block_size);
+               hypre_CSRBlockMatrixBlockNorm(6, &P_diag_data[0], &tmp_norm, block_size);
                min_weight = tmp_norm;
             }
             
 
             for (j = P_diag_i[0]; j < P_diag_i[1]; j++)
             {
-               hypre_CSRBlockMatrixBlockNorm(1, &P_diag_data[j*bnnz], &tmp_norm, block_size);
+               hypre_CSRBlockMatrixBlockNorm(6, &P_diag_data[j*bnnz], &tmp_norm, block_size);
                min_weight = hypre_min(min_weight, tmp_norm);
 
                if (tmp_norm != 1.0)
@@ -630,7 +638,7 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
             }
             for (j = P_offd_i[0]; j < P_offd_i[1]; j++)
             {        
-               hypre_CSRBlockMatrixBlockNorm(1, &P_offd_data[j*bnnz], &tmp_norm, block_size);
+               hypre_CSRBlockMatrixBlockNorm(6, &P_offd_data[j*bnnz], &tmp_norm, block_size);
                min_weight = hypre_min(min_weight, tmp_norm); 
  
               if (tmp_norm != 1.0)
@@ -653,7 +661,7 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
                rowsum = 0.0;
                for (i = P_diag_i[j]; i < P_diag_i[j+1]; i++)
                {
-                  hypre_CSRBlockMatrixBlockNorm(1, &P_diag_data[i*bnnz], &tmp_norm, block_size);
+                  hypre_CSRBlockMatrixBlockNorm(6, &P_diag_data[i*bnnz], &tmp_norm, block_size);
                   min_weight = hypre_min(min_weight, tmp_norm);
 
                   if (tmp_norm != 1.0)
@@ -664,7 +672,7 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
                
                for (i = P_offd_i[j]; i < P_offd_i[j+1]; i++)
                {
-                  hypre_CSRBlockMatrixBlockNorm(1, &P_offd_data[i*bnnz], &tmp_norm, block_size);
+                  hypre_CSRBlockMatrixBlockNorm(6, &P_offd_data[i*bnnz], &tmp_norm, block_size);
                   min_weight = hypre_min(min_weight, tmp_norm);
 
                   if (tmp_norm != 1.0) 
@@ -867,7 +875,7 @@ hypre_BoomerAMGSetupStats( void               *amg_vdata,
       printf( "  Cycle type (1 = V, 2 = W, etc.):  %d\n\n", cycle_type);
       printf( "  Relaxation Parameters:\n");
       printf( "   Visiting Grid:                     down   up  coarse\n");
-      printf( "            Number of partial sweeps: %4d   %2d  %4d \n",
+      printf( "            Number of sweeps:         %4d   %2d  %4d \n",
               num_grid_sweeps[1],
               num_grid_sweeps[2],num_grid_sweeps[3]);
       printf( "   Type 0=Jac, 3=hGS, 6=hSGS, 9=GE:   %4d   %2d  %4d \n",
@@ -1006,8 +1014,7 @@ void    *data;
       printf( "  Cycle type (1 = V, 2 = W, etc.):  %d\n\n", cycle_type);
       printf( "  Relaxation Parameters:\n");
       printf( "   Visiting Grid:                     down   up  coarse\n");
-      printf( "   Visiting Grid:                     down   up  coarse\n");
-      printf( "            Number of partial sweeps: %4d   %2d  %4d \n",
+      printf( "            Number of sweeps:         %4d   %2d  %4d \n",
               num_grid_sweeps[1],
               num_grid_sweeps[2],num_grid_sweeps[3]);
       printf( "   Type 0=Jac, 3=hGS, 6=hSGS, 9=GE:   %4d   %2d  %4d \n",
