@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.5 $
+ * $Revision: 2.8 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_ParCSRMatrix interface
@@ -281,6 +268,12 @@ HYPRE_ParCSRMatrixRestoreRow( HYPRE_ParCSRMatrix  matrix,
 
 /*--------------------------------------------------------------------------
  * HYPRE_CSRMatrixToParCSRMatrix
+ * Output argument (fifth argument): a new ParCSRmatrix.
+ * Input arguments: MPI communicator, CSR matrix, and optional partitionings.
+ * If you don't have partitionings, just pass a null pointer for the third
+ * and fourth arguments and they will be computed.
+ * Note that it is not possible to provide a null pointer if this is called
+ * from Fortran code; so you must provide the paritionings from Fortran.
  *--------------------------------------------------------------------------*/
 
 int
@@ -298,6 +291,24 @@ HYPRE_CSRMatrixToParCSRMatrix( MPI_Comm comm,
    return hypre_error_flag;
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_CSRMatrixToParCSRMatrix_WithNewPartitioning
+ * Output argument (third argument): a new ParCSRmatrix.
+ * Input arguments: MPI communicator, CSR matrix.
+ * Row and column partitionings are computed for the output matrix.
+ *--------------------------------------------------------------------------*/
+
+int
+HYPRE_CSRMatrixToParCSRMatrix_WithNewPartitioning(
+   MPI_Comm comm, HYPRE_CSRMatrix A_CSR, HYPRE_ParCSRMatrix *matrix)
+{
+   *matrix = (HYPRE_ParCSRMatrix) hypre_CSRMatrixToParCSRMatrix(
+      comm, (hypre_CSRMatrix *) A_CSR, NULL, NULL ) ;
+   if (!matrix) 
+      hypre_error_in_arg(3);
+   return hypre_error_flag;
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_ParCSRMatrixMatvec
  *--------------------------------------------------------------------------*/
