@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.10 $
+ * $Revision: 2.13 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * Matvec functions for hypre_CSRMatrix class.
@@ -140,13 +127,13 @@ hypre_CSRMatrixMatvec( double           alpha,
     * y += A*x
     *-----------------------------------------------------------------*/
 
-#define HYPRE_SMP_PRIVATE i,jj
-#include "../utilities/hypre_smp_forloop.h"
-
 /* use rownnz pointer to do the A*x multiplication  when num_rownnz is smaller than num_rows */
 
    if (num_rownnz < xpar*(num_rows))
    {
+#define HYPRE_SMP_PRIVATE i,jj,m,tempx
+#include "../utilities/hypre_smp_forloop.h"
+
       for (i = 0; i < num_rownnz; i++)
       {
          m = A_rownnz[i];
@@ -177,6 +164,8 @@ hypre_CSRMatrixMatvec( double           alpha,
    }
    else
    {
+#define HYPRE_SMP_PRIVATE i,jj,temp
+#include "../utilities/hypre_smp_forloop.h"
       for (i = 0; i < num_rows; i++)
       {
          if ( num_vectors==1 )
