@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.7 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *  FAC composite level interpolation.
  *  Identity interpolation of values away from underlying refinement patches;
@@ -163,7 +150,7 @@ hypre_FacSemiInterpSetup2( void                 *fac_interp_vdata,
    int                    ***send_processes;
    int                    ***send_remote_boxnums;
 
-   hypre_BoxArrayArray     **recv_boxes;
+   hypre_BoxArrayArray     **recv_boxes, *recv_rboxes;
    int                    ***recv_processes;
    int                    ***recv_remote_boxnums;
 
@@ -216,8 +203,9 @@ hypre_FacSemiInterpSetup2( void                 *fac_interp_vdata,
       hypre_CommPkgCreate(comm_info,
                           hypre_StructVectorDataSpace(e_var),
                           hypre_StructVectorDataSpace(e_var),
-                          1,
-                          hypre_StructVectorComm(e_var), &gnodes_comm_pkg[vars]);
+                          1, NULL, 0, hypre_StructVectorComm(e_var),
+                          &gnodes_comm_pkg[vars]);
+      hypre_CommInfoDestroy(comm_info);
    }
 
   (fac_interp_data -> ndim)           = ndim;
@@ -399,8 +387,8 @@ hypre_FacSemiInterpSetup2( void                 *fac_interp_vdata,
             {
                hypre_AppendBox(&box,
                                 hypre_BoxArrayArrayBoxArray(ownboxes[vars], fi));
-               hypre_SStructMapEntryGetBox(map_entries[i],
-                                          &own_cboxnums[vars][fi][cnt1]);
+               hypre_SStructMapEntryGetBoxnum(map_entries[i],
+                                              &own_cboxnums[vars][fi][cnt1]);
                cnt1++;
             }
             else
@@ -586,8 +574,8 @@ hypre_FacSemiInterpSetup2( void                 *fac_interp_vdata,
                                  hypre_BoxArrayArrayBoxArray(send_boxes[vars], ci));
 
                 send_processes[vars][ci][cnt1]= proc;
-                hypre_SStructMapEntryGetBox(map_entries[i],
-                                           &send_remote_boxnums[vars][ci][cnt1]);
+                hypre_SStructMapEntryGetBoxnum(
+                   map_entries[i], &send_remote_boxnums[vars][ci][cnt1]);
                 cnt1++;
              }
           }
@@ -613,17 +601,20 @@ hypre_FacSemiInterpSetup2( void                 *fac_interp_vdata,
 
       s_cvector= hypre_SStructPVectorSVector(recv_cvectors, vars);
       send_rboxes= hypre_BoxArrayArrayDuplicate(send_boxes[vars]);
+      recv_rboxes= hypre_BoxArrayArrayDuplicate(recv_boxes[vars]);
 
-      hypre_CommInfoCreate(send_boxes[vars], recv_boxes[vars], send_processes[vars],
-                           recv_processes[vars], send_remote_boxnums[vars],
-                           recv_remote_boxnums[vars], send_rboxes, &comm_info);
+      hypre_CommInfoCreate(send_boxes[vars], recv_boxes[vars],
+                           send_processes[vars], recv_processes[vars],
+                           send_remote_boxnums[vars], recv_remote_boxnums[vars],
+                           send_rboxes, recv_rboxes, 1, &comm_info);
 
       hypre_CommPkgCreate(comm_info,
                           hypre_StructVectorDataSpace(s_rc),
                           hypre_StructVectorDataSpace(s_cvector),
-                          num_values,
+                          num_values, NULL, 0,
                           hypre_StructVectorComm(s_rc),
-                         &interlevel_comm[vars]);
+                          &interlevel_comm[vars]);
+      hypre_CommInfoDestroy(comm_info);
   }
   hypre_TFree(send_boxes);
   hypre_TFree(recv_boxes);
@@ -797,7 +788,7 @@ hypre_FAC_WeightedInterp2(void                  *fac_interp_vdata,
       xc_var= hypre_SStructPVectorSVector(xc, var);
       hypre_InitializeCommunication(comm_pkg[var],
                                     hypre_StructVectorData(xc_var),
-                                    hypre_StructVectorData(xc_var),
+                                    hypre_StructVectorData(xc_var), 0, 0,
                                    &comm_handle);
       hypre_FinalizeCommunication(comm_handle);
 
@@ -806,7 +797,7 @@ hypre_FAC_WeightedInterp2(void                  *fac_interp_vdata,
          recv_var= hypre_SStructPVectorSVector(recv_cvectors, var);
          hypre_InitializeCommunication(interlevel_comm[var],
                                        hypre_StructVectorData(xc_var),
-                                       hypre_StructVectorData(recv_var),
+                                       hypre_StructVectorData(recv_var), 0, 0,
                                       &comm_handle);
          hypre_FinalizeCommunication(comm_handle);
       }
