@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.6 $
+ * $Revision: 2.9 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *  FAC composite level restriction.
  *  Injection away from the refinement patches; constant restriction
@@ -140,7 +127,7 @@ hypre_FacSemiRestrictSetup2( void                 *fac_restrict_vdata,
    int                      ***send_processes;
    int                      ***send_remote_boxnums;
 
-   hypre_BoxArrayArray       **recv_boxes;
+   hypre_BoxArrayArray       **recv_boxes, *recv_rboxes;
    int                      ***recv_processes;
    int                      ***recv_remote_boxnums;
 
@@ -353,8 +340,8 @@ hypre_FacSemiRestrictSetup2( void                 *fac_restrict_vdata,
                                 hypre_BoxArrayArrayBoxArray(send_boxes[vars], fi));
 
                send_processes[vars][fi][cnt1]= proc;
-               hypre_SStructMapEntryGetBox(map_entries[i],
-                                           &send_remote_boxnums[vars][fi][cnt1]);
+               hypre_SStructMapEntryGetBoxnum(map_entries[i],
+                                              &send_remote_boxnums[vars][fi][cnt1]);
                cnt1++;
             }
            
@@ -362,8 +349,8 @@ hypre_FacSemiRestrictSetup2( void                 *fac_restrict_vdata,
             {
                hypre_AppendBox(&box,
                                 hypre_BoxArrayArrayBoxArray(fullwgt_ownboxes[vars], fi));
-               hypre_SStructMapEntryGetBox(map_entries[i],
-                                          &own_cboxnums[vars][fi][cnt2]);
+               hypre_SStructMapEntryGetBoxnum(map_entries[i],
+                                              &own_cboxnums[vars][fi][cnt2]);
                cnt2++;
             }
          }
@@ -458,17 +445,20 @@ hypre_FacSemiRestrictSetup2( void                 *fac_restrict_vdata,
       s_rc     = hypre_SStructPVectorSVector(rc, vars);
       s_cvector= hypre_SStructPVectorSVector(fgrid_cvectors, vars);
       send_rboxes= hypre_BoxArrayArrayDuplicate(send_boxes[vars]);
+      recv_rboxes= hypre_BoxArrayArrayDuplicate(recv_boxes[vars]);
 
-      hypre_CommInfoCreate(send_boxes[vars], recv_boxes[vars], send_processes[vars],
-                           recv_processes[vars], send_remote_boxnums[vars],
-                           recv_remote_boxnums[vars], send_rboxes, &comm_info);
+      hypre_CommInfoCreate(send_boxes[vars], recv_boxes[vars],
+                           send_processes[vars], recv_processes[vars],
+                           send_remote_boxnums[vars], recv_remote_boxnums[vars],
+                           send_rboxes, recv_rboxes, 1, &comm_info);
 
       hypre_CommPkgCreate(comm_info,
                           hypre_StructVectorDataSpace(s_cvector),
                           hypre_StructVectorDataSpace(s_rc),
-                          num_values,
+                          num_values, NULL, 0,
                           hypre_StructVectorComm(s_rc),
-                         &interlevel_comm[vars]);
+                          &interlevel_comm[vars]);
+      hypre_CommInfoDestroy(comm_info);
   }
   hypre_TFree(send_boxes);
   hypre_TFree(recv_boxes);
@@ -819,8 +809,8 @@ hypre_FACRestrict2( void                 *  fac_restrict_vdata,
        xc_var= hypre_SStructPVectorSVector(xc, var);
        hypre_InitializeCommunication(interlevel_comm[var], 
                                      hypre_StructVectorData(xc_temp),
-                                     hypre_StructVectorData(xc_var), 
-                                    &comm_handle);
+                                     hypre_StructVectorData(xc_var), 0, 0,
+                                     &comm_handle);
 
        hypre_FinalizeCommunication(comm_handle);
    }
