@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.6 $
+ * $Revision: 2.9 $
  ***********************************************************************EHEADER*/
 
 
 
+
 #include "headers.h"
 #include "fac.h"
 
@@ -107,8 +94,10 @@ hypre_FacSetup2( void                 *fac_vdata,
    HYPRE_SStructSolver     crse_solver;
    HYPRE_SStructSolver     crse_precond;
    
-   int                     max_level      =  hypre_FACDataMaxLevels(fac_data);
-   int                     relax_type     =  fac_data -> relax_type;
+   int                     max_level        =  hypre_FACDataMaxLevels(fac_data);
+   int                     relax_type       =  fac_data -> relax_type;
+   int                     usr_jacobi_weight=  fac_data -> usr_jacobi_weight;
+   double                  jacobi_weight    =  fac_data -> jacobi_weight;
    int                    *levels;
    int                    *part_to_level;
 
@@ -895,6 +884,10 @@ hypre_FacSetup2( void                 *fac_vdata,
        relax_data_level[level]=  hypre_SysPFMGRelaxCreate(comm);
        hypre_SysPFMGRelaxSetTol(relax_data_level[level], 0.0);
        hypre_SysPFMGRelaxSetType(relax_data_level[level], relax_type);
+       if (usr_jacobi_weight)
+       {
+          hypre_SysPFMGRelaxSetJacobiWeight(relax_data_level[level], jacobi_weight);
+       }
        hypre_SysPFMGRelaxSetTempVec(relax_data_level[level], tx_level[level]);
        hypre_SysPFMGRelaxSetup(relax_data_level[level], 
                                hypre_SStructMatrixPMatrix(A_level[level], part_fine),
@@ -923,6 +916,10 @@ hypre_FacSetup2( void                 *fac_vdata,
        HYPRE_SStructSysPFMGSetZeroGuess(crse_precond);
        /* weighted Jacobi = 1; red-black GS = 2 */
        HYPRE_SStructSysPFMGSetRelaxType(crse_precond, 3);
+       if (usr_jacobi_weight)
+       {
+          HYPRE_SStructFACSetJacobiWeight(crse_precond, jacobi_weight);
+       }
        HYPRE_SStructSysPFMGSetNumPreRelax(crse_precond, 1);
        HYPRE_SStructSysPFMGSetNumPostRelax(crse_precond, 1);
        HYPRE_PCGSetPrecond((HYPRE_Solver) crse_solver,
@@ -946,6 +943,10 @@ hypre_FacSetup2( void                 *fac_vdata,
        HYPRE_SStructSysPFMGSetZeroGuess(crse_solver);
        /* weighted Jacobi = 1; red-black GS = 2 */
        HYPRE_SStructSysPFMGSetRelaxType(crse_solver, relax_type);
+       if (usr_jacobi_weight)
+       {
+          HYPRE_SStructFACSetJacobiWeight(crse_precond, jacobi_weight);
+       }
        HYPRE_SStructSysPFMGSetNumPreRelax(crse_solver, 1);
        HYPRE_SStructSysPFMGSetNumPostRelax(crse_solver, 1);
        HYPRE_SStructSysPFMGSetup(crse_solver, A_level[0], b_level[0], x_level[0]);
