@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.4 $
+ * $Revision: 2.7 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -49,20 +36,22 @@ hypre_SysPFMGCreate( MPI_Comm  comm )
    (sys_pfmg_data -> time_index) = hypre_InitializeTiming("SYS_PFMG");
 
    /* set defaults */
-   (sys_pfmg_data -> tol)            = 1.0e-06;
-   (sys_pfmg_data -> max_iter)       = 200;
-   (sys_pfmg_data -> rel_change)     = 0;
-   (sys_pfmg_data -> zero_guess)     = 0;
-   (sys_pfmg_data -> max_levels)     = 0;
-   (sys_pfmg_data -> dxyz)[0]        = 0.0;
-   (sys_pfmg_data -> dxyz)[1]        = 0.0;
-   (sys_pfmg_data -> dxyz)[2]        = 0.0;
-   (sys_pfmg_data -> relax_type)     = 1;       /* weighted Jacobi */
-   (sys_pfmg_data -> num_pre_relax)  = 1;
-   (sys_pfmg_data -> num_post_relax) = 1;
-   (sys_pfmg_data -> skip_relax)     = 1;
-   (sys_pfmg_data -> logging)        = 0;
-   (sys_pfmg_data -> print_level)    = 0;
+   (sys_pfmg_data -> tol)              = 1.0e-06;
+   (sys_pfmg_data -> max_iter  )       = 200;
+   (sys_pfmg_data -> rel_change)       = 0;
+   (sys_pfmg_data -> zero_guess)       = 0;
+   (sys_pfmg_data -> max_levels)       = 0;
+   (sys_pfmg_data -> dxyz)[0]          = 0.0;
+   (sys_pfmg_data -> dxyz)[1]          = 0.0;
+   (sys_pfmg_data -> dxyz)[2]          = 0.0;
+   (sys_pfmg_data -> relax_type)       = 1;       /* weighted Jacobi */
+   (sys_pfmg_data -> jacobi_weight)    = 0.0;
+   (sys_pfmg_data -> usr_jacobi_weight)= 0;
+   (sys_pfmg_data -> num_pre_relax)    = 1;
+   (sys_pfmg_data -> num_post_relax)   = 1;
+   (sys_pfmg_data -> skip_relax)       = 1;
+   (sys_pfmg_data -> logging)          = 0;
+   (sys_pfmg_data -> print_level)      = 0;
 
    /* initialize */
    (sys_pfmg_data -> num_levels) = -1;
@@ -222,6 +211,21 @@ hypre_SysPFMGSetRelaxType( void *sys_pfmg_vdata,
    return ierr;
 }
 
+/*--------------------------------------------------------------------------
+ * hypre_SysPFMGSetJacobiWeight
+ *--------------------------------------------------------------------------*/
+int
+hypre_SysPFMGSetJacobiWeight( void  *sys_pfmg_vdata,
+                              double weight )
+{
+   hypre_SysPFMGData *sys_pfmg_data = sys_pfmg_vdata;
+                                                                                                                                     
+   (sys_pfmg_data -> jacobi_weight)    = weight;
+   (sys_pfmg_data -> usr_jacobi_weight)= 1;
+
+   return hypre_error_flag;
+}
+
 /*--------------------------------------------------------------------------
  * hypre_SysPFMGSetNumPreRelax
  *--------------------------------------------------------------------------*/
