@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.3 $
+ * $Revision: 2.7 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -41,6 +28,7 @@ typedef struct
 {
    void                   *relax_data;
    int                     relax_type;
+   double                  jacobi_weight;
 
 } hypre_SysPFMGRelaxData;
 
@@ -108,8 +96,17 @@ hypre_SysPFMGRelaxSetup( void                 *sys_pfmg_relax_vdata,
                          hypre_SStructPVector *x                )
 {
    hypre_SysPFMGRelaxData *sys_pfmg_relax_data = sys_pfmg_relax_vdata;
-   int                     ierr = 0;
+   void                   *relax_data       = (sys_pfmg_relax_data -> relax_data);
+   int                     relax_type       = (sys_pfmg_relax_data -> relax_type);
+   double                  jacobi_weight    = (sys_pfmg_relax_data -> jacobi_weight);
 
+   int                     ierr = 0;
+  
+   if (relax_type == 1)
+   {
+      hypre_NodeRelaxSetWeight(relax_data, jacobi_weight);
+   }
+                                                                                                                                     
    ierr = hypre_NodeRelaxSetup((sys_pfmg_relax_data -> relax_data), A, b, x);
 
    return ierr;
@@ -129,17 +126,14 @@ hypre_SysPFMGRelaxSetType( void  *sys_pfmg_relax_vdata,
 
    (sys_pfmg_relax_data -> relax_type) = relax_type;
 
-   hypre_NodeRelaxSetWeight(relax_data, 1.0);
    switch(relax_type)
    {
-      case 1: /* Weighted Jacobi (weight = 2/3) */
-      hypre_NodeRelaxSetWeight(relax_data, 0.666666);
-
       case 0: /* Jacobi */
       {
          hypre_Index  stride;
          hypre_Index  indices[1];
 
+         hypre_NodeRelaxSetWeight(relax_data, 1.0);
          hypre_NodeRelaxSetNumNodesets(relax_data, 1);
 
          hypre_SetIndex(stride, 1, 1, 1);
@@ -177,6 +171,20 @@ hypre_SysPFMGRelaxSetType( void  *sys_pfmg_relax_vdata,
    return ierr;
 }
 
+/*--------------------------------------------------------------------------
+ * hypre_SysPFMGRelaxSetPreRelax
+ *--------------------------------------------------------------------------*/
+int
+hypre_SysPFMGRelaxSetJacobiWeight(void  *sys_pfmg_relax_vdata,
+                                  double weight)
+{
+   hypre_SysPFMGRelaxData *sys_pfmg_relax_data = sys_pfmg_relax_vdata;
+                                                                                                                                     
+  (sys_pfmg_relax_data -> jacobi_weight)    = weight;
+
+   return hypre_error_flag;
+}
+
 /*--------------------------------------------------------------------------
  * hypre_SysPFMGRelaxSetPreRelax
  *--------------------------------------------------------------------------*/
