@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.6 $
+ * $Revision: 2.11 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -73,6 +60,8 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
    hypre_SStructPVector *x;
 
    int                   relax_type = (sys_pfmg_data -> relax_type);
+   int                   usr_jacobi_weight= (sys_pfmg_data -> usr_jacobi_weight);
+   double                jacobi_weight    = (sys_pfmg_data -> jacobi_weight);
    int                   skip_relax = (sys_pfmg_data -> skip_relax);
    double               *dxyz       = (sys_pfmg_data -> dxyz);
                      
@@ -115,6 +104,11 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
 
    hypre_Box            *cbox;
 
+   double               *relax_weights;
+   double               *mean, *deviation;
+   double                alpha, beta;
+   int                   dxyz_flag;
+
    double                min_dxyz;
    int                   cdir;
    int                   d, l;
@@ -170,14 +164,36 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
    /* compute dxyz */
    if ((dxyz[0] == 0) || (dxyz[1] == 0) || (dxyz[2] == 0))
    {
+      mean= hypre_CTAlloc(double, 3);
+      deviation= hypre_CTAlloc(double, 3);
+      dxyz_flag= 0;
+
       for ( i = 0; i < nvars; i++)
       {
-         hypre_PFMGComputeDxyz(hypre_SStructPMatrixSMatrix(A,i,i), sys_dxyz[i]);
+         hypre_PFMGComputeDxyz(hypre_SStructPMatrixSMatrix(A,i,i), sys_dxyz[i],
+                               mean, deviation);
+
+         /* signal flag if any of the flag has a large (square) coeff. of variation */
+         if (!dxyz_flag)
+         {
+            for (d= 0; d< dim; d++)
+            {
+               deviation[d]-= mean[d]*mean[d];
+               if (deviation[d]/(mean[d]*mean[d]) > .1)  /* square of coeff. of variation */
+               {
+                  dxyz_flag= 1;
+                  break;
+               }
+            }
+         }
+
          for ( d = 0; d < 3; d++)
          {
             dxyz[d] += sys_dxyz[i][d];
          } 
       }
+      hypre_TFree(mean);
+      hypre_TFree(deviation);
    }
 
    grid_l = hypre_TAlloc(hypre_SStructPGrid *, max_levels);
@@ -186,12 +202,14 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
    P_grid_l[0] = NULL;
    cdir_l = hypre_TAlloc(int, max_levels);
    active_l = hypre_TAlloc(int, max_levels);
+   relax_weights= hypre_CTAlloc(double, max_levels);
    hypre_SetIndex(coarsen, 1, 1, 1); /* forces relaxation on finest grid */
    for (l = 0; ; l++)
    {
       /* determine cdir */
       min_dxyz = dxyz[0] + dxyz[1] + dxyz[2] + 1;
       cdir = -1;
+      alpha= 0.0;
       for (d = 0; d < dim; d++)
       {
          if ((hypre_BoxIMaxD(cbox, d) > hypre_BoxIMinD(cbox, d)) &&
@@ -200,6 +218,45 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
             min_dxyz = dxyz[d];
             cdir = d;
          }
+         alpha+= 1.0/(dxyz[d]*dxyz[d]);
+      }
+      relax_weights[l]= 2.0/3.0;
+
+      beta= 0.0;
+      if (cdir != -1)
+      {
+         if (dxyz_flag)
+         {
+            relax_weights[l]= 2.0/3.0;
+         }
+         else
+         {
+            for (d = 0; d < dim; d++)
+            {
+               if (d != cdir)
+               {
+                  beta+= 1.0/(dxyz[d]*dxyz[d]);
+               }
+            }
+            if (beta == alpha)
+            {
+               alpha= 0.0;
+            }
+            else
+            {
+               alpha= beta/alpha;
+            }
+
+            /* determine level Jacobi weights */
+            if (dim > 1)
+            {
+               relax_weights[l]= 2.0/(3.0 - alpha);
+            }
+            else
+            {
+               relax_weights[l]= 2.0/3.0; /* always 2/3 for 1-d */
+            }
+         }
       }
 
       /* if cannot coarsen in any direction, stop */
@@ -389,6 +446,14 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
    relax_data_l[0] = hypre_SysPFMGRelaxCreate(comm);
    hypre_SysPFMGRelaxSetTol(relax_data_l[0], 0.0);
    hypre_SysPFMGRelaxSetType(relax_data_l[0], relax_type);
+   if (usr_jacobi_weight)
+   {
+      hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[0], jacobi_weight);
+   }
+   else
+   {
+      hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[0], relax_weights[0]);
+   }
    hypre_SysPFMGRelaxSetTempVec(relax_data_l[0], tx_l[0]);
    hypre_SysPFMGRelaxSetup(relax_data_l[0], A_l[0], b_l[0], x_l[0]);
    if (num_levels > 1)
@@ -399,6 +464,14 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
          relax_data_l[l] = hypre_SysPFMGRelaxCreate(comm);
          hypre_SysPFMGRelaxSetTol(relax_data_l[l], 0.0);
          hypre_SysPFMGRelaxSetType(relax_data_l[l], relax_type);
+         if (usr_jacobi_weight)
+         {
+            hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[l], jacobi_weight);
+         }
+         else
+         {
+            hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[l], relax_weights[l]);
+         }
          hypre_SysPFMGRelaxSetTempVec(relax_data_l[l], tx_l[l]);
          hypre_SysPFMGRelaxSetup(relax_data_l[l], A_l[l], b_l[l], x_l[l]);
       }
@@ -407,9 +480,18 @@ hypre_SysPFMGSetup( void                 *sys_pfmg_vdata,
       hypre_SysPFMGRelaxSetTol(relax_data_l[l], 0.0);
       hypre_SysPFMGRelaxSetMaxIter(relax_data_l[l], 1);
       hypre_SysPFMGRelaxSetType(relax_data_l[l], 0);
+      if (usr_jacobi_weight)
+      {
+         hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[l], jacobi_weight);
+      }
+      else
+      {
+         hypre_SysPFMGRelaxSetJacobiWeight(relax_data_l[l], relax_weights[l]);
+      }
       hypre_SysPFMGRelaxSetTempVec(relax_data_l[l], tx_l[l]);
       hypre_SysPFMGRelaxSetup(relax_data_l[l], A_l[l], b_l[l], x_l[l]);
    }
+   hypre_TFree(relax_weights);
 
    for (l = 0; l < num_levels; l++)
    {
