@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.5 $
+ * $Revision: 2.9 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_SStructGrid interface
@@ -92,7 +79,7 @@ hypre_F90_IFACE(hypre_sstructgridsetvariables, HYPRE_SSTRUCTGRIDSETVARIABLES)
                                                           (long int   *grid,
                                                            int        *part,
                                                            int        *nvars,
-                                                           long int   *vartypes,
+                                                           int        *vartypes,
                                                            int        *ierr)
 {
    *ierr = (int) (HYPRE_SStructGridSetVariables( (HYPRE_SStructGrid)      *grid,
@@ -113,7 +100,7 @@ hypre_F90_IFACE(hypre_sstructgridsetvariable, HYPRE_SSTRUCTGRIDSETVARIABLE)
                                                            int        *part,
                                                            int        *var,
                                                            int        *nvars,
-                                                           long int   *vartype,
+                                                           int        *vartype,
                                                            int        *ierr)
 {
    *ierr = (int) (HYPRE_SStructGridSetVariable( (HYPRE_SStructGrid)      *grid,
@@ -133,7 +120,7 @@ hypre_F90_IFACE(hypre_sstructgridaddvariables, HYPRE_SSTRUCTGRIDADDVARIABLES)
                                                            int        *part,
                                                            int        *index,
                                                            int        *nvars,
-                                                           long int   *vartypes,
+                                                           int        *vartypes,
                                                            int        *ierr)
 {
    *ierr = (int) (HYPRE_SStructGridAddVariables( (HYPRE_SStructGrid)      *grid,
@@ -155,7 +142,7 @@ hypre_F90_IFACE(hypre_sstructgridaddvariable, HYPRE_SSTRUCTGRIDADDVARIABLE)
                                                            int        *part,
                                                            int        *index,
                                                            int        *var,
-                                                           long int   *vartype,
+                                                           int        *vartype,
                                                            int        *ierr)
 {
    *ierr = (int) (HYPRE_SStructGridAddVariable( (HYPRE_SStructGrid)      *grid,
@@ -191,35 +178,6 @@ hypre_F90_IFACE(hypre_sstructgridsetneighborbox, HYPRE_SSTRUCTGRIDSETNEIGHBORBOX
                                                    (int *)              index_map ) );
 }
 
-/*--------------------------------------------------------------------------
- * ** TEMPORARY **
- *  HYPRE_SStructGridSetNeighborBoxZ
- *--------------------------------------------------------------------------*/
-
-void
-hypre_F90_IFACE(hypre_sstructgridsetneighborboz, HYPRE_SSTRUCTGRIDSETNEIGHBORBOZ)
-                                                          (long int   *grid,
-                                                           int        *part,
-                                                           int        *ilower,
-                                                           int        *iupper,
-                                                           int        *nbor_part,
-                                                           int        *nbor_ilower,
-                                                           int        *nbor_iupper,
-                                                           int        *index_map,
-                                                           int        *primary,
-                                                           int        *ierr)
-{
-   *ierr = (int) (HYPRE_SStructGridSetNeighborBoxZ( (HYPRE_SStructGrid) *grid,
-                                                    (int)               *part,
-                                                    (int *)              ilower,
-                                                    (int *)              iupper,
-                                                    (int)               *nbor_part,
-                                                    (int *)              nbor_ilower,
-                                                    (int *)              nbor_iupper,
-                                                    (int *)              index_map,
-                                                    (int)               *primary ) );
-}
-
 /*--------------------------------------------------------------------------
  * *** placeholder ***
  *  HYPRE_SStructGridAddUnstructuredPart
