@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.14 $
+ * $Revision: 2.18 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_SStructGrid interface
@@ -43,8 +30,6 @@ HYPRE_SStructGridCreate( MPI_Comm           comm,
                          int                nparts,
                          HYPRE_SStructGrid *grid_ptr )
 {
-   int  ierr = 0;
-
    hypre_SStructGrid       *grid;
    hypre_SStructPGrid     **pgrids;
    hypre_SStructPGrid      *pgrid;
@@ -86,7 +71,7 @@ HYPRE_SStructGridCreate( MPI_Comm           comm,
 
    *grid_ptr = grid;
 
-   return ierr;
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -95,19 +80,19 @@ HYPRE_SStructGridCreate( MPI_Comm           comm,
 int
 HYPRE_SStructGridDestroy( HYPRE_SStructGrid grid )
 {
-   int ierr = 0;
-
    int                        nparts;
    hypre_SStructPGrid       **pgrids;
    int                       *nneighbors;
    hypre_SStructNeighbor    **neighbors;
    int                      **nvneighbors;
    hypre_SStructNeighbor   ***vneighbors;
+   hypre_SStructCommInfo    **vnbor_comm_info;
+   int                        vnbor_ncomms;
    hypre_BoxMap            ***maps;
    hypre_SStructMapInfo    ***info;
    hypre_SStructNMapInfo   ***ninfo;
    int                        nvars;
-   int                        part, var;
+   int                        part, var, i;
 
    if (grid)
    {
@@ -120,6 +105,8 @@ HYPRE_SStructGridDestroy( HYPRE_SStructGrid grid )
          neighbors   = hypre_SStructGridNeighbors(grid);
          nvneighbors = hypre_SStructGridNVNeighbors(grid);
          vneighbors  = hypre_SStructGridVNeighbors(grid);
+         vnbor_comm_info = hypre_SStructGridVNborCommInfo(grid);
+         vnbor_ncomms = hypre_SStructGridVNborNComms(grid);
          maps  = hypre_SStructGridMaps(grid);
          info  = hypre_SStructGridInfo(grid);
          ninfo = hypre_SStructGridNInfo(grid);
@@ -141,11 +128,19 @@ HYPRE_SStructGridDestroy( HYPRE_SStructGrid grid )
             hypre_TFree(info[part]);
             hypre_TFree(ninfo[part]);
          }
+         for (i = 0; i < vnbor_ncomms; i++)
+         {
+            hypre_CommInfoDestroy(
+               hypre_SStructCommInfoCommInfo(vnbor_comm_info[i]));
+            hypre_TFree(vnbor_comm_info[i]);
+         }
+         hypre_TFree(vnbor_comm_info);
          hypre_TFree(pgrids);
          hypre_TFree(nneighbors);
          hypre_TFree(neighbors);
          hypre_TFree(nvneighbors);
          hypre_TFree(vneighbors);
+         hypre_TFree(vnbor_comm_info);
          hypre_TFree(maps);
          hypre_TFree(info);
          hypre_TFree(ninfo);
@@ -153,7 +148,7 @@ HYPRE_SStructGridDestroy( HYPRE_SStructGrid grid )
       }
    }
 
-   return ierr;
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -173,7 +168,9 @@ HYPRE_SStructGridSetExtents( HYPRE_SStructGrid  grid,
    hypre_CopyToCleanIndex(ilower, ndim, cilower);
    hypre_CopyToCleanIndex(iupper, ndim, ciupper);
 
-   return ( hypre_SStructPGridSetExtents(pgrid, cilower, ciupper) );
+   hypre_SStructPGridSetExtents(pgrid, cilower, ciupper);
+
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -186,7 +183,9 @@ int HYPRE_SStructGridSetVariables( HYPRE_SStructGrid      grid,
 {
    hypre_SStructPGrid  *pgrid = hypre_SStructGridPGrid(grid, part);
 
-   return ( hypre_SStructPGridSetVariables(pgrid, nvars, vartypes) );
+   hypre_SStructPGridSetVariables(pgrid, nvars, vartypes);
+
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -203,7 +202,9 @@ int HYPRE_SStructGridSetVariable( HYPRE_SStructGrid      grid,
 {
    hypre_SStructPGrid  *pgrid = hypre_SStructGridPGrid(grid, part);
 
-   return hypre_SStructPGridSetVariable( pgrid, var, nvars, vartype );
+   hypre_SStructPGridSetVariable( pgrid, var, nvars, vartype );
+
+   return hypre_error_flag;
 }
 
 
@@ -217,8 +218,6 @@ HYPRE_SStructGridAddVariables( HYPRE_SStructGrid      grid,
                                int                    nvars,
                                HYPRE_SStructVariable *vartypes )
 {
-   int  ierr = 0;
-
    int                  ndim    = hypre_SStructGridNDim(grid);
    int                  nucvars = hypre_SStructGridNUCVars(grid);
    hypre_SStructUCVar **ucvars  = hypre_SStructGridUCVars(grid);
@@ -251,7 +250,7 @@ HYPRE_SStructGridAddVariables( HYPRE_SStructGrid      grid,
    hypre_SStructGridNUCVars(grid) = nucvars;
    hypre_SStructGridUCVars(grid)  = ucvars;
 
-   return ierr;
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -266,8 +265,6 @@ HYPRE_SStructGridAddVariable( HYPRE_SStructGrid      grid,
                               int                    var,
                               HYPRE_SStructVariable  vartype )
 {
-   int  ierr = 0;
-
    int                  ndim    = hypre_SStructGridNDim(grid);
    int                  nucvars = hypre_SStructGridNUCVars(grid);
    hypre_SStructUCVar **ucvars  = hypre_SStructGridUCVars(grid);
@@ -299,12 +296,88 @@ HYPRE_SStructGridAddVariable( HYPRE_SStructGrid      grid,
    hypre_SStructGridNUCVars(grid) = nucvars;
    hypre_SStructGridUCVars(grid)  = ucvars;
 
-   return ierr;
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
  *--------------------------------------------------------------------------*/
 
+int
+HYPRE_SStructGridSetNeighborPart( HYPRE_SStructGrid  grid,
+                                  int                part,
+                                  int               *ilower,
+                                  int               *iupper,
+                                  int                nbor_part,
+                                  int               *nbor_ilower,
+                                  int               *nbor_iupper,
+                                  int               *index_map,
+                                  int               *index_dir )
+{
+   int                      ndim       = hypre_SStructGridNDim(grid);
+   int                     *nneighbors = hypre_SStructGridNNeighbors(grid);
+   hypre_SStructNeighbor  **neighbors  = hypre_SStructGridNeighbors(grid);
+   hypre_SStructNeighbor   *neighbor;
+
+   hypre_Box               *box;
+   hypre_Index              cilower;
+   hypre_Index              ciupper;
+   hypre_IndexRef           coord, dir, ilower_mapped;
+   int                      memchunk = 10;
+   int                      d, dd, tdir;
+
+   /* allocate more memory if needed */
+   if ((nneighbors[part] % memchunk) == 0)
+   {
+      neighbors[part] = hypre_TReAlloc(neighbors[part], hypre_SStructNeighbor,
+                                       (nneighbors[part] + memchunk));
+   }
+
+   neighbor = &neighbors[part][nneighbors[part]];
+   nneighbors[part]++;
+
+   box = hypre_SStructNeighborBox(neighbor);
+   hypre_CopyToCleanIndex(ilower, ndim, cilower);
+   hypre_CopyToCleanIndex(iupper, ndim, ciupper);
+   hypre_BoxSetExtents(box, cilower, ciupper);
+
+   hypre_SStructNeighborPart(neighbor) = nbor_part;
+
+   coord = hypre_SStructNeighborCoord(neighbor);
+   dir = hypre_SStructNeighborDir(neighbor);
+   ilower_mapped = hypre_SStructNeighborILower(neighbor);
+   hypre_CopyIndex(index_map, coord);
+   hypre_CopyIndex(index_dir, dir);
+   for (d = 0; d < ndim; d++)
+   {
+      dd = coord[d];
+      tdir = dir[d];
+      /* this effectively sorts nbor_ilower and nbor_iupper */
+      if (hypre_IndexD(nbor_ilower, dd) > hypre_IndexD(nbor_iupper, dd))
+      {
+         tdir = -tdir;
+      }
+      if (tdir > 0)
+      {
+         hypre_IndexD(ilower_mapped, dd) = hypre_IndexD(nbor_ilower, dd);
+      }
+      else
+      {
+         hypre_IndexD(ilower_mapped, dd) = hypre_IndexD(nbor_iupper, dd);
+      }
+   }
+   for (d = ndim; d < 3; d++)
+   {
+      hypre_IndexD(coord, d) = d;
+      hypre_IndexD(dir, d) = 1;
+   }
+
+   return hypre_error_flag;
+}
+
+/*--------------------------------------------------------------------------
+ * DEFUNCT - Use SetNeighborPart instead!
+ *--------------------------------------------------------------------------*/
+
 int
 HYPRE_SStructGridSetNeighborBox( HYPRE_SStructGrid  grid,
                                  int                part,
@@ -315,8 +388,6 @@ HYPRE_SStructGridSetNeighborBox( HYPRE_SStructGrid  grid,
                                  int               *nbor_iupper,
                                  int               *index_map )
 {
-   int ierr = 0;
-
    int                      ndim       = hypre_SStructGridNDim(grid);
    int                     *nneighbors = hypre_SStructGridNNeighbors(grid);
    hypre_SStructNeighbor  **neighbors  = hypre_SStructGridNeighbors(grid);
@@ -325,8 +396,9 @@ HYPRE_SStructGridSetNeighborBox( HYPRE_SStructGrid  grid,
    hypre_Box               *box;
    hypre_Index              cilower;
    hypre_Index              ciupper;
+   hypre_IndexRef           coord, dir;
    int                      memchunk = 10;
-   int                      d;
+   int                      d, dd;
 
    /* allocate more memory if needed */
    if ((nneighbors[part] % memchunk) == 0)
@@ -348,120 +420,29 @@ HYPRE_SStructGridSetNeighborBox( HYPRE_SStructGrid  grid,
    hypre_CopyToCleanIndex(nbor_ilower, ndim,
                           hypre_SStructNeighborILower(neighbor));
 
-   hypre_CopyIndex(index_map, hypre_SStructNeighborCoord(neighbor));
+   coord = hypre_SStructNeighborCoord(neighbor);
+   hypre_CopyIndex(index_map, coord);
    for (d = ndim; d < 3; d++)
    {
-      hypre_IndexD(hypre_SStructNeighborCoord(neighbor), d) = d;
+      hypre_IndexD(coord, d) = d;
    }
 
+   dir = hypre_SStructNeighborDir(neighbor);
    for (d = 0; d < 3; d++)
    {
-      hypre_IndexD(hypre_SStructNeighborDir(neighbor), d) = 1;
+      hypre_IndexD(dir, d) = 1;
 
       if (d < ndim)
       {
-         if (hypre_IndexD(nbor_ilower, d) > hypre_IndexD(nbor_iupper, d))
+         dd = coord[d];
+         if (hypre_IndexD(nbor_ilower, dd) > hypre_IndexD(nbor_iupper, dd))
          {
-            hypre_IndexD(hypre_SStructNeighborDir(neighbor), d) = -1;
+            hypre_IndexD(dir, d) = -1;
          }
       }
    }
 
-   /* part with the smaller ID owns the primary variables */
-   if (part < nbor_part)
-   {
-      hypre_SStructNeighborPrimary(neighbor) = 1;
-   }
-   else
-   {
-      hypre_SStructNeighborPrimary(neighbor) = 0;
-   }
-
-   return ierr;
-}
-
-/*--------------------------------------------------------------------------
- * ** TEMPORARY **
- *--------------------------------------------------------------------------*/
-
-int
-HYPRE_SStructGridSetNeighborBoxZ( HYPRE_SStructGrid  grid,
-                                  int                part,
-                                  int               *ilower,
-                                  int               *iupper,
-                                  int                nbor_part,
-                                  int               *nbor_ilower,
-                                  int               *nbor_iupper,
-                                  int               *index_map,
-                                  int                primary )
-{
-   int ierr = 0;
-
-   int                      ndim       = hypre_SStructGridNDim(grid);
-   int                     *nneighbors = hypre_SStructGridNNeighbors(grid);
-   hypre_SStructNeighbor  **neighbors  = hypre_SStructGridNeighbors(grid);
-   hypre_SStructNeighbor   *neighbor;
-
-   hypre_Box               *box;
-   hypre_Index              cilower;
-   hypre_Index              ciupper;
-   int                      memchunk = 10;
-   int                      d;
-
-   /* allocate more memory if needed */
-   if ((nneighbors[part] % memchunk) == 0)
-   {
-      neighbors[part] = hypre_TReAlloc(neighbors[part], hypre_SStructNeighbor,
-                                       (nneighbors[part] + memchunk));
-   }
-
-   neighbor = &neighbors[part][nneighbors[part]];
-   nneighbors[part]++;
-
-   box = hypre_SStructNeighborBox(neighbor);
-   hypre_CopyToCleanIndex(ilower, ndim, cilower);
-   hypre_CopyToCleanIndex(iupper, ndim, ciupper);
-   hypre_BoxSetExtents(box, cilower, ciupper);
-
-   hypre_SStructNeighborPart(neighbor) = nbor_part;
-
-   hypre_CopyToCleanIndex(nbor_ilower, ndim,
-                          hypre_SStructNeighborILower(neighbor));
-
-   hypre_CopyIndex(index_map, hypre_SStructNeighborCoord(neighbor));
-   for (d = ndim; d < 3; d++)
-   {
-      hypre_IndexD(hypre_SStructNeighborCoord(neighbor), d) = d;
-   }
-
-   for (d = 0; d < 3; d++)
-   {
-      hypre_IndexD(hypre_SStructNeighborDir(neighbor), d) = 1;
-
-      if (d < ndim)
-      {
-         if (hypre_IndexD(nbor_ilower, d) > hypre_IndexD(nbor_iupper, d))
-         {
-            hypre_IndexD(hypre_SStructNeighborDir(neighbor), d) = -1;
-         }
-      }
-   }
-
-   if (primary < 0)
-   {
-      /* hypre decides: part with the smaller ID owns the primary variables */
-      if (part < nbor_part)
-      {
-         primary = 1;
-      }
-      else
-      {
-         primary = 0;
-      }
-   }
-   hypre_SStructNeighborPrimary(neighbor) = primary;
-
-   return ierr;
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -474,7 +455,9 @@ HYPRE_SStructGridAddUnstructuredPart( HYPRE_SStructGrid grid,
                                       int              ilower,
                                       int              iupper )
 {
-   return ( hypre_SStructGridAssemble(grid) );
+   hypre_SStructGridAssemble(grid);
+
+   return hypre_error_flag;
 }
 #endif
 
@@ -484,8 +467,6 @@ HYPRE_SStructGridAddUnstructuredPart( HYPRE_SStructGrid grid,
 int
 HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
 {
-   int                   ierr = 0;
-
    int                      ndim        = hypre_SStructGridNDim(grid);
    int                      nparts      = hypre_SStructGridNParts(grid);
    hypre_SStructPGrid     **pgrids      = hypre_SStructGridPGrids(grid);
@@ -504,13 +485,14 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
    hypre_Box               *int_box;
    hypre_BoxMapEntry      **entries;
    int                      nentries;
-   int                     *ilower, *imin0, *imin1, *coord, *dir;
+   int                     *ilower, *coord, *dir, *box_imin;
+   hypre_Index              imin0, imin1;
 
    hypre_SStructPGrid      *pgrid;
    HYPRE_SStructVariable   *vartypes;
    hypre_Index              varoffset;
    int                      nvars;
-   int                      part, npart, var, i, b, vb, t, d, nd;
+   int                      part, nbor_part, var, nbor_var, i, b, vb, t, d, nd;
 
    /*-------------------------------------------------------------
     * set pneighbors for each pgrid info to crop pgrids
@@ -532,7 +514,8 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
       {
          neighbor = &neighbors[part][i];
 
-         if (!hypre_SStructNeighborPrimary(neighbor))
+         /* if this part is not the owner of the shared data */
+         if ( part > hypre_SStructNeighborPart(neighbor) )
          {
             hypre_SStructPGridSetPNeighbor(pgrid,
                                            hypre_SStructNeighborBox(neighbor));
@@ -582,9 +565,6 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
 
    /*-------------------------------------------------
     * Set up neighbor info
-    *
-    * ZTODO: This should work for all variable types,
-    * but it has only been tested for cell-centered.
     *-------------------------------------------------*/
 
    nbor_box = hypre_BoxCreate();
@@ -616,21 +596,31 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
             nbor_boxa = hypre_BoxArrayArrayBoxArray(nbor_boxes, b);
             hypre_BoxArraySetSize(nbor_boxa, 0);
 
-            imin0 = hypre_BoxIMin(hypre_SStructNeighborBox(neighbor));
-            imin1 = hypre_SStructNeighborILower(neighbor);
+            hypre_CopyBox(hypre_SStructNeighborBox(neighbor), nbor_box);
+            hypre_CopyIndex(
+               hypre_BoxIMin(hypre_SStructNeighborBox(neighbor)), imin0);
+            hypre_CopyIndex(hypre_SStructNeighborILower(neighbor), imin1);
             coord = hypre_SStructNeighborCoord(neighbor);
             dir   = hypre_SStructNeighborDir(neighbor);
 
-            hypre_CopyBox(hypre_SStructNeighborBox(neighbor), nbor_box);
-            hypre_BoxIMinX(nbor_box) -= hypre_IndexX(varoffset);
-            hypre_BoxIMinY(nbor_box) -= hypre_IndexY(varoffset);
-            hypre_BoxIMinZ(nbor_box) -= hypre_IndexZ(varoffset);
+            /* change variable type; it's important to change imin0 & imin1 */
+            for (d = 0; d < 3; d++)
+            {
+               nd = coord[d];
+               hypre_BoxIMinD(nbor_box, d) -= hypre_IndexD(varoffset, d);
+               hypre_IndexD(imin0, d) -= hypre_IndexD(varoffset, d);
+               if (dir[d] > 0)
+               {
+                  hypre_IndexD(imin1, nd) -= hypre_IndexD(varoffset, d);
+               }
+            }
 
             /* map to neighbor part index space */
-            hypre_SStructBoxToNBorBox(nbor_box, imin0, imin1, coord, dir);
+            hypre_SStructBoxToNborBox(nbor_box, imin0, imin1, coord, dir);
+            hypre_SStructVarToNborVar(grid, part, var, coord, &nbor_var);
 
-            npart = hypre_SStructNeighborPart(neighbor);
-            hypre_BoxMapIntersect(hypre_SStructGridMap(grid, npart, var),
+            nbor_part = hypre_SStructNeighborPart(neighbor);
+            hypre_BoxMapIntersect(hypre_SStructGridMap(grid, nbor_part, nbor_var),
                                   hypre_BoxIMin(nbor_box),
                                   hypre_BoxIMax(nbor_box),
                                   &entries, &nentries );
@@ -645,7 +635,7 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
                if (hypre_BoxVolume(int_box))
                {
                   /* map back from neighbor part index space */
-                  hypre_SStructNBorBoxToBox(int_box, imin0, imin1, coord, dir);
+                  hypre_SStructNborBoxToBox(int_box, imin0, imin1, coord, dir);
 
                   hypre_AppendBox(int_box, nbor_boxa);
                }
@@ -683,6 +673,23 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
             neighbor  = &neighbors[part][b];
             nbor_boxa = hypre_BoxArrayArrayBoxArray(nbor_boxes, b);
 
+            hypre_CopyIndex(
+               hypre_BoxIMin(hypre_SStructNeighborBox(neighbor)), imin0);
+            hypre_CopyIndex(hypre_SStructNeighborILower(neighbor), imin1);
+            coord = hypre_SStructNeighborCoord(neighbor);
+            dir   = hypre_SStructNeighborDir(neighbor);
+
+            /* change variable type as above ('nbor_boxa' already changed) */
+            for (d = 0; d < 3; d++)
+            {
+               nd = coord[d];
+               hypre_IndexD(imin0, d) -= hypre_IndexD(varoffset, d);
+               if (dir[d] > 0)
+               {
+                  hypre_IndexD(imin1, nd) -= hypre_IndexD(varoffset, d);
+               }
+            }
+
             hypre_ForBoxI(i, nbor_boxa)
                {
                   vneighbor = &vneighbors[part][var][vb];
@@ -691,23 +698,17 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
                                 hypre_SStructNeighborBox(vneighbor));
                   hypre_SStructNeighborPart(vneighbor) =
                      hypre_SStructNeighborPart(neighbor);
-                  hypre_CopyIndex(hypre_SStructNeighborILower(neighbor),
-                                  hypre_SStructNeighborILower(vneighbor));
-                  hypre_CopyIndex(hypre_SStructNeighborCoord(neighbor),
-                                  hypre_SStructNeighborCoord(vneighbor));
-                  hypre_CopyIndex(hypre_SStructNeighborDir(neighbor),
-                                  hypre_SStructNeighborDir(vneighbor));
+                  hypre_CopyIndex(imin1, hypre_SStructNeighborILower(vneighbor));
+                  hypre_CopyIndex(coord, hypre_SStructNeighborCoord(vneighbor));
+                  hypre_CopyIndex(dir, hypre_SStructNeighborDir(vneighbor));
 
-                  /* adjust vneighbor ilower appropriately */
+                  /* compute correct vneighbor ilower based on box imin */
+                  box_imin = hypre_BoxIMin(hypre_SStructNeighborBox(vneighbor));
                   ilower = hypre_SStructNeighborILower(vneighbor);
-                  imin0  = hypre_BoxIMin(hypre_SStructNeighborBox(neighbor));
-                  imin1  = hypre_BoxIMin(hypre_SStructNeighborBox(vneighbor));
-                  coord  = hypre_SStructNeighborCoord(vneighbor);
-                  dir    = hypre_SStructNeighborDir(vneighbor);
                   for (d = 0; d < 3; d++)
                   {
                      nd = coord[d];
-                     ilower[nd] += (imin1[d] - imin0[d]) * dir[nd];
+                     ilower[nd] = imin1[nd] + (box_imin[d] - imin0[d]) * dir[d];
                   }
 
                   vb++;
@@ -729,9 +730,15 @@ HYPRE_SStructGridAssemble( HYPRE_SStructGrid grid )
     * Assemble the neighbor map info
     *-------------------------------------------------*/
 
-   hypre_SStructGridAssembleNBorMaps(grid);
+   hypre_SStructGridAssembleNborMaps(grid);
 
-   return ierr;
+   /*-------------------------------------------------
+    * Compute the CommInfo component of the grid
+    *-------------------------------------------------*/
+
+   hypre_SStructGridCreateCommInfo(grid);
+
+   return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
@@ -742,8 +749,6 @@ HYPRE_SStructGridSetPeriodic( HYPRE_SStructGrid  grid,
                               int                part,
                               int               *periodic )
 {
-   int ierr = 0;
-
    hypre_SStructPGrid *pgrid          = hypre_SStructGridPGrid(grid, part);
    hypre_IndexRef      pgrid_periodic = hypre_SStructPGridPeriodic(pgrid);
    int                 d;
@@ -753,7 +758,7 @@ HYPRE_SStructGridSetPeriodic( HYPRE_SStructGrid  grid,
       hypre_IndexD(pgrid_periodic, d) = periodic[d];
    }
 
-   return ierr;
+   return hypre_error_flag;
 }
 
 
@@ -766,5 +771,7 @@ int
 HYPRE_SStructGridSetNumGhost( HYPRE_SStructGrid grid,
                               int            *num_ghost)       
 {
-   return ( hypre_SStructGridSetNumGhost(grid, num_ghost) );
+   hypre_SStructGridSetNumGhost(grid, num_ghost);
+
+   return hypre_error_flag;
 }
