@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.23 $
+ * $Revision: 2.27 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * Member functions for hypre_SStructPMatrix class.
@@ -39,7 +26,6 @@
  *==========================================================================*/
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixRef
  *--------------------------------------------------------------------------*/
 
 int
@@ -53,7 +39,6 @@ hypre_SStructPMatrixRef( hypre_SStructPMatrix  *matrix,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixCreate
  *--------------------------------------------------------------------------*/
 
 int
@@ -182,7 +167,7 @@ hypre_SStructPMatrixCreate( MPI_Comm               comm,
    hypre_SStructPMatrixSEntriesSize(pmatrix) = size;
    hypre_SStructPMatrixSEntries(pmatrix) = hypre_TAlloc(int, size);
 
-   hypre_SStructPMatrixRefCount(pmatrix)   = 1;
+   hypre_SStructPMatrixRefCount(pmatrix) = 1;
 
    *pmatrix_ptr = pmatrix;
 
@@ -190,7 +175,6 @@ hypre_SStructPMatrixCreate( MPI_Comm               comm,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixDestroy
  *--------------------------------------------------------------------------*/
 
 int 
@@ -242,30 +226,18 @@ hypre_SStructPMatrixDestroy( hypre_SStructPMatrix *pmatrix )
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixInitialize
  *--------------------------------------------------------------------------*/
 int 
 hypre_SStructPMatrixInitialize( hypre_SStructPMatrix *pmatrix )
 {
-   int                    nvars       = hypre_SStructPMatrixNVars(pmatrix);
-   int                  **symmetric   = hypre_SStructPMatrixSymmetric(pmatrix);
-   hypre_SStructPGrid    *pgrid       = hypre_SStructPMatrixPGrid(pmatrix);
-   HYPRE_SStructVariable *vartypes    = hypre_SStructPGridVarTypes(pgrid);
-   int                    ndim        = hypre_SStructPGridNDim(pgrid);
-
-   int                    num_ghost[6]= {1, 1, 1, 1, 1, 1};
-   hypre_StructMatrix    *smatrix;
-   hypre_StructGrid      *sgrid;
-
-   hypre_Index            varoffset;
-   int                    vi, vj, d;
+   int                   nvars        = hypre_SStructPMatrixNVars(pmatrix);
+   int                 **symmetric    = hypre_SStructPMatrixSymmetric(pmatrix);
+   int                   num_ghost[6] = {1, 1, 1, 1, 1, 1};
+   hypre_StructMatrix   *smatrix;
+   int                   vi, vj;
 
    for (vi = 0; vi < nvars; vi++)
    {
-     /* use variable vi add_numghost */
-      sgrid= hypre_SStructPGridSGrid(pgrid, vi);
-      hypre_SStructVariableGetOffset(vartypes[vi], ndim, varoffset);
-
       for (vj = 0; vj < nvars; vj++)
       {
          smatrix = hypre_SStructPMatrixSMatrix(pmatrix, vi, vj);
@@ -273,25 +245,22 @@ hypre_SStructPMatrixInitialize( hypre_SStructPMatrix *pmatrix )
          {
             HYPRE_StructMatrixSetSymmetric(smatrix, symmetric[vi][vj]);
             hypre_StructMatrixSetNumGhost(smatrix, num_ghost);
-
-            for (d = 0; d < 3; d++)
-            {
-               hypre_StructMatrixAddNumGhost(smatrix)[2*d]=
-                                       hypre_IndexD(varoffset, d);
-               hypre_StructMatrixAddNumGhost(smatrix)[2*d+1]=
-                                       hypre_IndexD(varoffset, d);
-            }
-
             hypre_StructMatrixInitialize(smatrix);
+            /* needed to get AddTo accumulation correct between processors */
+            hypre_StructMatrixClearGhostValues(smatrix);
          }
       }
    }
 
+   hypre_SStructPMatrixAccumulated(pmatrix) = 0;
+
    return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixSetValues
+ * (action > 0): add-to values
+ * (action = 0): set values
+ * (action < 0): get values
  *--------------------------------------------------------------------------*/
 
 int 
@@ -301,12 +270,14 @@ hypre_SStructPMatrixSetValues( hypre_SStructPMatrix *pmatrix,
                                int                   nentries,
                                int                  *entries,
                                double               *values,
-                               int                   add_to )
+                               int                   action )
 {
    hypre_SStructStencil *stencil = hypre_SStructPMatrixStencil(pmatrix, var);
    int                  *smap    = hypre_SStructPMatrixSMap(pmatrix, var);
    int                  *vars    = hypre_SStructStencilVars(stencil);
    hypre_StructMatrix   *smatrix;
+   hypre_BoxArray       *grid_boxes;
+   hypre_Box            *box;
    int                  *sentries;
    int                   i;
 
@@ -318,13 +289,90 @@ hypre_SStructPMatrixSetValues( hypre_SStructPMatrix *pmatrix,
       sentries[i] = smap[entries[i]];
    }
 
-   hypre_StructMatrixSetValues(smatrix, index, nentries, sentries, values, add_to);
+   /* set values inside the grid */
+   hypre_StructMatrixSetValues(smatrix, index, nentries, sentries, values,
+                               action, -1, 0);
+
+   /* set (AddTo/Get) or clear (Set) values outside the grid in ghost zones */
+   if (action != 0)
+   {
+      /* AddTo/Get */
+      hypre_SStructPGrid  *pgrid = hypre_SStructPMatrixPGrid(pmatrix);
+      hypre_Index          varoffset;
+      int                  done = 0;
+
+      grid_boxes = hypre_StructGridBoxes(hypre_StructMatrixGrid(smatrix));
+
+      hypre_ForBoxI(i, grid_boxes)
+      {
+         box = hypre_BoxArrayBox(grid_boxes, i);
+         if ((hypre_IndexX(index) >= hypre_BoxIMinX(box)) &&
+             (hypre_IndexX(index) <= hypre_BoxIMaxX(box)) &&
+             (hypre_IndexY(index) >= hypre_BoxIMinY(box)) &&
+             (hypre_IndexY(index) <= hypre_BoxIMaxY(box)) &&
+             (hypre_IndexZ(index) >= hypre_BoxIMinZ(box)) &&
+             (hypre_IndexZ(index) <= hypre_BoxIMaxZ(box))   )
+         {
+            done = 1;
+            break;
+         }
+      }
+
+      if (!done)
+      {
+         hypre_SStructVariableGetOffset(hypre_SStructPGridVarType(pgrid, var),
+                                        hypre_SStructPGridNDim(pgrid), varoffset);
+         hypre_ForBoxI(i, grid_boxes)
+         {
+            box = hypre_BoxArrayBox(grid_boxes, i);
+            if ((hypre_IndexX(index) >=
+                 hypre_BoxIMinX(box) - hypre_IndexX(varoffset)) &&
+                (hypre_IndexX(index) <=
+                 hypre_BoxIMaxX(box) + hypre_IndexX(varoffset)) &&
+                (hypre_IndexY(index) >=
+                 hypre_BoxIMinY(box) - hypre_IndexY(varoffset)) &&
+                (hypre_IndexY(index) <=
+                 hypre_BoxIMaxY(box) + hypre_IndexY(varoffset)) &&
+                (hypre_IndexZ(index) >=
+                 hypre_BoxIMinZ(box) - hypre_IndexZ(varoffset)) &&
+                (hypre_IndexZ(index) <=
+                 hypre_BoxIMaxZ(box) + hypre_IndexZ(varoffset))   )
+            {
+               hypre_StructMatrixSetValues(smatrix, index, nentries, sentries,
+                                           values, action, i, 1);
+               break;
+            }
+         }
+      }
+   }
+   else
+   {
+      /* Set */
+      grid_boxes = hypre_StructGridBoxes(hypre_StructMatrixGrid(smatrix));
+
+      hypre_ForBoxI(i, grid_boxes)
+      {
+         box = hypre_BoxArrayBox(grid_boxes, i);
+         if ((hypre_IndexX(index) < hypre_BoxIMinX(box)) ||
+             (hypre_IndexX(index) > hypre_BoxIMaxX(box)) ||
+             (hypre_IndexY(index) < hypre_BoxIMinY(box)) ||
+             (hypre_IndexY(index) > hypre_BoxIMaxY(box)) ||
+             (hypre_IndexZ(index) < hypre_BoxIMinZ(box)) ||
+             (hypre_IndexZ(index) > hypre_BoxIMaxZ(box))   )
+         {
+            hypre_StructMatrixClearValues(smatrix, index, nentries, sentries, i, 1);
+         }
+      }
+   }
 
    return hypre_error_flag;
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixSetBoxValues
+ * (action > 0): add-to values
+ * (action = 0): set values
+ * (action < 0): get values
+ * (action =-2): get values and zero out
  *--------------------------------------------------------------------------*/
 
 int 
@@ -335,21 +383,24 @@ hypre_SStructPMatrixSetBoxValues( hypre_SStructPMatrix *pmatrix,
                                   int                   nentries,
                                   int                  *entries,
                                   double               *values,
-                                  int                   add_to )
+                                  int                   action )
 {
    hypre_SStructStencil *stencil = hypre_SStructPMatrixStencil(pmatrix, var);
    int                  *smap    = hypre_SStructPMatrixSMap(pmatrix, var);
    int                  *vars    = hypre_SStructStencilVars(stencil);
    hypre_StructMatrix   *smatrix;
+   hypre_BoxArray       *grid_boxes;
    hypre_Box            *box;
+   hypre_Box            *value_box;
    int                  *sentries;
-   int                   i;
+   int                   i, j;
 
    smatrix = hypre_SStructPMatrixSMatrix(pmatrix, var, vars[entries[0]]);
 
    box = hypre_BoxCreate();
    hypre_CopyIndex(ilower, hypre_BoxIMin(box));
    hypre_CopyIndex(iupper, hypre_BoxIMax(box));
+   value_box = box;
 
    sentries = hypre_SStructPMatrixSEntries(pmatrix);
    for (i = 0; i < nentries; i++)
@@ -357,7 +408,86 @@ hypre_SStructPMatrixSetBoxValues( hypre_SStructPMatrix *pmatrix,
       sentries[i] = smap[entries[i]];
    }
 
-   hypre_StructMatrixSetBoxValues(smatrix, box, nentries, sentries, values, add_to);
+   /* set values inside the grid */
+   hypre_StructMatrixSetBoxValues(smatrix, box, value_box, nentries, sentries,
+                                  values, action, -1, 0);
+
+   /* set (AddTo/Get) or clear (Set) values outside the grid in ghost zones */
+   if (action != 0)
+   {
+      /* AddTo/Get */
+      hypre_SStructPGrid  *pgrid = hypre_SStructPMatrixPGrid(pmatrix);
+      hypre_Index          varoffset;
+      hypre_BoxArray      *left_boxes, *done_boxes, *temp_boxes;
+      hypre_Box           *left_box, *done_box, *int_box;
+
+      hypre_SStructVariableGetOffset(hypre_SStructPGridVarType(pgrid, var),
+                                     hypre_SStructPGridNDim(pgrid), varoffset);
+      grid_boxes = hypre_StructGridBoxes(hypre_StructMatrixGrid(smatrix));
+
+      left_boxes = hypre_BoxArrayCreate(1);
+      done_boxes = hypre_BoxArrayCreate(2);
+      temp_boxes = hypre_BoxArrayCreate(0);
+
+      /* done_box always points to the first box in done_boxes */
+      done_box = hypre_BoxArrayBox(done_boxes, 0);
+      /* int_box always points to the second box in done_boxes */
+      int_box = hypre_BoxArrayBox(done_boxes, 1);
+
+      hypre_CopyBox(box, hypre_BoxArrayBox(left_boxes, 0));
+      hypre_BoxArraySetSize(left_boxes, 1);
+      hypre_SubtractBoxArrays(left_boxes, grid_boxes, temp_boxes);
+
+      hypre_BoxArraySetSize(done_boxes, 0);
+      hypre_ForBoxI(i, grid_boxes)
+      {
+         hypre_SubtractBoxArrays(left_boxes, done_boxes, temp_boxes);
+         hypre_BoxArraySetSize(done_boxes, 1);
+         hypre_CopyBox(hypre_BoxArrayBox(grid_boxes, i), done_box);
+         hypre_BoxIMinX(done_box) -= hypre_IndexX(varoffset);
+         hypre_BoxIMinY(done_box) -= hypre_IndexY(varoffset);
+         hypre_BoxIMinZ(done_box) -= hypre_IndexZ(varoffset);
+         hypre_BoxIMaxX(done_box) += hypre_IndexX(varoffset);
+         hypre_BoxIMaxY(done_box) += hypre_IndexY(varoffset);
+         hypre_BoxIMaxZ(done_box) += hypre_IndexZ(varoffset);
+         hypre_ForBoxI(j, left_boxes)
+         {
+            left_box = hypre_BoxArrayBox(left_boxes, j);
+            hypre_IntersectBoxes(left_box, done_box, int_box);
+            hypre_StructMatrixSetBoxValues(smatrix, int_box, value_box,
+                                           nentries, sentries,
+                                           values, action, i, 1);
+         }
+      }
+
+      hypre_BoxArrayDestroy(left_boxes);
+      hypre_BoxArrayDestroy(done_boxes);
+      hypre_BoxArrayDestroy(temp_boxes);
+   }
+   else
+   {
+      /* Set */
+      hypre_BoxArray  *diff_boxes;
+      hypre_Box       *grid_box, *diff_box;
+
+      grid_boxes = hypre_StructGridBoxes(hypre_StructMatrixGrid(smatrix));
+      diff_boxes = hypre_BoxArrayCreate(0);
+
+      hypre_ForBoxI(i, grid_boxes)
+      {
+         grid_box = hypre_BoxArrayBox(grid_boxes, i);
+         hypre_BoxArraySetSize(diff_boxes, 0);
+         hypre_SubtractBoxes(box, grid_box, diff_boxes);
+
+         hypre_ForBoxI(j, diff_boxes)
+         {
+            diff_box = hypre_BoxArrayBox(diff_boxes, j);
+            hypre_StructMatrixClearBoxValues(smatrix, diff_box, nentries, sentries,
+                                             i, 1);
+         }
+      }
+      hypre_BoxArrayDestroy(diff_boxes);
+   }
 
    hypre_BoxDestroy(box);
 
@@ -365,15 +495,31 @@ hypre_SStructPMatrixSetBoxValues( hypre_SStructPMatrix *pmatrix,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixAssemble
  *--------------------------------------------------------------------------*/
 
 int 
-hypre_SStructPMatrixAssemble( hypre_SStructPMatrix *pmatrix )
+hypre_SStructPMatrixAccumulate( hypre_SStructPMatrix *pmatrix )
 {
-   int                 nvars = hypre_SStructPMatrixNVars(pmatrix);
-   hypre_StructMatrix *smatrix;
-   int                 vi, vj;
+   hypre_SStructPGrid    *pgrid    = hypre_SStructPMatrixPGrid(pmatrix);
+   int                    nvars    = hypre_SStructPMatrixNVars(pmatrix);
+   int                    ndim     = hypre_SStructPGridNDim(pgrid);
+   HYPRE_SStructVariable *vartypes = hypre_SStructPGridVarTypes(pgrid);
+
+   hypre_StructMatrix    *smatrix;
+   hypre_Index            varoffset;
+   int                    num_ghost[6];
+   hypre_StructGrid      *sgrid;
+   int                    vi, vj, d;
+
+   hypre_CommInfo        *comm_info;
+   hypre_CommPkg         *comm_pkg;
+   hypre_CommHandle      *comm_handle;
+
+   /* if values already accumulated, just return */
+   if (hypre_SStructPMatrixAccumulated(pmatrix))
+   {
+      return hypre_error_flag;
+   }
 
    for (vi = 0; vi < nvars; vi++)
    {
@@ -382,6 +528,60 @@ hypre_SStructPMatrixAssemble( hypre_SStructPMatrix *pmatrix )
          smatrix = hypre_SStructPMatrixSMatrix(pmatrix, vi, vj);
          if (smatrix != NULL)
          {
+            sgrid = hypre_StructMatrixGrid(smatrix);
+            /* assumes vi and vj vartypes are the same */
+            hypre_SStructVariableGetOffset(vartypes[vi], ndim, varoffset);
+            for (d = 0; d < 3; d++)
+            {
+               num_ghost[2*d]   = hypre_IndexD(varoffset, d);
+               num_ghost[2*d+1] = hypre_IndexD(varoffset, d);
+            }
+         
+            /* accumulate values from AddTo */
+            hypre_CreateCommInfoFromNumGhost(sgrid, num_ghost, &comm_info);
+            hypre_CommPkgCreate(comm_info,
+                                hypre_StructMatrixDataSpace(smatrix),
+                                hypre_StructMatrixDataSpace(smatrix),
+                                hypre_StructMatrixNumValues(smatrix), NULL, 1,
+                                hypre_StructMatrixComm(smatrix),
+                                &comm_pkg);
+            hypre_InitializeCommunication(comm_pkg,
+                                          hypre_StructMatrixData(smatrix),
+                                          hypre_StructMatrixData(smatrix),
+                                          1, 0, &comm_handle);
+            hypre_FinalizeCommunication(comm_handle);
+
+            hypre_CommInfoDestroy(comm_info);
+            hypre_CommPkgDestroy(comm_pkg);
+         }
+      }
+   }
+
+   hypre_SStructPMatrixAccumulated(pmatrix) = 1;
+
+   return hypre_error_flag;
+}
+
+/*--------------------------------------------------------------------------
+ *--------------------------------------------------------------------------*/
+
+int 
+hypre_SStructPMatrixAssemble( hypre_SStructPMatrix *pmatrix )
+{
+   int                    nvars    = hypre_SStructPMatrixNVars(pmatrix);
+   hypre_StructMatrix    *smatrix;
+   int                    vi, vj;
+
+   hypre_SStructPMatrixAccumulate(pmatrix);
+
+   for (vi = 0; vi < nvars; vi++)
+   {
+      for (vj = 0; vj < nvars; vj++)
+      {
+         smatrix = hypre_SStructPMatrixSMatrix(pmatrix, vi, vj);
+         if (smatrix != NULL)
+         {
+            hypre_StructMatrixClearGhostValues(smatrix);
             hypre_StructMatrixAssemble(smatrix);
          }
       }
@@ -430,7 +630,6 @@ hypre_SStructPMatrixSetSymmetric( hypre_SStructPMatrix *pmatrix,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructPMatrixPrint
  *--------------------------------------------------------------------------*/
 
 int
@@ -464,7 +663,6 @@ hypre_SStructPMatrixPrint( const char           *filename,
  *==========================================================================*/
 
 /*--------------------------------------------------------------------------
- * hypre_SStructUMatrixInitialize
  *--------------------------------------------------------------------------*/
 
 int 
@@ -626,11 +824,9 @@ hypre_SStructUMatrixInitialize( hypre_SStructMatrix *matrix )
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructUMatrixSetValues
- *
- * (add_to > 0): add-to values
- * (add_to = 0): set values
- * (add_to < 0): get values
+ * (action > 0): add-to values
+ * (action = 0): set values
+ * (action < 0): get values
  *--------------------------------------------------------------------------*/
 
 int 
@@ -641,7 +837,7 @@ hypre_SStructUMatrixSetValues( hypre_SStructMatrix *matrix,
                                int                  nentries,
                                int                 *entries,
                                double              *values,
-                               int                  add_to )
+                               int                  action )
 {
    HYPRE_IJMatrix        ijmatrix = hypre_SStructMatrixIJMatrix(matrix);
    hypre_SStructGraph   *graph   = hypre_SStructMatrixGraph(matrix);
@@ -686,7 +882,7 @@ hypre_SStructUMatrixSetValues( hypre_SStructMatrix *matrix,
 
    /* Only Set values if I am the owner process; off-process AddTo and Get
     * values are done by IJ */
-   if (!add_to)
+   if (!action)
    {
       hypre_SStructMapEntryGetProcess(map_entry, &proc);
       MPI_Comm_rank(hypre_SStructGridComm(grid), &myproc);
@@ -720,11 +916,8 @@ hypre_SStructUMatrixSetValues( hypre_SStructMatrix *matrix,
          
          if (map_entry != NULL)
         {
-
-	    
-	     hypre_SStructMapEntryGetGlobalRank(map_entry, to_index,
+           hypre_SStructMapEntryGetGlobalRank(map_entry, to_index,
                                               &col_coords[ncoeffs],matrix_type);
-	    
 
            coeffs[ncoeffs] = values[i];
            ncoeffs++;
@@ -742,13 +935,13 @@ hypre_SStructUMatrixSetValues( hypre_SStructMatrix *matrix,
       }
    }
 
-   if (add_to > 0)
+   if (action > 0)
    {
       HYPRE_IJMatrixAddToValues(ijmatrix, 1, &ncoeffs, &row_coord,
                                 (const int *) col_coords,
                                 (const double *) coeffs);
    }
-   else if (add_to > -1)
+   else if (action > -1)
    {
       HYPRE_IJMatrixSetValues(ijmatrix, 1, &ncoeffs, &row_coord,
                               (const int *) col_coords,
@@ -766,9 +959,9 @@ hypre_SStructUMatrixSetValues( hypre_SStructMatrix *matrix,
 /*--------------------------------------------------------------------------
  * Note: Entries must all be of type stencil or non-stencil, but not both.
  *
- * (add_to > 0): add-to values
- * (add_to = 0): set values
- * (add_to < 0): get values
+ * (action > 0): add-to values
+ * (action = 0): set values
+ * (action < 0): get values
  *--------------------------------------------------------------------------*/
 
 int 
@@ -780,7 +973,7 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
                                   int                  nentries,
                                   int                 *entries,
                                   double              *values,
-                                  int                  add_to )
+                                  int                  action )
 {
    HYPRE_IJMatrix        ijmatrix = hypre_SStructMatrixIJMatrix(matrix);
    hypre_SStructGraph   *graph   = hypre_SStructMatrixGraph(matrix);
@@ -827,7 +1020,6 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
 
       hypre_CopyIndex(ilower, hypre_BoxIMin(box));
       hypre_CopyIndex(iupper, hypre_BoxIMax(box));
-      /* ZTODO: check that this change fixes multiple-entry problem */
       nrows    = hypre_BoxVolume(box)*nentries;
       ncols    = hypre_CTAlloc(int, nrows);
       for (i = 0; i < nrows; i++)
@@ -848,7 +1040,7 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
       {
          /* Only Set values if I am the owner process; off-process AddTo and Get
           * values are done by IJ */
-         if (!add_to)
+         if (!action)
          {
             hypre_SStructMapEntryGetProcess(map_entries[ii], &proc);
             MPI_Comm_rank(hypre_SStructGridComm(grid), &myproc);
@@ -906,7 +1098,7 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
                 /* GEC1002 introducing the rank based on the type of the matrix  */
 
                hypre_SStructMapEntryGetGlobalRank(map_to_entries[jj],
-                                                  index, &col_base,matrix_type);
+                                                  index, &col_base, matrix_type);
 
                hypre_IndexX(index) -= hypre_IndexX(offset);
                hypre_IndexY(index) -= hypre_IndexY(offset);
@@ -915,7 +1107,7 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
                 /* GEC1002 introducing the rank based on the type of the matrix  */
 
                hypre_SStructMapEntryGetGlobalRank(map_entries[ii],
-                                                  index, &row_base,matrix_type);
+                                                  index, &row_base, matrix_type);
 
                hypre_IndexX(index) -= hypre_IndexX(ilower);
                hypre_IndexY(index) -= hypre_IndexY(ilower);
@@ -947,14 +1139,14 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
           * set IJ values one stencil entry at a time
           *------------------------------------------*/
 
-         if (add_to > 0)
+         if (action > 0)
          {
             HYPRE_IJMatrixAddToValues(ijmatrix, nrows, ncols,
                                       (const int *) rows,
                                       (const int *) cols,
                                       (const double *) ijvalues);
          }
-         else if (add_to > -1)
+         else if (action > -1)
          {
             HYPRE_IJMatrixSetValues(ijmatrix, nrows, ncols,
                                     (const int *) rows,
@@ -996,7 +1188,7 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
             {
                hypre_SetIndex(index, i, j, k);
                hypre_SStructUMatrixSetValues(matrix, part, index, var,
-                                             nentries, entries, values, add_to);
+                                             nentries, entries, values, action);
                values += nentries;
             }
          }
@@ -1009,7 +1201,6 @@ hypre_SStructUMatrixSetBoxValues( hypre_SStructMatrix *matrix,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructUMatrixAssemble
  *--------------------------------------------------------------------------*/
 
 int 
@@ -1029,7 +1220,6 @@ hypre_SStructUMatrixAssemble( hypre_SStructMatrix *matrix )
  *==========================================================================*/
 
 /*--------------------------------------------------------------------------
- * hypre_SStructMatrixRef
  *--------------------------------------------------------------------------*/
 
 int
@@ -1043,7 +1233,6 @@ hypre_SStructMatrixRef( hypre_SStructMatrix  *matrix,
 }
 
 /*--------------------------------------------------------------------------
- * hypre_SStructMatrixSplitEntries
  *--------------------------------------------------------------------------*/
 
 int
