@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.7 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * SStruct matrix-vector multiply routine
@@ -320,7 +307,7 @@ hypre_SStructMatvecCompute( void                *matvec_vdata,
       printf("possible error: A and x are different object types\n");
    }
 
-   if (x_object_type == HYPRE_SSTRUCT)
+   if ( (x_object_type == HYPRE_SSTRUCT) || (x_object_type == HYPRE_STRUCT) )
    {
      /* do S-matrix computations */
       for (part = 0; part < nparts; part++)
@@ -332,25 +319,29 @@ hypre_SStructMatvecCompute( void                *matvec_vdata,
          hypre_SStructPMatvecCompute(pdata, alpha, pA, px, beta, py);
       }
 
-     /* do U-matrix computations */
+      if ( (x_object_type == HYPRE_SSTRUCT) )
+      {
 
-     /* GEC1002 the data chunk pointed by the local-parvectors 
-      *  inside the semistruct vectors x and y is now identical to the
-      *  data chunk of the structure vectors x and y. The role of the function
-      *  convert is to pass the addresses of the data chunk
-      *  to the parx and pary. */  
+         /* do U-matrix computations */
 
-      hypre_SStructVectorConvert(x, &parx);
-      hypre_SStructVectorConvert(y, &pary); 
+         /* GEC1002 the data chunk pointed by the local-parvectors 
+          *  inside the semistruct vectors x and y is now identical to the
+          *  data chunk of the structure vectors x and y. The role of the function
+          *  convert is to pass the addresses of the data chunk
+          *  to the parx and pary. */  
 
-      hypre_ParCSRMatrixMatvec(alpha, parcsrA, parx, 1.0, pary);
+         hypre_SStructVectorConvert(x, &parx);
+         hypre_SStructVectorConvert(y, &pary); 
 
-      /* dummy functions since there is nothing to restore  */
+         hypre_ParCSRMatrixMatvec(alpha, parcsrA, parx, 1.0, pary);
 
-      hypre_SStructVectorRestore(x, NULL);
-      hypre_SStructVectorRestore(y, pary); 
+         /* dummy functions since there is nothing to restore  */
 
-      parx = NULL; 
+         hypre_SStructVectorRestore(x, NULL);
+         hypre_SStructVectorRestore(y, pary); 
+
+         parx = NULL; 
+      }
 
   }
 
