@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.5 $
+ * $Revision: 2.8 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 #include "headers.h"
 
 /*==========================================================================*/
@@ -183,6 +170,29 @@ HYPRE_StructPCGSetTol( HYPRE_StructSolver solver,
 {
    return( HYPRE_PCGSetTol( (HYPRE_Solver) solver, tol ) );
 }
+/*==========================================================================*/
+/*==========================================================================*/
+/** (Optional) Set the absolute stopping tolerance.
+
+{\bf Input files:}
+headers.h
+
+@return Error code.
+
+@param solver [IN/OUT]
+  solver structure
+@param tol [IN]
+  PCG solver tolerance
+
+@see HYPRE_StructPCGSolve, HYPRE_StructPCGSetup   */
+/*--------------------------------------------------------------------------*/
+
+int
+HYPRE_StructPCGSetAbsoluteTol( HYPRE_StructSolver solver,
+                       double             tol    )
+{
+   return( HYPRE_PCGSetAbsoluteTol( (HYPRE_Solver) solver, tol ) );
+}
 
 /*==========================================================================*/
 /*==========================================================================*/
