@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.6 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  * HYPRE_StructPFMG interface
@@ -188,7 +175,10 @@ HYPRE_StructPFMGSetNonZeroGuess( HYPRE_StructSolver solver )
 }
 
 /*--------------------------------------------------------------------------
- * HYPRE_StructPFMGSetRelaxType, HYPRE_StructPFMGGetRelaxType
+ * HYPRE_StructPFMGSetRelaxType, HYPRE_StructPFMGGetRelaxType,
+ * HYPRE_StructPFMGSetJacobiWeight, HYPRE_StructPFMGGetJacobiWeight
+ * GetJacobiWeight will not return the actual weight
+ * if SetJacobiWeight has not been called.
  *--------------------------------------------------------------------------*/
 
 int
@@ -205,6 +195,19 @@ HYPRE_StructPFMGGetRelaxType( HYPRE_StructSolver solver,
    return( hypre_PFMGGetRelaxType( (void *) solver, relax_type) );
 }
 
+int
+HYPRE_StructPFMGSetJacobiWeight(HYPRE_StructSolver solver,
+                                double             weight)
+{
+   return( hypre_PFMGSetJacobiWeight( (void *) solver, weight) );
+}
+int
+HYPRE_StructPFMGGetJacobiWeight(HYPRE_StructSolver solver,
+                                double            *weight)
+{
+   return( hypre_PFMGGetJacobiWeight( (void *) solver, weight) );
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_StructPFMGSetRAPType, HYPRE_StructPFMGGetRAPType
  *--------------------------------------------------------------------------*/
