@@ -1,30 +1,15 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.2 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
-
 #include "_hypre_utilities.h"
 
 #include "HYPRE_struct_ls.h"
@@ -92,6 +77,7 @@ int HYPRE_StructBiCGSTABDestroy ( HYPRE_StructSolver solver );
 int HYPRE_StructBiCGSTABSetup ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructBiCGSTABSolve ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructBiCGSTABSetTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructBiCGSTABSetAbsoluteTol ( HYPRE_StructSolver solver , double tol );
 int HYPRE_StructBiCGSTABSetMaxIter ( HYPRE_StructSolver solver , int max_iter );
 int HYPRE_StructBiCGSTABSetPrecond ( HYPRE_StructSolver solver , HYPRE_PtrToStructSolverFcn precond , HYPRE_PtrToStructSolverFcn precond_setup , HYPRE_StructSolver precond_solver );
 int HYPRE_StructBiCGSTABSetLogging ( HYPRE_StructSolver solver , int logging );
@@ -100,13 +86,31 @@ int HYPRE_StructBiCGSTABGetNumIterations ( HYPRE_StructSolver solver , int *num_
 int HYPRE_StructBiCGSTABGetFinalRelativeResidualNorm ( HYPRE_StructSolver solver , double *norm );
 int HYPRE_StructBiCGSTABGetResidual ( HYPRE_StructSolver solver , void **residual );
 
+/* HYPRE_struct_flexgmres.c */
+int HYPRE_StructFlexGMRESCreate ( MPI_Comm comm , HYPRE_StructSolver *solver );
+int HYPRE_StructFlexGMRESDestroy ( HYPRE_StructSolver solver );
+int HYPRE_StructFlexGMRESSetup ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
+int HYPRE_StructFlexGMRESSolve ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
+int HYPRE_StructFlexGMRESSetTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructFlexGMRESSetAbsoluteTol ( HYPRE_StructSolver solver , double atol );
+int HYPRE_StructFlexGMRESSetMaxIter ( HYPRE_StructSolver solver , int max_iter );
+int HYPRE_StructFlexGMRESSetKDim ( HYPRE_StructSolver solver , int k_dim );
+int HYPRE_StructFlexGMRESSetPrecond ( HYPRE_StructSolver solver , HYPRE_PtrToStructSolverFcn precond , HYPRE_PtrToStructSolverFcn precond_setup , HYPRE_StructSolver precond_solver );
+int HYPRE_StructFlexGMRESSetLogging ( HYPRE_StructSolver solver , int logging );
+int HYPRE_StructFlexGMRESSetPrintLevel ( HYPRE_StructSolver solver , int print_level );
+int HYPRE_StructFlexGMRESGetNumIterations ( HYPRE_StructSolver solver , int *num_iterations );
+int HYPRE_StructFlexGMRESGetFinalRelativeResidualNorm ( HYPRE_StructSolver solver , double *norm );
+int HYPRE_StructFlexGMRESSetModifyPC ( HYPRE_StructSolver solver , HYPRE_PtrToModifyPCFcn modify_pc );
+
 /* HYPRE_struct_gmres.c */
 int HYPRE_StructGMRESCreate ( MPI_Comm comm , HYPRE_StructSolver *solver );
 int HYPRE_StructGMRESDestroy ( HYPRE_StructSolver solver );
 int HYPRE_StructGMRESSetup ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructGMRESSolve ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructGMRESSetTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructGMRESSetAbsoluteTol ( HYPRE_StructSolver solver , double atol );
 int HYPRE_StructGMRESSetMaxIter ( HYPRE_StructSolver solver , int max_iter );
+int HYPRE_StructGMRESSetKDim ( HYPRE_StructSolver solver , int k_dim );
 int HYPRE_StructGMRESSetPrecond ( HYPRE_StructSolver solver , HYPRE_PtrToStructSolverFcn precond , HYPRE_PtrToStructSolverFcn precond_setup , HYPRE_StructSolver precond_solver );
 int HYPRE_StructGMRESSetLogging ( HYPRE_StructSolver solver , int logging );
 int HYPRE_StructGMRESSetPrintLevel ( HYPRE_StructSolver solver , int print_level );
@@ -157,12 +161,29 @@ int HYPRE_StructJacobiSetNonZeroGuess ( HYPRE_StructSolver solver );
 int HYPRE_StructJacobiGetNumIterations ( HYPRE_StructSolver solver , int *num_iterations );
 int HYPRE_StructJacobiGetFinalRelativeResidualNorm ( HYPRE_StructSolver solver , double *norm );
 
+/* HYPRE_struct_lgmres.c */
+int HYPRE_StructLGMRESCreate ( MPI_Comm comm , HYPRE_StructSolver *solver );
+int HYPRE_StructLGMRESDestroy ( HYPRE_StructSolver solver );
+int HYPRE_StructLGMRESSetup ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
+int HYPRE_StructLGMRESSolve ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
+int HYPRE_StructLGMRESSetTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructLGMRESSetAbsoluteTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructLGMRESSetMaxIter ( HYPRE_StructSolver solver , int max_iter );
+int HYPRE_StructLGMRESSetKDim ( HYPRE_StructSolver solver , int k_dim );
+int HYPRE_StructLGMRESSetAugDim ( HYPRE_StructSolver solver , int aug_dim );
+int HYPRE_StructLGMRESSetPrecond ( HYPRE_StructSolver solver , HYPRE_PtrToStructSolverFcn precond , HYPRE_PtrToStructSolverFcn precond_setup , HYPRE_StructSolver precond_solver );
+int HYPRE_StructLGMRESSetLogging ( HYPRE_StructSolver solver , int logging );
+int HYPRE_StructLGMRESSetPrintLevel ( HYPRE_StructSolver solver , int print_level );
+int HYPRE_StructLGMRESGetNumIterations ( HYPRE_StructSolver solver , int *num_iterations );
+int HYPRE_StructLGMRESGetFinalRelativeResidualNorm ( HYPRE_StructSolver solver , double *norm );
+
 /* HYPRE_struct_pcg.c */
 int HYPRE_StructPCGCreate ( MPI_Comm comm , HYPRE_StructSolver *solver );
 int HYPRE_StructPCGDestroy ( HYPRE_StructSolver solver );
 int HYPRE_StructPCGSetup ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructPCGSolve ( HYPRE_StructSolver solver , HYPRE_StructMatrix A , HYPRE_StructVector b , HYPRE_StructVector x );
 int HYPRE_StructPCGSetTol ( HYPRE_StructSolver solver , double tol );
+int HYPRE_StructPCGSetAbsoluteTol ( HYPRE_StructSolver solver , double tol );
 int HYPRE_StructPCGSetMaxIter ( HYPRE_StructSolver solver , int max_iter );
 int HYPRE_StructPCGSetTwoNorm ( HYPRE_StructSolver solver , int two_norm );
 int HYPRE_StructPCGSetRelChange ( HYPRE_StructSolver solver , int rel_change );
@@ -192,6 +213,8 @@ int HYPRE_StructPFMGGetZeroGuess ( HYPRE_StructSolver solver , int *zeroguess );
 int HYPRE_StructPFMGSetNonZeroGuess ( HYPRE_StructSolver solver );
 int HYPRE_StructPFMGSetRelaxType ( HYPRE_StructSolver solver , int relax_type );
 int HYPRE_StructPFMGGetRelaxType ( HYPRE_StructSolver solver , int *relax_type );
+int HYPRE_StructPFMGSetJacobiWeight ( HYPRE_StructSolver solver , double weight );
+int HYPRE_StructPFMGGetJacobiWeight ( HYPRE_StructSolver solver , double *weight );
 int HYPRE_StructPFMGSetRAPType ( HYPRE_StructSolver solver , int rap_type );
 int HYPRE_StructPFMGGetRAPType ( HYPRE_StructSolver solver , int *rap_type );
 int HYPRE_StructPFMGSetNumPreRelax ( HYPRE_StructSolver solver , int num_pre_relax );
@@ -247,6 +270,7 @@ int HYPRE_StructSparseMSGSetRelChange ( HYPRE_StructSolver solver , int rel_chan
 int HYPRE_StructSparseMSGSetZeroGuess ( HYPRE_StructSolver solver );
 int HYPRE_StructSparseMSGSetNonZeroGuess ( HYPRE_StructSolver solver );
 int HYPRE_StructSparseMSGSetRelaxType ( HYPRE_StructSolver solver , int relax_type );
+int HYPRE_StructSparseMSGSetJacobiWeight ( HYPRE_StructSolver solver , double weight );
 int HYPRE_StructSparseMSGSetNumPreRelax ( HYPRE_StructSolver solver , int num_pre_relax );
 int HYPRE_StructSparseMSGSetNumPostRelax ( HYPRE_StructSolver solver , int num_post_relax );
 int HYPRE_StructSparseMSGSetNumFineRelax ( HYPRE_StructSolver solver , int num_fine_relax );
@@ -333,6 +357,8 @@ int hypre_PFMGSetZeroGuess ( void *pfmg_vdata , int zero_guess );
 int hypre_PFMGGetZeroGuess ( void *pfmg_vdata , int *zero_guess );
 int hypre_PFMGSetRelaxType ( void *pfmg_vdata , int relax_type );
 int hypre_PFMGGetRelaxType ( void *pfmg_vdata , int *relax_type );
+int hypre_PFMGSetJacobiWeight ( void *pfmg_vdata , double weight );
+int hypre_PFMGGetJacobiWeight ( void *pfmg_vdata , double *weight );
 int hypre_PFMGSetRAPType ( void *pfmg_vdata , int rap_type );
 int hypre_PFMGGetRAPType ( void *pfmg_vdata , int *rap_type );
 int hypre_PFMGSetNumPreRelax ( void *pfmg_vdata , int num_pre_relax );
@@ -356,6 +382,7 @@ int hypre_PFMGRelaxDestroy ( void *pfmg_relax_vdata );
 int hypre_PFMGRelax ( void *pfmg_relax_vdata , hypre_StructMatrix *A , hypre_StructVector *b , hypre_StructVector *x );
 int hypre_PFMGRelaxSetup ( void *pfmg_relax_vdata , hypre_StructMatrix *A , hypre_StructVector *b , hypre_StructVector *x );
 int hypre_PFMGRelaxSetType ( void *pfmg_relax_vdata , int relax_type );
+int hypre_PFMGRelaxSetJacobiWeight ( void *pfmg_relax_vdata , double weight );
 int hypre_PFMGRelaxSetPreRelax ( void *pfmg_relax_vdata );
 int hypre_PFMGRelaxSetPostRelax ( void *pfmg_relax_vdata );
 int hypre_PFMGRelaxSetTol ( void *pfmg_relax_vdata , double tol );
@@ -365,7 +392,7 @@ int hypre_PFMGRelaxSetTempVec ( void *pfmg_relax_vdata , hypre_StructVector *t )
 
 /* pfmg_setup.c */
 int hypre_PFMGSetup ( void *pfmg_vdata , hypre_StructMatrix *A , hypre_StructVector *b , hypre_StructVector *x );
-int hypre_PFMGComputeDxyz ( hypre_StructMatrix *A , double *dxyz );
+int hypre_PFMGComputeDxyz ( hypre_StructMatrix *A , double *dxyz , double *mean , double *deviation );
 int hypre_ZeroDiagonal ( hypre_StructMatrix *A );
 
 /* pfmg_setup_interp.c */
@@ -415,7 +442,6 @@ int hypre_PointRelaxSetTempVec ( void *relax_vdata , hypre_StructVector *t );
 int hypre_PointRelaxGetFinalRelativeResidualNorm ( void *relax_vdata , double *norm );
 int hypre_relax_wtx ( void *relax_vdata , int pointset , hypre_StructVector *t , hypre_StructVector *x );
 int hypre_relax_copy ( void *relax_vdata , int pointset , hypre_StructVector *t , hypre_StructVector *x );
-int hypre_sumsqdiff_pointset ( void *relax_vdata , int pointset , hypre_StructVector *t , hypre_StructVector *x , hypre_StructMatrix *A , double *sumsq );
 
 /* red_black_constantcoef_gs.c */
 int hypre_RedBlackConstantCoefGS ( void *relax_vdata , hypre_StructMatrix *A , hypre_StructVector *b , hypre_StructVector *x );
@@ -573,6 +599,7 @@ int hypre_SparseMSGSetJump ( void *smsg_vdata , int jump );
 int hypre_SparseMSGSetRelChange ( void *smsg_vdata , int rel_change );
 int hypre_SparseMSGSetZeroGuess ( void *smsg_vdata , int zero_guess );
 int hypre_SparseMSGSetRelaxType ( void *smsg_vdata , int relax_type );
+int hypre_SparseMSGSetJacobiWeight ( void *smsg_vdata , double weight );
 int hypre_SparseMSGSetNumPreRelax ( void *smsg_vdata , int num_pre_relax );
 int hypre_SparseMSGSetNumPostRelax ( void *smsg_vdata , int num_post_relax );
 int hypre_SparseMSGSetNumFineRelax ( void *smsg_vdata , int num_fine_relax );
