@@ -1,32 +1,19 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.2 $
+ * $Revision: 2.5 $
  ***********************************************************************EHEADER*/
 
 
 
 
+
 /******************************************************************************
  *
  * Struct matrix-vector implementation of PCG interface routines.
@@ -69,9 +56,11 @@ hypre_StructKrylovCreateVector( void *vvector )
 {
    hypre_StructVector *vector = vvector;
    hypre_StructVector *new_vector;
+   int                *num_ghost= hypre_StructVectorNumGhost(vector);
 
    new_vector = hypre_StructVectorCreate( hypre_StructVectorComm(vector),
                                           hypre_StructVectorGrid(vector) );
+   hypre_StructVectorSetNumGhost(new_vector, num_ghost);
    hypre_StructVectorInitialize(new_vector);
    hypre_StructVectorAssemble(new_vector);
 
@@ -87,6 +76,7 @@ hypre_StructKrylovCreateVectorArray(int n, void *vvector )
 {
    hypre_StructVector *vector = vvector;
    hypre_StructVector **new_vector;
+   int                *num_ghost= hypre_StructVectorNumGhost(vector);
    int i;
 
    new_vector = hypre_CTAlloc(hypre_StructVector*,n);
@@ -95,6 +85,7 @@ hypre_StructKrylovCreateVectorArray(int n, void *vvector )
       HYPRE_StructVectorCreate(hypre_StructVectorComm(vector),
                                 hypre_StructVectorGrid(vector),
                                 (HYPRE_StructVector *) &new_vector[i] );
+      hypre_StructVectorSetNumGhost(new_vector[i], num_ghost);
       HYPRE_StructVectorInitialize((HYPRE_StructVector) new_vector[i]);
       HYPRE_StructVectorAssemble((HYPRE_StructVector) new_vector[i]);
    }
