@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.10 $
+ * $Revision: 2.13 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -270,6 +257,7 @@ hypre_PFMGSetupInterpOp_CC0
    hypre_StructStencil   *stencil = hypre_StructMatrixStencil(A);
    hypre_Index           *stencil_shape = hypre_StructStencilShape(stencil);
    int                    stencil_size = hypre_StructStencilSize(stencil);
+   int                    warning_cnt= 0;
 
    hypre_BoxLoop2Begin(loop_size,
                        A_dbox, start, stride, Ai,
@@ -308,8 +296,17 @@ hypre_PFMGSetupInterpOp_CC0
                mrk1++;
          }
 
-         Pp0[Pi] /= center;
-         Pp1[Pi] /= center;  
+         if (!center)
+         {
+            warning_cnt++;
+            Pp0[Pi] = 0.0;
+            Pp1[Pi] = 0.0;  
+         }
+         else
+         {
+            Pp0[Pi] /= center;
+            Pp1[Pi] /= center;  
+         }
 
          /*----------------------------------------------
           * Set interpolation weight to zero, if stencil
@@ -323,6 +320,9 @@ hypre_PFMGSetupInterpOp_CC0
             Pp1[Pi] = 0.0;
       }
    hypre_BoxLoop2End(Ai, Pi);
+  
+   if (warning_cnt)
+      printf("warning 0 center in interpolation. Setting interp= 0.0 \n");
 
    return hypre_error_flag;
 }
@@ -356,6 +356,7 @@ hypre_PFMGSetupInterpOp_CC1
    hypre_StructStencil   *stencil = hypre_StructMatrixStencil(A);
    hypre_Index           *stencil_shape = hypre_StructStencilShape(stencil);
    int                    stencil_size = hypre_StructStencilSize(stencil);
+   int                    warning_cnt= 0;
 
    Ai = hypre_CCBoxIndexRank(A_dbox,start );
    Pi = hypre_CCBoxIndexRank(P_dbox,startc);
@@ -389,8 +390,17 @@ hypre_PFMGSetupInterpOp_CC1
       if (si == si1 && Ap[Ai] == 0.0)
          mrk1++;
    }
-   Pp0[Pi] /= center;
-   Pp1[Pi] /= center;  
+   if (!center)
+   {
+        warning_cnt++;
+        Pp0[Pi] = 0.0;
+        Pp1[Pi] = 0.0;  
+   }
+   else
+   {
+        Pp0[Pi] /= center;
+        Pp1[Pi] /= center;  
+   }
 
    /*----------------------------------------------
     * Set interpolation weight to zero, if stencil
@@ -408,6 +418,9 @@ hypre_PFMGSetupInterpOp_CC1
    if (mrk1 != 0)
       Pp1[Pi] = 0.0;
 
+   if (warning_cnt)
+      printf("warning 0 center in interpolation. Setting interp= 0.0 \n");
+
    return hypre_error_flag;
 }
 
@@ -445,6 +458,7 @@ hypre_PFMGSetupInterpOp_CC2
    int                    stencil_size = hypre_StructStencilSize(stencil);
    hypre_Index            diag_index;
    int                    diag_rank;
+   int                    warning_cnt= 0;
 
    hypre_SetIndex(diag_index, 0, 0, 0);
    diag_rank = hypre_StructStencilElementRank(stencil, diag_index);
@@ -538,8 +552,17 @@ hypre_PFMGSetupInterpOp_CC2
             if (si == si1 && Ap[Ai] == 0.0)
                mrk1++;
 
-            Pp0[Pi] /= center;
-            Pp1[Pi] /= center;  
+             if (!center)
+             {
+                warning_cnt++;
+                Pp0[Pi] = 0.0;
+                Pp1[Pi] = 0.0;  
+             }
+             else
+             {
+                Pp0[Pi] /= center;
+                Pp1[Pi] /= center;  
+             }
 
             /*----------------------------------------------
              * Set interpolation weight to zero, if stencil
@@ -556,5 +579,8 @@ hypre_PFMGSetupInterpOp_CC2
       hypre_BoxLoop2End(Ai, Pi);
    }
 
+   if (warning_cnt)
+      printf("warning 0 center in interpolation. Setting interp= 0.0 \n");
+
    return hypre_error_flag;
 }
