@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.3 $
+ * $Revision: 2.6 $
  ***********************************************************************EHEADER*/
 
 
 
+
 /******************************************************************************
  *
  *
@@ -49,22 +36,24 @@ hypre_SparseMSGCreate( MPI_Comm  comm )
    (smsg_data -> time_index) = hypre_InitializeTiming("SparseMSG");
 
    /* set defaults */
-   (smsg_data -> tol)            = 1.0e-06;
-   (smsg_data -> max_iter)       = 200;
-   (smsg_data -> rel_change)     = 0;
-   (smsg_data -> zero_guess)     = 0;
-   (smsg_data -> jump)           = 0;
-   (smsg_data -> relax_type)     = 1;       /* weighted Jacobi */
-   (smsg_data -> num_pre_relax)  = 1;
-   (smsg_data -> num_post_relax) = 1;
-   (smsg_data -> num_fine_relax) = 1;
-   (smsg_data -> logging)        = 0;
-   (smsg_data -> print_level)    = 0;
+   (smsg_data -> tol)              = 1.0e-06;
+   (smsg_data -> max_iter)         = 200;
+   (smsg_data -> rel_change)       = 0;
+   (smsg_data -> zero_guess)       = 0;
+   (smsg_data -> jump)             = 0;
+   (smsg_data -> relax_type)       = 1;       /* weighted Jacobi */
+   (smsg_data -> jacobi_weight)    = 0.0;
+   (smsg_data -> usr_jacobi_weight)= 0;     /* no user Jacobi weight */
+   (smsg_data -> num_pre_relax)    = 1;
+   (smsg_data -> num_post_relax)   = 1;
+   (smsg_data -> num_fine_relax)   = 1;
+   (smsg_data -> logging)          = 0;
+   (smsg_data -> print_level)      = 0;
 
    /* initialize */
-   (smsg_data -> num_grids[0])    = 1;
-   (smsg_data -> num_grids[1])    = 1;
-   (smsg_data -> num_grids[2])    = 1;
+   (smsg_data -> num_grids[0])     = 1;
+   (smsg_data -> num_grids[1])     = 1;
+   (smsg_data -> num_grids[2])     = 1;
 
    return (void *) smsg_data;
 }
@@ -264,6 +253,21 @@ hypre_SparseMSGSetRelaxType( void *smsg_vdata,
    return ierr;
 }
 
+/*--------------------------------------------------------------------------
+ * hypre_SparseMSGSetJacobiWeight
+ *--------------------------------------------------------------------------*/
+int
+hypre_SparseMSGSetJacobiWeight( void  *smsg_vdata,
+                                double weight )
+{
+   hypre_SparseMSGData *smsg_data = smsg_vdata;
+
+   (smsg_data -> jacobi_weight)    = weight;
+   (smsg_data -> usr_jacobi_weight)= 1;
+                                                                                                                                      
+   return hypre_error_flag;
+}
+
 /*--------------------------------------------------------------------------
  * hypre_SparseMSGSetNumPreRelax
  *--------------------------------------------------------------------------*/
