@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.3 $
+ * $Revision: 2.6 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  *
  *
@@ -72,6 +59,8 @@ hypre_SparseMSGSetup( void               *smsg_vdata,
    int                   max_iter;
    int                   jump       = (smsg_data -> jump);
    int                   relax_type = (smsg_data -> relax_type);
+   int                   usr_jacobi_weight= (smsg_data -> usr_jacobi_weight);
+   double                jacobi_weight    = (smsg_data -> jacobi_weight);
    int                  *num_grids  = (smsg_data -> num_grids);
    int                   num_all_grids;
    int                   num_levels;
@@ -725,6 +714,10 @@ hypre_SparseMSGSetup( void               *smsg_vdata,
    relax_a[0] = hypre_PFMGRelaxCreate(comm);
    hypre_PFMGRelaxSetTol(relax_a[0], 0.0);
    hypre_PFMGRelaxSetType(relax_a[0], relax_type);
+   if (usr_jacobi_weight)
+   {
+      hypre_PFMGRelaxSetJacobiWeight(relax_a[0], jacobi_weight);
+   }
    hypre_PFMGRelaxSetTempVec(relax_a[0], t_a[0]);
    hypre_PFMGRelaxSetup(relax_a[0], A_a[0], b_a[0], x_a[0]);
    /* set up the fine grid residual routine */
@@ -748,6 +741,10 @@ hypre_SparseMSGSetup( void               *smsg_vdata,
                   relax_a[fi] = hypre_PFMGRelaxCreate(comm);
                   hypre_PFMGRelaxSetTol(relax_a[fi], 0.0);
                   hypre_PFMGRelaxSetType(relax_a[fi], relax_type);
+                  if (usr_jacobi_weight)
+                  {
+                     hypre_PFMGRelaxSetJacobiWeight(relax_a[fi], jacobi_weight);
+                  }
                   hypre_PFMGRelaxSetTempVec(relax_a[fi], t_a[fi]);
                   hypre_PFMGRelaxSetup(relax_a[fi], A_a[fi], b_a[fi], x_a[fi]);
 
@@ -764,6 +761,10 @@ hypre_SparseMSGSetup( void               *smsg_vdata,
       hypre_PFMGRelaxSetTol(relax_a[fi], 0.0);
       hypre_PFMGRelaxSetMaxIter(relax_a[fi], 1);
       hypre_PFMGRelaxSetType(relax_a[fi], 0);
+      if (usr_jacobi_weight)
+      {
+         hypre_PFMGRelaxSetJacobiWeight(relax_a[fi], jacobi_weight);
+      }
       hypre_PFMGRelaxSetTempVec(relax_a[fi], t_a[fi]);
       hypre_PFMGRelaxSetup(relax_a[fi], A_a[fi], b_a[fi], x_a[fi]);
    }
