@@ -1,31 +1,18 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.13 $
+ * $Revision: 2.17 $
  ***********************************************************************EHEADER*/
 
 
 
+
 #ifndef HYPRE_STRUCT_MV_HEADER
 #define HYPRE_STRUCT_MV_HEADER
 
@@ -274,6 +261,30 @@ int HYPRE_StructMatrixAddToBoxValues(HYPRE_StructMatrix  matrix,
  **/
 int HYPRE_StructMatrixAssemble(HYPRE_StructMatrix matrix);
 
+/**
+ * Get matrix coefficients index by index.  The {\tt values} array is of length
+ * {\tt nentries}.
+ *
+ * NOTE: For better efficiency, use \Ref{HYPRE_StructMatrixGetBoxValues} to get
+ * coefficients a box at a time.
+ **/
+int HYPRE_StructMatrixGetValues(HYPRE_StructMatrix  matrix,
+                                int                *index,
+                                int                 nentries,
+                                int                *entries,
+                                double             *values);
+
+/**
+ * Get matrix coefficients a box at a time.  The data in {\tt values} is
+ * ordered as in \Ref{HYPRE_StructMatrixSetBoxValues}.
+ **/
+int HYPRE_StructMatrixGetBoxValues(HYPRE_StructMatrix  matrix,
+                                   int                *ilower,
+                                   int                *iupper,
+                                   int                 nentries,
+                                   int                *entries,
+                                   double             *values);
+
 /**
  * Define symmetry properties of the matrix.  By default, matrices are assumed
  * to be nonsymmetric.  Significant storage savings can be made if the matrix is
@@ -359,13 +370,6 @@ int HYPRE_StructVectorDestroy(HYPRE_StructVector vector);
  **/
 int HYPRE_StructVectorInitialize(HYPRE_StructVector vector);
 
-/**
- * Clears the ghostvalues of vector object. Beneficial to users that re-assemble
- * a vector object (e.g., in time-stepping).
- **/
-int HYPRE_StructVectorClearGhostValues(HYPRE_StructVector vector);
-
-
 /**
  * Set vector coefficients index by index.
  *
