@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.6 $
+ * $Revision: 2.9 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  *
  * HYPRE_StructVector interface
@@ -69,16 +56,6 @@ HYPRE_StructVectorInitialize( HYPRE_StructVector vector )
    return ( hypre_StructVectorInitialize(vector) );
 }
 
-/*--------------------------------------------------------------------------
- * HYPRE_StructVectorClearGhostValues
- *--------------------------------------------------------------------------*/
-                                                                                                      
-int
-HYPRE_StructVectorClearGhostValues( HYPRE_StructVector vector )
-{
-   return ( hypre_StructVectorClearGhostValues(vector) );
-}
-
 /*--------------------------------------------------------------------------
  * HYPRE_StructVectorSetValues
  *--------------------------------------------------------------------------*/
@@ -99,7 +76,7 @@ HYPRE_StructVectorSetValues( HYPRE_StructVector  vector,
       hypre_IndexD(new_grid_index, d) = grid_index[d];
    }
 
-   ierr = hypre_StructVectorSetValues(vector, new_grid_index, values, 0);
+   ierr = hypre_StructVectorSetValues(vector, new_grid_index, &values, 0, -1, 0);
 
    return ierr;
 }
@@ -131,7 +108,8 @@ HYPRE_StructVectorSetBoxValues( HYPRE_StructVector  vector,
    new_value_box = hypre_BoxCreate();
    hypre_BoxSetExtents(new_value_box, new_ilower, new_iupper);
 
-   ierr = hypre_StructVectorSetBoxValues(vector, new_value_box, values, 0 );
+   ierr = hypre_StructVectorSetBoxValues(vector, new_value_box, new_value_box,
+                                         values, 0, -1, 0);
 
    hypre_BoxDestroy(new_value_box);
 
@@ -158,7 +136,7 @@ HYPRE_StructVectorAddToValues( HYPRE_StructVector  vector,
       hypre_IndexD(new_grid_index, d) = grid_index[d];
    }
 
-   ierr = hypre_StructVectorSetValues(vector, new_grid_index, values, 1);
+   ierr = hypre_StructVectorSetValues(vector, new_grid_index, &values, 1, -1, 0);
 
    return ierr;
 }
@@ -190,7 +168,8 @@ HYPRE_StructVectorAddToBoxValues( HYPRE_StructVector  vector,
    new_value_box = hypre_BoxCreate();
    hypre_BoxSetExtents(new_value_box, new_ilower, new_iupper);
 
-   ierr = hypre_StructVectorSetBoxValues(vector, new_value_box, values, 1);
+   ierr = hypre_StructVectorSetBoxValues(vector, new_value_box, new_value_box,
+                                         values, 1, -1, 0);
 
    hypre_BoxDestroy(new_value_box);
 
@@ -215,7 +194,7 @@ HYPRE_StructVectorScaleValues( HYPRE_StructVector  vector,
 int 
 HYPRE_StructVectorGetValues( HYPRE_StructVector  vector,
                              int                *grid_index,
-                             double             *values_ptr )
+                             double             *values )
 {
    hypre_Index  new_grid_index;
                 
@@ -228,7 +207,7 @@ HYPRE_StructVectorGetValues( HYPRE_StructVector  vector,
       hypre_IndexD(new_grid_index, d) = grid_index[d];
    }
 
-   ierr = hypre_StructVectorGetValues(vector, new_grid_index, values_ptr);
+   ierr = hypre_StructVectorSetValues(vector, new_grid_index, values, -1, -1, 0);
 
    return ierr;
 }
@@ -260,7 +239,8 @@ HYPRE_StructVectorGetBoxValues( HYPRE_StructVector  vector,
    new_value_box = hypre_BoxCreate();
    hypre_BoxSetExtents(new_value_box, new_ilower, new_iupper);
 
-   ierr = hypre_StructVectorGetBoxValues(vector, new_value_box, values);
+   ierr = hypre_StructVectorSetBoxValues(vector, new_value_box, new_value_box,
+                                         values, -1, -1, 0);
 
    hypre_BoxDestroy(new_value_box);
 
