@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.7 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  *
  * Member functions for hypre_Box class:
@@ -562,6 +549,30 @@ hypre_BoxExpandConstant( hypre_Box   *box,
   return ierr;
 }
 
+/*--------------------------------------------------------------------------
+ * hypre_BoxExpandDim - grow a box in each direction (the same pos as negative)
+ * so expand is size 3
+ *--------------------------------------------------------------------------*/
+
+int
+hypre_BoxExpandConstantDim( hypre_Box   *box,
+                         int         *expand)
+{ 
+  int   ierr = 0;
+  int  *imin = hypre_BoxIMin(box);
+  int  *imax = hypre_BoxIMax(box);
+  int  d; 
+
+  for (d = 0; d < 3; d++)
+  {
+    imin[d] -= expand[d];
+    imax[d] += expand[d];
+  }
+  
+  return ierr;
+}
+
   
 
 
+
