@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.9 $
+ * $Revision: 2.12 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  *
  * Header info for the Box structures
@@ -108,6 +95,14 @@ typedef struct hypre_BoxArrayArray_struct
 
 #define hypre_ClearIndex(index)  hypre_SetIndex(index, 0, 0, 0)
 
+#define hypre_IndexZero(index)\
+   (hypre_IndexX(index) == 0 &&  hypre_IndexY(index) == 0 \
+    && hypre_IndexZ(index) == 0)
+
+#define hypre_IndexGTESize(index, size) \
+(hypre_IndexX(index) >= size &&  hypre_IndexY(index) >= size \
+    && hypre_IndexZ(index) >= size)
+
 #define hypre_CopyIndex(index1, index2) \
 ( hypre_IndexX(index2) = hypre_IndexX(index1),\
   hypre_IndexY(index2) = hypre_IndexY(index1),\
