@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.12 $
+ * $Revision: 2.15 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  * 
  *****************************************************************************/
@@ -312,8 +299,9 @@ hypre_ComputePkgCreate( hypre_ComputeInfo     *compute_info,
    compute_pkg = hypre_CTAlloc(hypre_ComputePkg, 1);
 
    hypre_CommPkgCreate(hypre_ComputeInfoCommInfo(compute_info),
-                       data_space, data_space, num_values,
+                       data_space, data_space, num_values, NULL, 0,
                        hypre_StructGridComm(grid), &comm_pkg);
+   hypre_CommInfoDestroy(hypre_ComputeInfoCommInfo(compute_info));
    hypre_ComputePkgCommPkg(compute_pkg) = comm_pkg;
 
    hypre_ComputePkgIndtBoxes(compute_pkg) = 
@@ -372,7 +360,7 @@ hypre_InitializeIndtComputations( hypre_ComputePkg  *compute_pkg,
    int            ierr = 0;
    hypre_CommPkg *comm_pkg = hypre_ComputePkgCommPkg(compute_pkg);
 
-   ierr = hypre_InitializeCommunication(comm_pkg, data, data, comm_handle_ptr);
+   ierr = hypre_InitializeCommunication(comm_pkg, data, data, 0, 0, comm_handle_ptr);
 
    return ierr;
 }
