@@ -1,30 +1,17 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team. UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer, contact information and the GNU Lesser General Public License.
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
  *
- * HYPRE is free software; you can redistribute it and/or modify it under the 
- * terms of the GNU General Public License (as published by the Free Software
- * Foundation) version 2.1 dated February 1999.
- *
- * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
- * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
- * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
- * Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.15 $
+ * $Revision: 2.18 $
  ***********************************************************************EHEADER*/
 
 
+
 /******************************************************************************
  *
  * Structured matrix-vector multiply routine
@@ -1076,7 +1063,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      AAp4 = Ap4[Ai_CC];
                      AAp5 = Ap5[Ai_CC];
                      AAp6 = Ap6[Ai_CC];
-                     if ( 0 <= si_center-si < 7 )
+                     if ( (0 <= si_center-si) && (si_center-si < 7) )
                      {
                         switch ( si_center-si )
                         {
@@ -1140,7 +1127,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      AAp3 = Ap3[Ai_CC];
                      AAp4 = Ap4[Ai_CC];
                      AAp5 = Ap5[Ai_CC];
-                     if ( 0 <= si_center-si < 6 )
+                     if ( (0 <= si_center-si) && (si_center-si < 6) )
                      {
                         switch ( si_center-si )
                         {
@@ -1195,7 +1182,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      AAp2 = Ap2[Ai_CC];
                      AAp3 = Ap3[Ai_CC];
                      AAp4 = Ap4[Ai_CC];
-                     if ( 0 <= si_center-si < 5 )
+                     if ( (0 <= si_center-si) && (si_center-si < 5) )
                      {
                         switch ( si_center-si )
                         {
@@ -1244,7 +1231,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      AAp1 = Ap1[Ai_CC];
                      AAp2 = Ap2[Ai_CC];
                      AAp3 = Ap3[Ai_CC];
-                     if ( 0 <= si_center-si < 4 )
+                     if ( (0 <= si_center-si) && (si_center-si < 4) )
                      {
                         switch ( si_center-si )
                         {
@@ -1287,7 +1274,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      AAp0 = Ap0[Ai_CC];
                      AAp1 = Ap1[Ai_CC];
                      AAp2 = Ap2[Ai_CC];
-                     if ( 0 <= si_center-si < 3 )
+                     if ( (0 <= si_center-si) && (si_center-si < 3) )
                      {
                         switch ( si_center-si )
                         {
@@ -1324,7 +1311,7 @@ int hypre_StructMatvecCC2( double              alpha,
                      Ap1 = hypre_StructMatrixBoxData(A, i, si+1);
                      AAp0 = Ap0[Ai_CC];
                      AAp1 = Ap1[Ai_CC];
-                     if ( 0 <= si_center-si < 2 )
+                     if ( (0 <= si_center-si) && (si_center-si < 2) )
                      {
                         switch ( si_center-si )
                         {
