@@ -1,30 +1,20 @@
 #!/bin/ksh
 #BHEADER**********************************************************************
-# Copyright (c) 2006   The Regents of the University of California.
+# Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory.
-# Written by the HYPRE team. UCRL-CODE-222953.
-# All rights reserved.
-#
-# This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
-# Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
-# disclaimer, contact information and the GNU Lesser General Public License.
+# This file is part of HYPRE.  See file COPYRIGHT for details.
 #
 # HYPRE is free software; you can redistribute it and/or modify it under the
-# terms of the GNU General Public License (as published by the Free Software 
-# Foundation) version 2.1 dated February 1999.
+# terms of the GNU Lesser General Public License (as published by the Free
+# Software Foundation) version 2.1 dated February 1999.
 #
-# HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
-# WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
-# FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
-# Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-#
-# $Revision: 1.12 $
+# $Revision: 1.16 $
 #EHEADER**********************************************************************
 
+
+
+
+
 TNAME=`basename $0 .sh`
 
 #=============================================================================
@@ -91,6 +81,29 @@ do
   tail -17 $i | head -6
 done >> ${TNAME}.out
 
+
+FILES="\
+ ${TNAME}.out.101\
+ ${TNAME}.out.102\
+ ${TNAME}.out.103\
+ ${TNAME}.out.104\
+"
+
+for i in $FILES
+do
+  echo "# Output file: $i"
+  tail -3 $i
+done >> ${TNAME}.out
+
+
+# Make sure that the output files are reasonable
+CHECK_LINE="Complexity"
+OUT_COUNT=`grep "$CHECK_LINE" ${TNAME}.out | wc -l`
+SAVED_COUNT=`grep "$CHECK_LINE" ${TNAME}.saved | wc -l`
+if [ "$OUT_COUNT" != "$SAVED_COUNT" ]; then
+   echo "Incorrect number of \"$CHECK_LINE\" lines in ${TNAME}.out" >&2
+fi
+
 if [ -z $HYPRE_NO_SAVED ]; then
    diff -U3 -bI"time" ${TNAME}.saved ${TNAME}.out >&2
 fi
