@@ -1,29 +1,16 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team, UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer and the GNU Lesser General Public License.
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License (as published by the Free
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.25 $
+ * $Revision: 2.29 $
  ***********************************************************************EHEADER*/
 
+
 /******************************************************************************
  *
  * Header file for HYPRE_utilities library
@@ -51,7 +38,7 @@ extern "C" {
  * Before a version of HYPRE goes out the door, increment the version
  * number and check in this file (for CVS to substitute the Date).
  */
-#define HYPRE_Version() "PACKAGE_STRING  $Date: 2006/09/26 22:51:26 $ Compiled: " __DATE__ " " __TIME__
+#define HYPRE_Version() "PACKAGE_STRING  $Date: 2008/07/18 01:34:47 $ Compiled: " __DATE__ " " __TIME__
 
 #ifdef HYPRE_USE_PTHREADS
 #ifndef hypre_MAX_THREADS
@@ -67,6 +54,18 @@ extern "C" {
 typedef int MPI_Comm;
 #endif
 
+
+/*--------------------------------------------------------------------------
+ * HYPRE error codes
+ *--------------------------------------------------------------------------*/
+
+#define HYPRE_ERROR_GENERIC         1   /* generic error */
+#define HYPRE_ERROR_MEMORY          2   /* unable to allocate memory */
+#define HYPRE_ERROR_ARG             4   /* argument error */
+/* bits 4-8 are reserved for the index of the argument error */
+#define HYPRE_ERROR_CONV          256   /* method did not converge as expected */
+
+
 /*--------------------------------------------------------------------------
  * HYPRE error user functions
  *--------------------------------------------------------------------------*/
@@ -84,6 +83,12 @@ int HYPRE_GetErrorArg();
 /* Describe the given error flag in the given string */
 void HYPRE_DescribeError(int hypre_ierr, char *descr);
 
+/* Clears the hypre error flag */
+int HYPRE_ClearAllErrors();
+
+/* Clears the given error code from the hypre error flag */
+int HYPRE_ClearError(int hypre_error_code);
+
 #ifdef __cplusplus
 }
 #endif
