@@ -1,29 +1,16 @@
 /*BHEADER**********************************************************************
- * Copyright (c) 2006   The Regents of the University of California.
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
  * Produced at the Lawrence Livermore National Laboratory.
- * Written by the HYPRE team, UCRL-CODE-222953.
- * All rights reserved.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
  *
- * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
- * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
- * disclaimer and the GNU Lesser General Public License.
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License (as published by the Free
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- * $Revision: 2.7 $
+ * $Revision: 2.10 $
  ***********************************************************************EHEADER*/
 
+
 /******************************************************************************
  *
  *  Fake mpi stubs to generate serial codes without mpi
@@ -434,13 +421,19 @@ hypre_MPI_Allreduce( void              *sendbuf,
                      hypre_MPI_Op       op,
                      hypre_MPI_Comm     comm )
 { 
+   int i;
+   
    switch (datatype)
    {
       case hypre_MPI_INT:
       {
          int *crecvbuf = (int *)recvbuf;
          int *csendbuf = (int *)sendbuf;
-         crecvbuf[0] = csendbuf[0];
+         for (i = 0; i < count; i++)
+         {
+            crecvbuf[i] = csendbuf[i];
+         }
+         
       } 
       break;
 
@@ -448,7 +441,10 @@ hypre_MPI_Allreduce( void              *sendbuf,
       {
          double *crecvbuf = (double *)recvbuf;
          double *csendbuf = (double *)sendbuf;
-         crecvbuf[0] = csendbuf[0];
+         for (i = 0; i < count; i++)
+         {
+            crecvbuf[i] = csendbuf[i];
+         }
       } 
       break;
 
@@ -456,13 +452,16 @@ hypre_MPI_Allreduce( void              *sendbuf,
       {
          char *crecvbuf = (char *)recvbuf;
          char *csendbuf = (char *)sendbuf;
-         crecvbuf[0] = csendbuf[0];
+         for (i = 0; i < count; i++)
+         {
+            crecvbuf[i] = csendbuf[i];
+         }
       } 
       break;
 
       case hypre_MPI_BYTE:
       {
-         memcpy(recvbuf, sendbuf, 1);
+         memcpy(recvbuf, sendbuf, count);
       } 
       break;
    }
